"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFilter = exports.decodeFilter = exports.operators = void 0;
var utils_1 = require("../../utils");
var date_time_helpers_1 = require("./date-time-helpers");
var utils_2 = require("./utils");
exports.operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_before: {
        getLabel: function (_s) { return 'is before'; },
    },
    is_after: {
        getLabel: function (_s) { return 'is after'; },
    },
};
exports.decodeFilter = function (filter) {
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var field = keys[0];
    var operator = filter.title;
    var value;
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_before') {
        value = filter.properties[field].formatMaximum;
    }
    else if (operator === 'is_after') {
        value = filter.properties[field].formatMinimum;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
exports.createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: utils_1.randomString(),
        title: operator,
        description: utils_2.getJsonDescription(title || field, exports.operators[operator].getLabel(schema), value),
        type: 'object',
    };
    var normalizedValue = date_time_helpers_1.normalizeDateTime(value);
    if (operator === 'is') {
        return Object.assign(base, {
            properties: (_a = {},
                _a[field] = {
                    type: 'string',
                    format: 'date-time',
                    const: normalizedValue,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_before') {
        return Object.assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'string',
                    format: 'date-time',
                    formatMaximum: normalizedValue,
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'is_after') {
        return Object.assign(base, {
            properties: (_c = {},
                _c[field] = {
                    type: 'string',
                    format: 'date-time',
                    formatMinimum: normalizedValue,
                },
                _c),
            required: [field],
        });
    }
    return base;
};
