"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFilter = exports.decodeFilter = exports.operators = void 0;
var utils_1 = require("../../utils");
var utils_2 = require("./utils");
exports.operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_more_than: {
        getLabel: function (_s) { return 'is more than'; },
    },
    is_less_than: {
        getLabel: function (_s) { return 'is less than'; },
    },
};
exports.decodeFilter = function (filter) {
    var operator = filter.title;
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var value;
    var field = keys[0];
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_more_than') {
        value = filter.properties[field].exclusiveMinimum;
    }
    else if (operator === 'is_less_than') {
        value = filter.properties[field].exclusiveMaximum;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
exports.createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: utils_1.randomString(),
        title: operator,
        description: utils_2.getJsonDescription(title || field, exports.operators[operator].getLabel(schema), value),
        type: 'object',
        required: [field],
    };
    var val = typeof value === 'number' ? value : Number(value);
    if (operator === 'is') {
        return Object.assign(base, {
            properties: (_a = {},
                _a[field] = {
                    type: 'number',
                    const: val,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_more_than') {
        return Object.assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'number',
                    exclusiveMinimum: val,
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'is_less_than') {
        return Object.assign(base, {
            properties: (_c = {},
                _c[field] = {
                    type: 'number',
                    exclusiveMaximum: val,
                },
                _c),
        });
    }
    return base;
};
