"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var DataTypes_1 = require("../../components/DataTypes");
var date_time_helpers_1 = require("../../components/DataTypes/date-time-helpers");
var expectMatchesKeys = function (data, keys) {
    return expect(Object.keys(data).sort()).toEqual(keys.sort());
};
describe('DataTypes', function () {
    describe('.getDataModel()', function () {
        var dataModelKeys = ['operators', 'createFilter', 'decodeFilter'];
        it('should return null if provided with a falsey value as the schema parameter', function () {
            expect(DataTypes_1.getDataModel()).toBe(null);
            expect(DataTypes_1.getDataModel(undefined)).toBe(null);
            expect(DataTypes_1.getDataModel(0)).toBe(null);
            expect(DataTypes_1.getDataModel(false)).toBe(null);
            expect(DataTypes_1.getDataModel(null)).toBe(null);
            expect(DataTypes_1.getDataModel('')).toBe(null);
        });
        it('should return null for unknown types', function () {
            var schema = {
                type: 'foobar',
            };
            expect(DataTypes_1.getDataModel(schema)).toBe(null);
        });
        it('should return a model for string types', function () {
            var schema = {
                type: 'string',
            };
            expectMatchesKeys(DataTypes_1.getDataModel(schema), dataModelKeys);
        });
        it('should return a model for string | null types', function () {
            var schema = {
                type: ['string', 'null'],
            };
            expectMatchesKeys(DataTypes_1.getDataModel(schema), dataModelKeys);
        });
        it('should return a model for date-time formatted string types', function () {
            var schema = {
                type: 'string',
                format: 'date-time',
            };
            expectMatchesKeys(DataTypes_1.getDataModel(schema), dataModelKeys);
        });
        it('should return a model for object types', function () {
            var schema = {
                type: 'object',
            };
            expectMatchesKeys(DataTypes_1.getDataModel(schema), __spreadArrays(['Edit'], dataModelKeys));
        });
        it('should return a model for boolean types', function () {
            var schema = {
                type: 'boolean',
            };
            expectMatchesKeys(DataTypes_1.getDataModel(schema), __spreadArrays(dataModelKeys, ['uiSchema']));
        });
        it('should return a model for number types', function () {
            var schema = {
                type: 'number',
            };
            expectMatchesKeys(DataTypes_1.getDataModel(schema), dataModelKeys);
        });
    });
    describe('normalizeDateTime', function () {
        it('rejects invalid date', function () {
            expect(date_time_helpers_1.normalizeDateTime('wrong time')).toEqual('Invalid date');
            expect(date_time_helpers_1.normalizeDateTime('')).toEqual('Invalid date');
        });
        it('formats the date correctly', function () {
            var tzFormat = function (stamp) {
                return new Date(stamp).toISOString().replace(/\.000/, '');
            };
            expect(date_time_helpers_1.normalizeDateTime('2017-01-01T08:49:26Z')).toEqual(tzFormat('2017-01-01T08:49:26Z'));
            expect(date_time_helpers_1.normalizeDateTime('2018-03-26T11:43')).toEqual(tzFormat('2018-03-26T11:43'));
            expect(date_time_helpers_1.normalizeDateTime('Sun, 01 Jan 2017 08:49:26 +0000')).toEqual(tzFormat('2017-01-01T08:49:26Z'));
        });
    });
});
