"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFilter = exports.decodeFilter = exports.operators = void 0;
var utils_1 = require("../../extra/AutoUI/utils");
var utils_2 = require("../../utils");
var SchemaSieve_1 = require("../Filters/SchemaSieve");
var utils_3 = require("./utils");
exports.operators = {
    contains: {
        getLabel: function (_s) { return 'contains'; },
    },
    not_contains: {
        getLabel: function (_s) { return 'does not contain'; },
    },
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    full_text_search: {
        getLabel: function (_s) { return 'full text search'; },
    },
    matches_re: {
        getLabel: function (_s) { return 'matches RegEx'; },
    },
    not_matches_re: {
        getLabel: function (_s) { return 'does not match RegEx'; },
    },
};
exports.decodeFilter = function (filter) {
    var _a, _b;
    var operator = filter.title;
    var value;
    var field;
    if (filter.properties) {
        var keys = Object.keys(filter.properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'is') {
            value = filter.properties[field].const;
        }
        else if (operator === 'contains') {
            value = filter.properties[field].description;
        }
        else if (operator === 'matches_re') {
            value = filter.properties[field].pattern;
        }
        else {
            return null;
        }
    }
    else if (filter.anyOf) {
        if (filter.anyOf.length === 0 || !filter.anyOf[0].properties) {
            return null;
        }
        var keys = Object.keys(filter.anyOf[0].properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'not_contains') {
            value = filter.anyOf[0].properties[field].description;
        }
        else if (operator === 'not_matches_re') {
            value = filter.anyOf[0].properties[field].not.pattern;
        }
        else if (operator === SchemaSieve_1.FULL_TEXT_SLUG) {
            return {
                field: 'any',
                operator: operator,
                value: (_b = (_a = utils_1.findInObject(filter.anyOf[0].properties, 'description')) !== null && _a !== void 0 ? _a : utils_1.findInObject(filter.anyOf[0].properties, 'pattern')) !== null && _b !== void 0 ? _b : utils_1.findInObject(filter.anyOf[0].properties, 'const'),
            };
        }
        else {
            return null;
        }
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
exports.createFilter = function (field, operator, value, schema) {
    var _a, _b, _c, _d, _e, _f, _g;
    var title = schema.title;
    var base = {
        $id: utils_2.randomString(),
        title: operator,
        description: utils_3.getJsonDescription(title || field, exports.operators[operator].getLabel(schema), value),
        type: 'object',
    };
    if (operator === 'is') {
        return Object.assign(base, {
            properties: (_a = {},
                _a[field] = {
                    title: title,
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'contains') {
        return Object.assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'string',
                    description: value,
                    regexp: {
                        pattern: utils_2.regexEscape(value),
                        flags: 'i',
                    },
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'not_contains') {
        return Object.assign(base, {
            anyOf: [
                {
                    properties: (_c = {},
                        _c[field] = {
                            type: 'string',
                            description: value,
                            not: {
                                regexp: {
                                    pattern: utils_2.regexEscape(value),
                                    flags: 'i',
                                },
                            },
                        },
                        _c),
                },
                {
                    properties: (_d = {},
                        _d[field] = {
                            type: 'null',
                        },
                        _d),
                },
            ],
        });
    }
    if (operator === 'matches_re') {
        return Object.assign(base, {
            properties: (_e = {},
                _e[field] = {
                    type: 'string',
                    pattern: value,
                },
                _e),
            required: [field],
        });
    }
    if (operator === 'not_matches_re') {
        return Object.assign(base, {
            anyOf: [
                {
                    properties: (_f = {},
                        _f[field] = {
                            type: 'string',
                            not: {
                                pattern: value,
                            },
                        },
                        _f),
                },
                {
                    properties: (_g = {},
                        _g[field] = {
                            type: 'null',
                        },
                        _g),
                },
            ],
        });
    }
    return base;
};
