"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
jest.mock('lodash/debounce', function () { return jest.fn(function (fn) { return fn; }); });
var enzyme_1 = require("enzyme");
var sinon_1 = __importDefault(require("sinon"));
var react_1 = __importDefault(require("react"));
var __1 = require("../..");
var FilterModal_1 = require("./FilterModal");
var sandbox = sinon_1.default.createSandbox();
describe('FilterModal', function () {
    var addFilter = sandbox.stub();
    var onClose = sandbox.stub();
    var edit = [
        {
            field: 'name',
            operator: 'is',
            value: '',
        },
    ];
    var schema = {
        type: 'object',
        properties: {
            name: {
                type: 'string',
            },
            type: {
                type: 'string',
            },
        },
    };
    afterEach(function () {
        sandbox.reset();
    });
    it('lets the user search for filter fields', function () {
        var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(FilterModal_1.FilterModal, { schema: schema, addFilter: addFilter, edit: edit, onClose: onClose })));
        var fieldSelect = component.find('Select').first();
        fieldSelect.simulate('click');
        var options = component.find('#filtermodal__fieldselect__select-drop button[role="menuitem"]');
        expect(options.length).toBe(2);
        expect(options.at(0).text()).toBe('name');
        expect(options.at(1).text()).toBe('type');
        var searchInput = component.find('input[placeholder="Search..."]');
        searchInput.simulate('change', { target: { value: 'type' } });
        options = component.find('#filtermodal__fieldselect__select-drop button[role="menuitem"]');
        expect(options.length).toBe(1);
        expect(options.at(0).text()).toBe('type');
    });
    it('allows a custom comparer to be provided', function () {
        var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(FilterModal_1.FilterModal, { schema: schema, addFilter: addFilter, edit: edit, onClose: onClose, fieldCompareFn: function (a, b) {
                    return b.title.toLowerCase().localeCompare(a.title.toLowerCase());
                } })));
        var fieldSelect = component.find('Select').first();
        fieldSelect.simulate('click');
        var options = component.find('#filtermodal__fieldselect__select-drop button[role="menuitem"]');
        expect(options.length).toBe(2);
        expect(options.at(0).text()).toBe('type');
        expect(options.at(1).text()).toBe('name');
    });
});
