"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCleanEditModel = exports.unflattenSchema = exports.flattenSchema = exports.getOperators = exports.decodeFilter = exports.createFilter = exports.removeFullTextSearch = exports.insertFullTextSearch = exports.createFullTextSearchFilter = exports.filter = exports.FULL_TEXT_SLUG = void 0;
var ajv_1 = __importDefault(require("ajv"));
var ajv_keywords_1 = __importDefault(require("ajv-keywords"));
var cloneDeep_1 = __importDefault(require("lodash/cloneDeep"));
var defaults_1 = __importDefault(require("lodash/defaults"));
var every_1 = __importDefault(require("lodash/every"));
var findKey_1 = __importDefault(require("lodash/findKey"));
var includes_1 = __importDefault(require("lodash/includes"));
var map_1 = __importDefault(require("lodash/map"));
var pickBy_1 = __importDefault(require("lodash/pickBy"));
var reduce_1 = __importDefault(require("lodash/reduce"));
var startsWith_1 = __importDefault(require("lodash/startsWith"));
var trimStart_1 = __importDefault(require("lodash/trimStart"));
var without_1 = __importDefault(require("lodash/without"));
var utils_1 = require("../../utils");
var DataTypes_1 = require("../DataTypes");
var ajv = new ajv_1.default();
ajv_keywords_1.default(ajv, ['regexp', 'formatMaximum', 'formatMinimum']);
exports.FULL_TEXT_SLUG = 'full_text_search';
var DEFAULT_DELIMITER = '___';
function filter(filters, collection) {
    ajv.removeSchema(/^.*$/);
    var validators = Array.isArray(filters)
        ? filters.map(function (s) { return ajv.compile(s); })
        : [ajv.compile(filters)];
    if (Array.isArray(collection)) {
        return collection.filter(function (m) { return every_1.default(validators, function (v) { return v(m); }); });
    }
    return pickBy_1.default(collection, function (m) { return every_1.default(validators, function (v) { return v(m); }); });
}
exports.filter = filter;
exports.createFullTextSearchFilter = function (schema, term) {
    var items = !!schema.properties
        ? Object.entries(schema.properties).reduce(function (itemsAccumulator, entry) {
            var _a, _b;
            var key = entry[0], item = entry[1];
            var model = DataTypes_1.getDataModel(item);
            var defaultItem = {
                key: key,
                schema: item,
                model: model,
            };
            if ((_a = item.type) === null || _a === void 0 ? void 0 : _a.includes('boolean')) {
                return itemsAccumulator;
            }
            if (!!model && (!item.type || !item.type.includes('object'))) {
                itemsAccumulator.push(__assign(__assign({}, defaultItem), { operator: (model === null || model === void 0 ? void 0 : model.operators) && 'contains' in model.operators
                        ? 'contains'
                        : 'is' }));
            }
            else if (!!model && ((_b = item.type) === null || _b === void 0 ? void 0 : _b.includes('object'))) {
                itemsAccumulator.push(__assign(__assign({}, defaultItem), { operator: 'key_contains', searchKey: findKey_1.default(item.properties, { description: 'key' }) }));
                itemsAccumulator.push(__assign(__assign({}, defaultItem), { operator: 'value_contains', searchKey: findKey_1.default(item.properties, { description: 'value' }) }));
            }
            return itemsAccumulator;
        }, [])
        : [];
    var filter = generateFullTextSearchAjvFilter(term, items);
    return filter;
};
var generateFullTextSearchAjvFilter = function (term, items) {
    return {
        $id: utils_1.randomString(),
        title: exports.FULL_TEXT_SLUG,
        anyOf: [
            {
                title: exports.FULL_TEXT_SLUG,
                description: "Any field contains " + term,
                anyOf: items.map(function (_a) {
                    var _b;
                    var key = _a.key, schema = _a.schema, operator = _a.operator, model = _a.model, searchKey = _a.searchKey;
                    var val = searchKey ? (_b = {}, _b[searchKey] = term, _b) : term;
                    return model === null || model === void 0 ? void 0 : model.createFilter(key, operator, val, schema);
                }),
            },
        ],
    };
};
exports.insertFullTextSearch = function (schema, filters, term) {
    if (filters === void 0) { filters = []; }
    var searchFilter = exports.createFullTextSearchFilter(schema, term);
    return filters.concat(searchFilter);
};
exports.removeFullTextSearch = function (filters) {
    return filters.filter(function (f) { return f.title !== exports.FULL_TEXT_SLUG; });
};
exports.createFilter = function (schema, signatures) {
    var anyOf = signatures.map(function (_a) {
        var field = _a.field, operator = _a.operator, value = _a.value;
        var subSchema = schema.properties[field];
        var model = DataTypes_1.getDataModel(subSchema);
        if (!model || !model.operators.hasOwnProperty(operator)) {
            return {};
        }
        return model.createFilter(field, operator, value, subSchema);
    });
    return {
        $id: utils_1.randomString(),
        anyOf: anyOf,
    };
};
exports.decodeFilter = function (schema, filter) {
    var signatures = filter.anyOf.map(function (f) {
        if (!f) {
            return null;
        }
        if (!f.properties &&
            (!f.anyOf || !f.anyOf.length || !f.anyOf[0].properties)) {
            return null;
        }
        var schemaField = f.anyOf
            ? Object.keys(f.anyOf[0].properties).shift()
            : Object.keys(f.properties).shift();
        var subSchema = schema.properties[schemaField];
        var model = DataTypes_1.getDataModel(subSchema);
        if (!model) {
            return {};
        }
        return model.decodeFilter(f);
    });
    return signatures.filter(function (s) { return s !== null; });
};
exports.getOperators = function (schema, field) {
    var subSchema = schema.properties[field];
    var model = DataTypes_1.getDataModel(subSchema);
    if (!model) {
        return [];
    }
    return map_1.default(model.operators, function (value, key) { return ({
        slug: key,
        label: value.getLabel(subSchema),
    }); });
};
var flattenAccumulator = function (schema, delimiter, parentKey, accumulator) {
    if (parentKey === void 0) { parentKey = ''; }
    if (!accumulator) {
        accumulator = cloneDeep_1.default(schema);
        if (schema.properties) {
            accumulator.properties = {};
        }
    }
    if (schema.anyOf && Array.isArray(schema.anyOf)) {
        accumulator.anyOf = schema.anyOf.map(function (subSchema) {
            return flattenAccumulator(subSchema, delimiter, parentKey);
        });
    }
    return reduce_1.default(schema.properties, function (result, value, key) {
        var _a;
        if (typeof value === 'boolean') {
            return accumulator;
        }
        var newKey = parentKey + delimiter + key;
        (_a = value.required) === null || _a === void 0 ? void 0 : _a.forEach(function (requiredKey) {
            if (!result.required) {
                result.required = [];
            }
            else {
                result.required = without_1.default(result.required, key, parentKey + delimiter + key);
            }
            result.required.push(newKey + delimiter + requiredKey);
        });
        if (value.type !== 'object' ||
            (findKey_1.default(value.properties, { description: 'key' }) &&
                findKey_1.default(value.properties, { description: 'value' }))) {
            if (parentKey) {
                result.properties[newKey] = defaults_1.default(value, { title: key });
                return result;
            }
            result.properties[key] = value;
            return result;
        }
        return flattenAccumulator(value, delimiter, newKey, result);
    }, accumulator);
};
exports.flattenSchema = function (schema, delimiter) {
    if (delimiter === void 0) { delimiter = DEFAULT_DELIMITER; }
    return flattenAccumulator(schema, delimiter);
};
exports.unflattenSchema = function (schema, delimiter) {
    if (delimiter === void 0) { delimiter = DEFAULT_DELIMITER; }
    var base = cloneDeep_1.default(schema);
    if (schema.properties) {
        base.properties = {};
    }
    var unflattenedSchema = reduce_1.default(schema.properties, function (result, value, field) {
        if (!startsWith_1.default(field, delimiter)) {
            result.properties[field] = value;
            return result;
        }
        var keys = trimStart_1.default(field, delimiter).split(delimiter);
        var lastKey = keys.pop();
        var head = result;
        for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
            var key = keys_1[_i];
            if (!head.properties[key]) {
                head.properties[key] = {
                    type: 'object',
                    properties: {},
                };
            }
            head = head.properties[key];
        }
        head.properties[lastKey] = value;
        return result;
    }, base);
    if (unflattenedSchema.anyOf) {
        unflattenedSchema.anyOf = unflattenedSchema.anyOf.map(function (subSchema) {
            return exports.unflattenSchema(subSchema, delimiter);
        });
    }
    if (unflattenedSchema.required) {
        var requiredFields = unflattenedSchema.required;
        unflattenedSchema.required = [];
        requiredFields.forEach(function (requiredField) {
            var fields = trimStart_1.default(requiredField, delimiter).split(delimiter);
            var head = unflattenedSchema;
            for (var _i = 0, fields_1 = fields; _i < fields_1.length; _i++) {
                var field = fields_1[_i];
                if (!head.required) {
                    head.required = [];
                }
                if (!includes_1.default(head.required, field)) {
                    head.required.push(field);
                }
                head = head.properties[field];
            }
        });
    }
    return unflattenedSchema;
};
exports.getCleanEditModel = function (schema, field) {
    if (!field) {
        field = Object.keys(schema.properties).shift();
    }
    var fieldOperators = exports.getOperators(schema, field);
    if (!fieldOperators.length) {
        return {
            field: field,
            operator: '',
            value: '',
        };
    }
    var operator = fieldOperators.shift().slug;
    var value = '';
    var subschema = schema.properties[field];
    if (typeof subschema !== 'boolean') {
        if (subschema.enum) {
            value = subschema.enum[0] || '';
        }
        if (subschema.oneOf) {
            value = subschema.oneOf[0].const || '';
        }
        if (subschema.type === 'boolean') {
            value = true;
        }
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
