"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var enzyme_1 = require("enzyme");
var react_1 = __importDefault(require("react"));
var __1 = require("../../");
var Summary_1 = __importDefault(require("../../components/Filters/Summary"));
var grommet_1 = require("grommet");
var react_fontawesome_1 = require("@fortawesome/react-fontawesome");
var schema = {
    type: 'object',
    properties: {
        Name: {
            title: 'Pokemon Name',
            type: 'string',
        },
        Tag: {
            type: 'object',
            properties: {
                tag_name: {
                    title: 'Name',
                    description: 'key',
                    type: 'string',
                },
                tag_value: {
                    description: 'value',
                    title: 'Value',
                    type: 'string',
                },
            },
        },
    },
};
var filter = __1.SchemaSieve.createFilter(schema, [
    {
        field: 'Name',
        operator: 'is',
        value: 'Squirtle',
    },
]);
var tagIsFilter = __1.SchemaSieve.createFilter(schema, [
    {
        field: 'Tag',
        operator: 'is',
        value: { tag_name: 'rarity', tag_value: '10' },
    },
]);
var tagIsNotFilter = __1.SchemaSieve.createFilter(schema, [
    {
        field: 'Tag',
        operator: 'is_not',
        value: { tag_name: 'rarity', tag_value: '10' },
    },
]);
var view = {
    id: 'abcde',
    name: 'Test',
    scope: null,
    filters: [filter],
};
var viewScopes = [
    {
        slug: 'foo',
        name: 'foo',
    },
    {
        slug: 'bar',
        name: 'bar',
    },
];
describe('Filters component', function () {
    describe('filters property', function () {
        it('should not render a summary if there are no filters', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema })));
            expect(component.find(Summary_1.default)).toHaveLength(0);
            component.unmount();
        });
        it('should render a summary of filters that are provided as props', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, filters: [filter] })));
            expect(component.find(Summary_1.default)).toHaveLength(1);
            component.unmount();
        });
        it('should render a summary of filters that are added as props after the component mounts', function () {
            var component = enzyme_1.mount(react_1.default.createElement(function (props) { return (react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, __assign({}, props)))); }, { schema: schema }));
            component.setProps({ filters: [filter] });
            component.update();
            expect(component.find(Summary_1.default)).toHaveLength(1);
            component.unmount();
        });
        it('should not render a summary of filters if they are removed after the component mounts', function () {
            var component = enzyme_1.mount(react_1.default.createElement(function (props) { return (react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, __assign({}, props)))); }, { schema: schema, filters: [filter] }));
            component.setProps({ filters: null });
            component.update();
            expect(component.find(Summary_1.default)).toHaveLength(0);
            component.unmount();
        });
        it('should show the correct label when filtering using "is" operator for both key and value properties of an object', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, filters: [tagIsFilter] })));
            expect(component.find('button').at(4).text()).toBe('Tag is rarity : 10');
        });
        it('should show the correct label when filtering using "is_not" operator for both key and value properties of an object', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, filters: [tagIsNotFilter] })));
            expect(component.find('button').at(4).text()).toBe('Tag is not rarity : 10');
        });
        it('should remove buttons labels if compact property is set to true', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { compact: [true, true, true, true], schema: schema })));
            expect(component.find('button').at(0).text()).toBe('');
            expect(component.find('button').at(1).text()).toBe('');
        });
    });
    describe('save views modal', function () {
        it('should not show scopes selector if one or less scopes are passed', function () {
            var withOneViewScope = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, filters: [filter], viewScopes: [viewScopes[0]] })));
            var withNoViewScopes = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, filters: [filter], viewScopes: [viewScopes[0]] })));
            withOneViewScope.find('button').at(3).simulate('click');
            expect(withOneViewScope.find(__1.Select)).toHaveLength(0);
            withNoViewScopes.find('button').at(3).simulate('click');
            expect(withNoViewScopes.find(__1.Select)).toHaveLength(0);
            withOneViewScope.unmount();
            withNoViewScopes.unmount();
        });
        it('should show scopes selector if viewScopes are passed', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, filters: [filter], viewScopes: viewScopes })));
            component.find('button').at(3).simulate('click');
            expect(component.find(__1.Select)).toHaveLength(1);
            component.unmount();
        });
    });
    describe('views property', function () {
        it('should not render a views menu if there are no views', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema })));
            component.find('button').at(1).simulate('click');
            expect(component.find(__1.Box).at(1).html()).toContain("You haven't created any views yet");
            component.unmount();
        });
        it('should render a list of views that are provided as props', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, views: [view] })));
            component.find('button').at(1).simulate('click');
            expect(component.find(react_fontawesome_1.FontAwesomeIcon)).toHaveLength(5);
            component.unmount();
        });
        it('should not render scoped views in the views menu if no scopes are passed', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, views: [__assign(__assign({}, view), { scope: 'foo' })] })));
            component.find('button').at(1).simulate('click');
            expect(component.find("[children='foo']")).toHaveLength(0);
            expect(component.find("[children='null']")).toHaveLength(0);
            component.unmount();
        });
        it('should not render scoped views in the views menu if one or less scopes are passed', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, views: [__assign(__assign({}, view), { scope: 'foo' })], viewScopes: [viewScopes[0]] })));
            component.find('button').at(1).simulate('click');
            expect(component.find("[children='foo']")).toHaveLength(0);
            component.unmount();
        });
        it('should render scoped views in the views menu if more than one viewScopes are passed', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, views: [__assign(__assign({}, view), { scope: 'foo' })], viewScopes: viewScopes })));
            component.find('button').at(1).simulate('click');
            expect(component.find('strong').at(0).text()).toEqual('foo');
            expect(component.find("[children='bar']")).toHaveLength(0);
            component.unmount();
        });
        it('should render views as "Unscoped" if they do not have a scope and more than one viewScopes are passed', function () {
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, views: [__assign({}, view)], viewScopes: viewScopes })));
            component.find('button').at(1).simulate('click');
            expect(component.find('strong').at(0).text()).toEqual('Unscoped');
            expect(component.find("[children='foo']")).toHaveLength(0);
            expect(component.find("[children='bar']")).toHaveLength(0);
            component.unmount();
        });
        it('should render a list of views that are added as props after the component mounts', function () {
            var component = enzyme_1.mount(react_1.default.createElement(function (props) { return (react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, __assign({}, props)))); }, { schema: schema }));
            component.setProps({ views: [view] });
            component.update();
            component.find('button').at(1).simulate('click');
            expect(component.find(react_fontawesome_1.FontAwesomeIcon)).toHaveLength(5);
            component.unmount();
        });
        it('should not render a list of views if they are removed after the component mounts', function () {
            var component = enzyme_1.mount(react_1.default.createElement(function (props) { return (react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, __assign({}, props)))); }, { schema: schema, views: [view] }));
            component.setProps({ views: null });
            component.update();
            component.find('button').at(1).simulate('click');
            expect(component.find(__1.Box).at(1).html()).toContain("You haven't created any views yet");
            component.unmount();
        });
        it('should render when the schema contains an unknown type', function () {
            var unknownSchema = {
                type: 'object',
                properties: {
                    test: {
                        type: 'Foo Bar',
                    },
                },
            };
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: unknownSchema })));
            component.unmount();
        });
        it('should clear all filters when `clear all filters` gets clicked', function () {
            var defaultFilters = __1.SchemaSieve.createFilter(schema, [
                { field: 'Name', operator: 'contains', value: 's' },
                { field: 'Name', operator: 'contains', value: 'q' },
            ]);
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Filters, { schema: schema, filters: [defaultFilters] })));
            expect(component.find(Summary_1.default)).toHaveLength(1);
            component
                .find('input')
                .simulate('change', { target: { value: 'Squirtle' } });
            component.find(grommet_1.Keyboard).simulate('keypress', { key: 'Enter' });
            expect(component.text()).toContain('Clear all');
            component
                .findWhere(function (node) { return node.text() === 'Clear all'; })
                .at(1)
                .simulate('click');
            expect(component.find(Summary_1.default)).toHaveLength(0);
            component.unmount();
        });
    });
});
