"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var enzyme_1 = require("enzyme");
var react_1 = __importDefault(require("react"));
var sinon_1 = __importDefault(require("sinon"));
var __1 = require("../../");
var ESCAPE_KEY = 27;
var ENTER_KEY = 13;
describe('Keyboard closing modals', function () {
    it('should call the callback of the top-most nested modal on Escape key press', function () {
        var firstModalSpy = sinon_1.default.spy();
        var secondModalSpy = sinon_1.default.spy();
        var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(__1.Modal, { done: firstModalSpy },
                react_1.default.createElement(__1.Modal, { done: secondModalSpy }, "Test"))));
        component
            .find('div[onKeyDown]')
            .forEach(function (node) { return node.simulate('keydown', { which: ESCAPE_KEY }); });
        expect(firstModalSpy.notCalled).toBeTruthy();
        expect(secondModalSpy.calledOnce).toBeTruthy();
    });
    it('should call the callback of the only modal on Escape key press', function () {
        var modalSpy = sinon_1.default.spy();
        var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(__1.Modal, { done: modalSpy }, "Test")));
        component
            .find('div[onKeyDown]')
            .forEach(function (node) { return node.simulate('keydown', { which: ESCAPE_KEY }); });
        expect(modalSpy.calledOnce).toBeTruthy();
    });
});
describe('Keyboard submitting nested modals', function () {
    var originalAddEventListener;
    var eventListenersMap = {};
    beforeAll(function () {
        originalAddEventListener = window.addEventListener;
        window.addEventListener = function (event, cb) {
            if (!eventListenersMap[event]) {
                eventListenersMap[event] = [];
            }
            eventListenersMap[event].push(cb);
        };
    });
    afterAll(function () {
        window.addEventListener = originalAddEventListener;
    });
    it('should call the callback of the top-most modal with done on Enter key press', function () {
        var firstModalSpy = sinon_1.default.spy();
        var secondModalSpy = sinon_1.default.spy();
        enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(__1.Modal, { done: firstModalSpy },
                react_1.default.createElement(__1.Modal, { done: secondModalSpy }, "Test"))));
        eventListenersMap.keydown.forEach(function (fn) {
            return fn({
                preventDefault: function () { return null; },
                stopPropagation: function () { return null; },
                which: ENTER_KEY,
            });
        });
        expect(firstModalSpy.notCalled).toBeTruthy();
        expect(secondModalSpy.calledOnce).toBeTruthy();
    });
    it('should not call any callback of either modal on Enter key press when the primary button is disabled', function () {
        var firstModalSpy = sinon_1.default.spy();
        var secondModalSpy = sinon_1.default.spy();
        enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(__1.Modal, { done: firstModalSpy },
                react_1.default.createElement(__1.Modal, { primaryButtonProps: { disabled: true }, done: secondModalSpy }, "Test"))));
        eventListenersMap.keydown.forEach(function (fn) {
            return fn({
                preventDefault: function () { return null; },
                stopPropagation: function () { return null; },
                which: ENTER_KEY,
            });
        });
        expect(firstModalSpy.notCalled).toBeTruthy();
        expect(secondModalSpy.notCalled).toBeTruthy();
    });
});
