"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var enzyme_1 = require("enzyme");
var react_1 = __importDefault(require("react"));
var sinon_1 = __importDefault(require("sinon"));
var __1 = require("../../");
var NotificationsComponent = function (_a) {
    var content = _a.content, idToRemove = _a.idToRemove;
    return (react_1.default.createElement(__1.Provider, null,
        react_1.default.createElement(__1.NotificationsContainer, null),
        react_1.default.createElement(__1.Button, { onClick: function () { return __1.notifications.addNotification(content); } }, "Add text notification"),
        react_1.default.createElement(__1.Button, { onClick: function () { return __1.notifications.removeNotification(idToRemove); } }, "Remove text notification")));
};
describe('Notifications component', function () {
    it('can add a notification', function () {
        var component = enzyme_1.mount(react_1.default.createElement(NotificationsComponent, { content: 'A notification' }));
        component.find('button').first().simulate('click');
        expect(component.find('.notification-item').text()).toBe('A notification');
    });
    it('can remove a notification using the API', function () {
        var id = 'notification-id';
        var component = enzyme_1.mount(react_1.default.createElement(NotificationsComponent, { content: { content: 'A notification', id: id }, idToRemove: id }));
        component.find('button').first().simulate('click');
        component.find('button').at(2).simulate('click');
        component.find('.notification-item').first().simulate('transitionend');
        expect(component.find('.notification-item')).toHaveLength(0);
    });
    it('can remove a notification by clicking on the dismiss button', function () {
        var component = enzyme_1.mount(react_1.default.createElement(NotificationsComponent, { content: 'A notification' }));
        component.find('button').first().simulate('click');
        component
            .find('.notification-item')
            .find('button')
            .first()
            .simulate('click');
        component.find('.notification-item').first().simulate('transitionend');
        expect(component.find('.notification-item')).toHaveLength(0);
    });
    it('calls the onDismiss callback when the dismiss button is clicked', function () {
        var callback = sinon_1.default.spy();
        var component = enzyme_1.mount(react_1.default.createElement(NotificationsComponent, { content: { content: 'A notification', onDismiss: callback } }));
        component.find('button').first().simulate('click');
        component
            .find('.notification-item')
            .find('button')
            .first()
            .simulate('click');
        expect(callback.callCount).toEqual(1);
    });
    it('disappears after the duration passes', function () {
        var component = enzyme_1.mount(react_1.default.createElement(NotificationsComponent, { content: { content: 'A notification', duration: 20 } }));
        var clock = sinon_1.default.useFakeTimers();
        component.find('button').first().simulate('click');
        component.find('.notification-item').first().simulate('transitionend');
        clock.tick(200);
        component.find('.notification-item').first().simulate('transitionend');
        expect(component.find('.notification-item')).toHaveLength(0);
        clock.restore();
    });
    it('displays notifications in the expected position', function () {
        var container = 'bottom-right';
        var component = enzyme_1.mount(react_1.default.createElement(NotificationsComponent, { content: {
                container: container,
                content: 'A notification',
            } }));
        component.find('button').first().simulate('click');
        expect(component.find(".notification-container-" + container).text()).toBe('A notification');
    });
});
