"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateUiSchemaMetaSchema = void 0;
var first_1 = __importDefault(require("lodash/first"));
var forEach_1 = __importDefault(require("lodash/forEach"));
var get_1 = __importDefault(require("lodash/get"));
var without_1 = __importDefault(require("lodash/without"));
var uniq_1 = __importDefault(require("lodash/uniq"));
var keys_1 = __importDefault(require("lodash/keys"));
var widgets_1 = require("../widgets");
var index_1 = require("../index");
var widgets_2 = require("../widgets");
var widget_util_1 = require("../widgets/widget-util");
var getBaseMetaSchema = function () { return ({
    title: 'Renderer UI Schema',
    type: ['object', 'null'],
    properties: {
        'ui:title': {
            type: ['string', 'null'],
        },
        'ui:description': {
            type: ['string', 'null'],
        },
        'ui:value': {
            type: ['string', 'object', 'null'],
        },
        'ui:options': {
            type: 'object',
        },
        'ui:explicit': {
            type: 'boolean',
        },
    },
}); };
var generateArrayMetaSchema = function (metaSchema, _a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    var arrayValue = value;
    var itemsUiSchema = get_1.default(uiSchema, 'items', {});
    var itemsSchema = get_1.default(schema, 'items', {});
    metaSchema.properties.items = exports.generateUiSchemaMetaSchema({
        value: first_1.default(arrayValue),
        schema: typeof itemsSchema === 'boolean' ? {} : itemsSchema,
        uiSchema: itemsUiSchema,
        extraContext: extraContext,
        extraFormats: extraFormats,
    });
};
var generateObjectMetaSchema = function (metaSchema, _a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    metaSchema.properties['ui:order'] = {
        type: ['array'],
        items: {
            type: 'string',
            enum: keys_1.default(schema === null || schema === void 0 ? void 0 : schema.properties).concat(['*']),
        },
    };
    var propertyNames = widgets_2.getObjectPropertyNames({
        value: value || '',
        schema: schema,
        uiSchema: uiSchema || {},
    });
    forEach_1.default(propertyNames, function (propertyName) {
        var subSchema = get_1.default(schema, ['properties', propertyName], {});
        var subUiSchema = get_1.default(uiSchema, propertyName, {});
        metaSchema.properties[propertyName] = exports.generateUiSchemaMetaSchema({
            value: get_1.default(value, propertyName),
            schema: typeof subSchema === 'boolean' ? {} : subSchema,
            uiSchema: subUiSchema,
            extraContext: extraContext,
            extraFormats: extraFormats,
        });
    });
};
var setWidgetOptions = function (metaSchema, type) {
    var widgetKeys = __spreadArrays([
        type
    ], widgets_1.defaultFormats
        .filter(function (x) { var _a, _b; return (_b = (_a = x.widget) === null || _a === void 0 ? void 0 : _a.supportedTypes) === null || _b === void 0 ? void 0 : _b.includes(type); })
        .map(function (x) { return x.name; }));
    metaSchema.properties['ui:widget'] = {
        oneof: [
            {
                type: 'string',
                enum: without_1.default(uniq_1.default(widgetKeys), 'default'),
            },
            {
                type: 'object',
            },
        ],
    };
};
var setUiOptions = function (_a) {
    var metaSchema = _a.metaSchema, format = _a.format, _b = _a.input, value = _b.value, uiSchema = _b.uiSchema;
    var widget = index_1.getWidget(value, format, get_1.default(uiSchema, 'ui:widget'));
    metaSchema.properties['ui:options'] = {
        type: 'object',
        properties: __assign(__assign({}, widgets_2.WidgetWrapperUiOptions), widget.uiOptions),
    };
};
exports.generateUiSchemaMetaSchema = function (_a) {
    var unprocessedValue = _a.value, uiSchema = _a.uiSchema, schema = _a.schema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    var metaSchema = getBaseMetaSchema();
    var processedUiSchema = widget_util_1.transformUiSchema({
        value: unprocessedValue,
        uiSchema: uiSchema,
        extraContext: extraContext,
    });
    var input = {
        value: get_1.default(processedUiSchema, 'ui:value', unprocessedValue),
        schema: schema,
        uiSchema: processedUiSchema,
        extraContext: extraContext,
        extraFormats: extraFormats,
    };
    var type = index_1.getType(input.value);
    if (type === 'object') {
        generateObjectMetaSchema(metaSchema, input);
    }
    else if (type === 'array') {
        generateArrayMetaSchema(metaSchema, input);
    }
    if (type) {
        setWidgetOptions(metaSchema, type);
    }
    setUiOptions({ metaSchema: metaSchema, format: schema === null || schema === void 0 ? void 0 : schema.format, input: input });
    return metaSchema;
};
