import { Format } from './types';
export declare const CONTEXT_FUNCTIONS: {
    fns: {
        prependHello: (input: string) => string;
    };
};
export declare const EXTRA_FORMATS: Format[];
declare const jsonDataExamples: {
    'A string': {
        value: string;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                bold: boolean;
                italic: boolean;
                monospace: boolean;
                caps: boolean;
                align: string;
                whitespace: string;
            };
        };
    };
    'A number': {
        value: number;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {};
    };
    'An integer': {
        value: number;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {};
    };
    'A boolean': {
        value: boolean;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {
            'ui:options': {
                label: string;
                reverse: boolean;
                toggle: boolean;
            };
        };
    };
    'A null object': {
        value: null;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {
            'ui:widget': string;
        };
    };
    'A default value': {
        value: null;
        schema: {
            type: string[];
            default: string;
            title: string;
            description: string;
        };
        uiSchema: {
            'ui:widget': string;
        };
    };
    'An array of strings field': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            items: {
                'ui:widget': string;
            };
        };
    };
    'An invalid value': {
        value: {
            eh: string;
        };
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {};
    };
    'A hidden field': {
        value: {
            hidden: string;
            shown: string;
        };
        schema: {
            type: string;
            properties: {
                hidden: {
                    type: string;
                };
                shown: {
                    type: string;
                };
            };
        };
        uiSchema: {
            hidden: null;
        };
    };
    'A hidden title': {
        value: string;
        schema: {
            type: string;
            title: string;
        };
        uiSchema: {
            'ui:title': null;
        };
    };
    'An object with various properties': {
        value: {
            aString: string;
            aNumber: number;
            anInteger: number;
            aBoolean: boolean;
            aNull: null;
        };
        schema: {
            type: string;
            title: string;
            description: string;
            properties: {
                aString: {
                    type: string;
                    title: string;
                };
                aNumber: {
                    type: string;
                    title: string;
                };
                anInteger: {
                    type: string;
                    title: string;
                };
                aBoolean: {
                    type: string;
                    title: string;
                };
                aNull: {
                    type: string;
                    title: string;
                };
            };
        };
        uiSchema: {
            aString: {
                'ui:widget': string;
            };
            aNumber: {
                'ui:widget': string;
            };
            anInteger: {
                'ui:widget': string;
            };
            aBoolean: {
                'ui:widget': string;
            };
            aNull: {
                'ui:widget': string;
            };
        };
    };
    'Explicitly specifying which fields to render': {
        value: {
            aString: string;
            aNumber: number;
            anInteger: number;
            aBoolean: boolean;
            aNull: null;
        };
        schema: {
            type: string;
            title: string;
            description: string;
            properties: {
                aString: {
                    type: string;
                    title: string;
                };
                aNumber: {
                    type: string;
                    title: string;
                };
                anInteger: {
                    type: string;
                    title: string;
                };
                aBoolean: {
                    type: string;
                    title: string;
                };
                aNull: {
                    type: string;
                    title: string;
                };
            };
        };
        uiSchema: {
            'ui:explicit': boolean;
            aString: {
                'ui:widget': string;
            };
            aNumber: {
                'ui:widget': string;
            };
        };
    };
    'Re-ordered fields': {
        value: {
            fieldA: string;
            fieldB: string;
            fieldC: string;
        };
        schema: {
            type: string;
            properties: {
                fieldA: {
                    type: string;
                };
                fieldB: {
                    type: string;
                };
                fieldC: {
                    type: string;
                };
            };
        };
        uiSchema: {
            'ui:order': string[];
        };
    };
    'A truncated string': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                truncate: boolean;
            };
        };
    };
    'A truncated array of strings field': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:options': {
                truncate: number;
            };
        };
    };
    'A string-interpolated value': {
        value: number;
        schema: {
            type: string;
            title: string;
        };
        uiSchema: {
            'ui:value': string;
        };
    };
    'An evaluated value': {
        value: number;
        schema: {
            type: string;
            title: string;
        };
        uiSchema: {
            'ui:title': string;
            'ui:widget': string;
            'ui:value': {
                $eval: string;
            };
        };
    };
    'Using context functions': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:value': {
                $eval: string;
            };
        };
    };
    'A materialized field': {
        value: {
            firstName: string;
            lastName: string;
        };
        schema: {
            type: string;
            properties: {
                firstName: {
                    type: string;
                };
                lastName: {
                    type: string;
                };
            };
        };
        uiSchema: {
            firstName: null;
            lastName: null;
            'ui:field:fullName': {
                'ui:title': string;
                'ui:widget': string;
                'ui:value': string;
            };
        };
    };
    'A badge widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                shade: number;
            };
        };
    };
    'A button widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                href: string;
                target: string;
                disabled: boolean;
                primary: boolean;
                secondary: boolean;
                tertiary: boolean;
                quarternary: boolean;
                danger: boolean;
                warning: boolean;
                success: boolean;
                info: boolean;
                light: boolean;
                outline: boolean;
                plain: boolean;
                underline: boolean;
            };
        };
    };
    'A button group widget': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:widget': string;
            items: {
                'ui:options': {
                    href: string;
                };
            };
        };
    };
    'A color widget': {
        value: string;
        schema: {
            type: string;
            format: string;
        };
        uiSchema: {
            'ui:options': {
                label: string;
                hideValueDisplay: boolean;
                width: number;
                height: number;
            };
        };
    };
    'A drop-down button widget': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                label: string;
                disabled: boolean;
                primary: boolean;
                secondary: boolean;
                tertiary: boolean;
                quarternary: boolean;
                danger: boolean;
                warning: boolean;
                success: boolean;
                info: boolean;
                emphasized: boolean;
                square: boolean;
                border: boolean;
                joined: boolean;
                alignRight: boolean;
                listMaxHeight: string;
            };
            items: {
                'ui:widget': string;
                'ui:options': {
                    href: string;
                };
            };
        };
    };
    'A Link widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:value': string;
            'ui:options': {
                blank: boolean;
                href: string;
            };
        };
    };
    'An Img widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                width: number;
                alt: string;
            };
        };
    };
    'A Tag widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                name: string;
            };
        };
    };
    'A ProgressBar widget': {
        value: number;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:title': string;
            'ui:widget': string;
            'ui:options': {
                flex: number;
                alignItems: string;
                background: string;
                tertiary: boolean;
            };
        };
    };
    'A HighlightedName widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                bg: string;
                color: string;
            };
        };
    };
    'A Heading widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                size: number;
            };
        };
    };
    'A List widget': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                ordered: boolean;
            };
            items: {
                'ui:widget': string;
                'ui:options': {
                    href: string;
                };
            };
        };
    };
    'A markdown field': {
        value: string;
        schema: {
            type: string;
            format: string;
        };
        uiSchema: {};
    };
    'A mermaid field': {
        value: string;
        schema: {
            type: string;
            format: string;
        };
        uiSchema: {
            'ui:options': {
                flex: number;
            };
        };
    };
    'An email field': {
        value: string;
        schema: {
            type: string;
            format: string;
        };
        uiSchema: {};
    };
    'A date time field': {
        value: string;
        schema: {
            type: string;
            format: string;
        };
        uiSchema: {
            'ui:options': {
                dtFormat: string;
            };
        };
    };
    'A uri field': {
        value: string;
        schema: {
            type: string;
            format: string;
        };
        uiSchema: {};
    };
    'anyOf options': {
        value: {
            text: string;
        };
        schema: {
            type: string;
            anyOf: ({
                type: string;
                title: string;
                properties: {
                    text: {
                        type: string;
                        format: string;
                    };
                    num?: undefined;
                };
            } | {
                type: string;
                properties: {
                    num: {
                        type: string;
                        title: string;
                    };
                    text?: undefined;
                };
                title?: undefined;
            })[];
        };
        uiSchema: {};
    };
    'An array of different type items': {
        value: ({
            num: number;
            text?: undefined;
        } | {
            text: string;
            num?: undefined;
        })[];
        schema: {
            type: string;
            items: {
                type: string;
                anyOf: ({
                    type: string;
                    title: string;
                    properties: {
                        text: {
                            type: string;
                            format: string;
                        };
                        num?: undefined;
                    };
                } | {
                    type: string;
                    properties: {
                        num: {
                            type: string;
                            title: string;
                        };
                        text?: undefined;
                    };
                    title?: undefined;
                })[];
            };
        };
        uiSchema: {};
    };
};
export default jsonDataExamples;
