"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.itemsExample = void 0;
var react_1 = __importDefault(require("react"));
var _1 = require(".");
var enzyme_1 = require("enzyme");
var Button_1 = require("../Button");
var Provider_1 = require("../Provider");
var Input_1 = require("../Input");
var SimpleConfirmationModal_1 = require("../../internal/SimpleConfirmationModal");
var useTranslation_1 = require("../../hooks/useTranslation");
exports.itemsExample = [
    {
        id: 1,
        name: 'item-with-tag-1',
        tag_field: [
            {
                tag_key: 'tag1-key',
                value: 'tag-value',
            },
            {
                tag_key: 'tag2-key',
                value: 'tag3-value',
            },
            {
                tag_key: 'tag3-key',
                value: 'tag3-value',
            },
        ],
    },
    {
        id: 2,
        name: 'item-with-tag-2',
        tag_field: [
            {
                tag_key: 'tag1-key',
                value: 'tag-value',
            },
            {
                tag_key: 'tag2-key',
                value: 'tag3-value',
            },
        ],
    },
];
var TagManagement = function () {
    var _a = react_1.default.useState(false), isModalOpen = _a[0], setIsModalOpen = _a[1];
    var t = useTranslation_1.useTranslation().t;
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(Button_1.Button, { onClick: function () { return setIsModalOpen(true); }, primary: true }, t('labels.tags')),
        isModalOpen && (react_1.default.createElement(_1.TagManagementModal, __assign({}, props, { cancel: function () { return setIsModalOpen(false); }, done: function () { return setIsModalOpen(false); } })))));
};
var props = {
    items: exports.itemsExample,
    itemType: 'tag',
    titleField: 'name',
    tagField: 'tag_field',
};
describe('TagManagement component', function () {
    it('Should render the TagManagement component', function () {
        var component = enzyme_1.mount(react_1.default.createElement(Provider_1.Provider, null,
            react_1.default.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button_1.Button) && typeof node.prop('children') === 'string'; });
        expect(button.text()).toEqual('Tags');
    });
    it('Should render the TagManagement modal component', function () {
        var component = enzyme_1.mount(react_1.default.createElement(Provider_1.Provider, null,
            react_1.default.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button_1.Button) && typeof node.prop('children') === 'string'; });
        button.simulate('click');
        var modal = component.find(_1.TagManagementModal);
        expect(modal).toHaveLength(1);
    });
    it('Should render the TagManagement overwrite alert modal component', function () {
        var component = enzyme_1.mount(react_1.default.createElement(Provider_1.Provider, null,
            react_1.default.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button_1.Button) && typeof node.prop('children') === 'string'; });
        button.simulate('click');
        var modal = component.find(_1.TagManagementModal);
        var keyInput = modal.find(Input_1.Input).first();
        var valueInput = modal.find(Input_1.Input).last();
        keyInput
            .find('input')
            .simulate('change', { target: { value: 'tag3-key' } });
        valueInput
            .find('input')
            .simulate('change', { target: { value: 'running-test' } });
        var addTagButton = modal.findWhere(function (node) { return node.is(Button_1.Button) && node.text() === 'Add tag'; });
        addTagButton.simulate('click');
        var alertModal = component.find(SimpleConfirmationModal_1.SimpleConfirmationModal);
        expect(alertModal.find('h3').text()).toBe('Adding this would overwrite tags on tag');
    });
    it('Should disable Add tag button if tag key is empty', function () {
        var component = enzyme_1.mount(react_1.default.createElement(Provider_1.Provider, null,
            react_1.default.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button_1.Button) && typeof node.prop('children') === 'string'; });
        button.simulate('click');
        var modal = component.find(_1.TagManagementModal);
        var addTagButton = modal.findWhere(function (node) { return node.is(Button_1.Button) && node.text() === 'Add tag'; });
        expect(addTagButton.prop('disabled')).toBe(true);
    });
});
