"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var enzyme_1 = require("enzyme");
var noop_1 = __importDefault(require("lodash/noop"));
var react_1 = __importDefault(require("react"));
var __1 = require("../../");
describe('Textarea component', function () {
    it('should accept and display a value', function () {
        var value = 'lorem ipsum dolor sit amet';
        var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(__1.Textarea, { value: value, onChange: noop_1.default })));
        expect(component.text()).toEqual(value);
    });
    describe('autoRows property', function () {
        var lines = [
            'lorem ipsum dolor sit amet',
            'consectetur adipiscing elit',
            'mauris dui nulla',
            'volutpat et commodo eu',
            'pellentesque a risus',
            'vivamus iaculis consectetur nulla vel laoreet',
        ];
        var value = lines.join('\n');
        it('should resize the textarea to match the content', function () {
            var component = enzyme_1.mount(react_1.default.createElement(function (props) { return (react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Textarea, __assign({}, props)))); }, { autoRows: true, value: value, onChange: noop_1.default }));
            expect(component.text()).toEqual(value);
            var rows = component.find('textarea').prop('rows');
            expect(rows).toEqual(lines.length);
            var newLines = lines.slice();
            newLines.push('duis fermentum cursus accumsan');
            var newValue = newLines.join('\n');
            component.setProps({ value: newValue });
            component.update();
            expect(component.text()).toEqual(newValue);
            var newRows = component.find('textarea').prop('rows');
            expect(newRows).toEqual(newLines.length);
        });
        it('should respect the maxRows property', function () {
            var maxRows = Math.ceil(lines.length / 2);
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Textarea, { autoRows: true, maxRows: maxRows, value: value, onChange: noop_1.default })));
            expect(component.text()).toEqual(value);
            var rows = component.find('textarea').prop('rows');
            expect(rows).toEqual(maxRows);
        });
        it('should respect the minRows property', function () {
            var minRows = lines.length * 2;
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Textarea, { autoRows: true, minRows: minRows, value: value, onChange: noop_1.default })));
            expect(component.text()).toEqual(value);
            var rows = component.find('textarea').prop('rows');
            expect(rows).toEqual(minRows);
        });
    });
    describe('maxRows property', function () {
        it('should not allow a row property larger than maxRows', function () {
            var maxRows = 4;
            var rows = maxRows * 2;
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Textarea, { rows: rows, maxRows: maxRows })));
            var realRows = component.find('textarea').prop('rows');
            expect(realRows).toEqual(maxRows);
        });
    });
    describe('minRows property', function () {
        it('should not allow a row property smaller than minRows', function () {
            var minRows = 8;
            var rows = Math.ceil(minRows / 2);
            var component = enzyme_1.mount(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(__1.Textarea, { rows: rows, minRows: minRows })));
            var realRows = component.find('textarea').prop('rows');
            expect(realRows).toEqual(minRows);
        });
    });
});
