"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PersistentFilters = void 0;
var React = __importStar(require("react"));
var filter_1 = __importDefault(require("lodash/filter"));
var qs_1 = __importDefault(require("qs"));
var Filters_1 = require("../../../components/Filters");
var SchemaSieve_1 = require("../../../components/Filters/SchemaSieve");
var utils_1 = require("../../../utils");
var isListQueryStringFilterRule = function (rule) {
    return rule != null &&
        typeof rule === 'object' &&
        !!rule.n &&
        typeof rule.n === 'string' &&
        ((!!rule.o && typeof rule.o === 'string') ||
            !!rule.v);
};
var isQueryStringFilterRuleset = function (rule) {
    return Array.isArray(rule) &&
        !!(rule === null || rule === void 0 ? void 0 : rule.length) && (rule === null || rule === void 0 ? void 0 : rule.every(isListQueryStringFilterRule));
};
var listFilterQuery = function (schema, rules) {
    var queryStringFilters = rules.map(function (filter) {
        var flatSchema = SchemaSieve_1.flattenSchema(schema);
        var flattenFilter = SchemaSieve_1.flattenSchema(filter);
        var signatures = SchemaSieve_1.decodeFilter(flatSchema, flattenFilter);
        return signatures.map(function (_a) {
            var field = _a.field, operator = _a.operator, value = _a.value;
            return ({
                n: field,
                o: operator,
                v: value,
            });
        });
    });
    return qs_1.default.stringify(queryStringFilters);
};
var loadRulesFromUrl = function (searchLocation, schema) {
    if (!searchLocation) {
        return [];
    }
    var parsed = qs_1.default.parse(searchLocation, { ignoreQueryPrefix: true }) || {};
    var rules = filter_1.default(parsed, isQueryStringFilterRuleset).map(function (rules) {
        if (!Array.isArray(rules)) {
            rules = [rules];
        }
        var signatures = rules.map(function (_a) {
            var n = _a.n, o = _a.o, v = _a.v;
            return ({
                field: n,
                operator: o,
                value: v,
            });
        });
        if (signatures[0].operator === SchemaSieve_1.FULL_TEXT_SLUG) {
            return SchemaSieve_1.createFullTextSearchFilter(schema, signatures[0].value);
        }
        return SchemaSieve_1.createFilter(schema, signatures);
    });
    return rules;
};
exports.PersistentFilters = function (_a) {
    var _b, _c;
    var schema = _a.schema, views = _a.views, filters = _a.filters, onViewsUpdate = _a.onViewsUpdate, onFiltersUpdate = _a.onFiltersUpdate, viewsRestorationKey = _a.viewsRestorationKey, history = _a.history, onSearch = _a.onSearch, otherProps = __rest(_a, ["schema", "views", "filters", "onViewsUpdate", "onFiltersUpdate", "viewsRestorationKey", "history", "onSearch"]);
    var storedViews = React.useMemo(function () { var _a; return (_a = utils_1.getFromLocalStorage(viewsRestorationKey)) !== null && _a !== void 0 ? _a : []; }, [viewsRestorationKey]);
    var locationSearch = (_c = (_b = history === null || history === void 0 ? void 0 : history.location) === null || _b === void 0 ? void 0 : _b.search) !== null && _c !== void 0 ? _c : '';
    var storedFilters = React.useMemo(function () {
        return loadRulesFromUrl(locationSearch, schema);
    }, [locationSearch, schema]);
    React.useEffect(function () {
        if (!(views === null || views === void 0 ? void 0 : views.length) && storedViews.length && onViewsUpdate) {
            onViewsUpdate(storedViews);
        }
    }, []);
    var updateUrl = function (filters) {
        var _a;
        var pathname = window.location.pathname;
        (_a = history === null || history === void 0 ? void 0 : history.replace) === null || _a === void 0 ? void 0 : _a.call(history, {
            pathname: pathname,
            search: listFilterQuery(schema, filters),
        });
    };
    React.useEffect(function () {
        onFiltersUpdate === null || onFiltersUpdate === void 0 ? void 0 : onFiltersUpdate(storedFilters);
    }, [storedFilters]);
    var viewsUpdate = function (views) {
        utils_1.setToLocalStorage(viewsRestorationKey, views);
        if (onViewsUpdate) {
            onViewsUpdate(views);
        }
    };
    var filtersUpdate = function (filters) {
        updateUrl(filters);
        if (onFiltersUpdate) {
            onFiltersUpdate(filters);
        }
    };
    return (React.createElement(Filters_1.Filters, __assign({ schema: schema, filters: filters !== null && filters !== void 0 ? filters : storedFilters, views: views !== null && views !== void 0 ? views : storedViews, onFiltersUpdate: filtersUpdate, onViewsUpdate: viewsUpdate }, otherProps, { onSearch: onSearch })));
};
