import React from 'react';
import { AutoUIAction, AutoUIModel, AutoUIBaseResource, AutoUIContext, AutoUIRawModel, autoUIJsonSchemaPick, Priorities } from './schemaOps';
import { ResourceTagModelService } from '../../components/TagManagementModal/tag-management-service';
import { Format } from '../../components/Renderer/types';
import { Dictionary } from '../../common-types';
import { LensTemplate } from './Lenses';
import type { JSONSchema7 as JSONSchema } from 'json-schema';
import { BoxProps } from '../../components/Box';
import { autoUIAddToSchema, autoUIDefaultPermissions, autoUIGetModelForCollection, autoUIRunTransformers } from './models/helpers';
import { autoUIGetDisabledReason } from './utils';
import { TableColumn } from '../../components/Table';
export interface AutoUIProps<T> extends Omit<BoxProps, 'onChange'> {
    model: AutoUIModel<T>;
    data: T[] | T | undefined;
    formats?: Format[];
    actions?: Array<AutoUIAction<T>>;
    sdk?: {
        tags?: ResourceTagModelService;
    };
    customSort?: Dictionary<(a: T, b: T) => number>;
    getBaseUrl?: (entry: T) => string;
    refresh?: () => void;
    onEntityClick?: (entry: T, event: React.MouseEvent<HTMLAnchorElement, MouseEvent>) => void;
    onChange?: (changes: {
        filters?: JSONSchema[];
    }) => void;
    customLenses?: LensTemplate[];
    lensContext?: object;
}
export declare const AutoUI: <T extends AutoUIBaseResource<T>>({ model: modelRaw, data, formats, actions, sdk, customSort, refresh, getBaseUrl, onEntityClick, onChange, customLenses, lensContext, ...boxProps }: AutoUIProps<T>) => JSX.Element;
export { autoUIRunTransformers, autoUIDefaultPermissions, autoUIGetModelForCollection, autoUIAddToSchema, AutoUIAction, AutoUIBaseResource, AutoUIRawModel, AutoUIModel, autoUIJsonSchemaPick, autoUIGetDisabledReason, };
export declare type AutoUIEntityPropertyDefinition<T> = Required<Pick<TableColumn<T>, 'title' | 'field' | 'key' | 'selected' | 'sortable' | 'render'>> & {
    type: string;
    priority: string;
};
export declare const getColumnsFromSchema: <T extends AutoUIBaseResource<T>>({ schema, idField, tagField, customSort, priorities, formats, }: {
    schema: JSONSchema;
    idField: string;
    tagField: string | undefined;
    customSort?: Dictionary<(a: T, b: T) => number> | undefined;
    priorities?: Priorities<T> | undefined;
    formats?: Format[] | undefined;
}) => AutoUIEntityPropertyDefinition<T>[];
