"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPropertyRefScheme = exports.autoUIAddToSchema = exports.autoUIGetModelForCollection = exports.autoUIAdaptRefScheme = exports.autoUIRunTransformers = exports.isJson = exports.autoUIDefaultPermissions = void 0;
var isEmpty_1 = __importDefault(require("lodash/isEmpty"));
var schemaOps_1 = require("../schemaOps");
var get_1 = __importDefault(require("lodash/get"));
exports.autoUIDefaultPermissions = {
    read: [],
    create: [],
    update: [],
    delete: false,
};
exports.isJson = function (str) {
    try {
        JSON.parse(str);
    }
    catch (err) {
        return false;
    }
    return true;
};
exports.autoUIRunTransformers = function (data, transformers, context) {
    if (!data) {
        return data;
    }
    if (!transformers || isEmpty_1.default(transformers)) {
        return data;
    }
    var transformEntry = function (entry) {
        return Object.entries(transformers).forEach(function (_a) {
            var fieldName = _a[0], transformer = _a[1];
            entry[fieldName] = transformer(entry, context);
        });
    };
    var mutatedData = data;
    if (Array.isArray(mutatedData)) {
        mutatedData.forEach(transformEntry);
    }
    else {
        transformEntry(mutatedData);
    }
    return mutatedData;
};
exports.autoUIAdaptRefScheme = function (field, property) {
    var _a, _b, _c;
    if (!property || field == null) {
        return null;
    }
    if (typeof property === 'boolean' ||
        !((_a = property.description) === null || _a === void 0 ? void 0 : _a.includes('x-ref-scheme')) ||
        !exports.isJson(property.description) ||
        !!property.format) {
        return field;
    }
    var refScheme = exports.getPropertyRefScheme(property);
    var transformed = (_b = (Array.isArray(field) && field.length <= 1 ? field[0] : field)) !== null && _b !== void 0 ? _b : null;
    if (refScheme) {
        return (_c = get_1.default(transformed, refScheme)) !== null && _c !== void 0 ? _c : null;
    }
    return transformed;
};
exports.autoUIGetModelForCollection = function (model, context) {
    var accessRole = context === null || context === void 0 ? void 0 : context.accessRole;
    var schema = !!model.priorities
        ? schemaOps_1.autoUIJsonSchemaPick(model.schema, __spreadArrays(model.priorities.primary, model.priorities.secondary, model.priorities.tertiary))
        : model.schema;
    return __assign(__assign({}, model), { permissions: (accessRole != null && model.permissions[accessRole]) ||
            model.permissions['default'], schema: schema });
};
exports.autoUIAddToSchema = function (schema, schemaProperty, property, value) {
    var _a, _b;
    var _c;
    return __assign(__assign({}, schema), { properties: __assign(__assign({}, schema.properties), (_a = {}, _a[schemaProperty] = __assign(__assign({}, (_c = schema.properties) === null || _c === void 0 ? void 0 : _c[schemaProperty]), (_b = {}, _b[property] = value, _b)), _a)) });
};
exports.getPropertyRefScheme = function (schemaValue) {
    return typeof schemaValue !== 'boolean' &&
        !!schemaValue.description &&
        exports.isJson(schemaValue.description)
        ? JSON.parse(schemaValue.description)['x-ref-scheme']
        : null;
};
