"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.onClickOutOrEsc = exports.getSelected = exports.getSortingFunction = exports.autoUIGetDisabledReason = exports.getCreateDisabledReason = exports.getTagsDisabledReason = exports.ObjectFromEntries = exports.findInObject = exports.history = void 0;
var types_1 = require("../../components/Renderer/types");
var utils_1 = require("../../utils");
var castArray_1 = __importDefault(require("lodash/castArray"));
var history_1 = require("history");
var helpers_1 = require("./models/helpers");
var get_1 = __importDefault(require("lodash/get"));
exports.history = history_1.createBrowserHistory();
exports.findInObject = function (obj, key) {
    var result;
    for (var property in obj) {
        if (obj.hasOwnProperty(property)) {
            if (property === key) {
                return obj[key];
            }
            else if (typeof obj[property] === 'object') {
                result = exports.findInObject(obj[property], key);
                if (typeof result !== 'undefined') {
                    return result;
                }
            }
        }
    }
};
exports.ObjectFromEntries = function (entries) {
    var obj = {};
    for (var _i = 0, entries_1 = entries; _i < entries_1.length; _i++) {
        var _a = entries_1[_i], key = _a[0], value = _a[1];
        obj[key] = value;
    }
    return obj;
};
exports.getTagsDisabledReason = function (selected, tagField, t) {
    if (selected.length === 0) {
        return t('info.no_selected');
    }
    var lacksPermissionsOnSelected = selected.some(function (entry) {
        return (!entry.__permissions.delete &&
            !entry.__permissions.create.includes(tagField) &&
            !entry.__permissions.update.includes(tagField));
    });
    if (lacksPermissionsOnSelected) {
        return t('info.edit_tag_no_permissions', { resource: 'item' });
    }
    return false;
};
exports.getCreateDisabledReason = function (permissions, hasOngoingAction, t) {
    var _a;
    if (hasOngoingAction) {
        return t('info.ongoing_action_wait');
    }
    if (!((_a = permissions.create) === null || _a === void 0 ? void 0 : _a.length)) {
        return t('info.create_item_no_permissions', { resource: 'item' });
    }
};
exports.autoUIGetDisabledReason = function (selected, hasOngoingAction, actionType, t) {
    if (selected.length === 0) {
        return t('info.no_selected');
    }
    if (hasOngoingAction) {
        return t('info.ongoing_action_wait');
    }
    if (!actionType) {
        return;
    }
    var lacksPermissionsOnSelected = selected.some(function (entry) {
        return (!entry.__permissions[actionType] ||
            (Array.isArray(entry.__permissions[actionType]) &&
                entry.__permissions[actionType].length <= 0));
    });
    if (lacksPermissionsOnSelected) {
        return t('info.update_item_no_permissions', {
            action: actionType,
            resource: 'item',
        });
    }
};
var sortFn = function (a, b, ref) {
    var _a, _b;
    var aa = (_a = get_1.default(a, ref)) !== null && _a !== void 0 ? _a : '';
    var bb = (_b = get_1.default(b, ref)) !== null && _b !== void 0 ? _b : '';
    if (typeof aa === 'string' && typeof bb === 'string') {
        return aa.toLowerCase().localeCompare(bb.toLowerCase());
    }
    return utils_1.diff(aa, bb);
};
exports.getSortingFunction = function (schemaKey, schemaValue) {
    var types = castArray_1.default(schemaValue.type);
    var refScheme = helpers_1.getPropertyRefScheme(schemaValue);
    if (types.includes(types_1.JsonTypes.string)) {
        return function (a, b) { return sortFn(a, b, schemaKey); };
    }
    if (types.includes(types_1.JsonTypes.object) && refScheme) {
        return function (a, b) { return sortFn(a, b, __spreadArrays([schemaKey], [refScheme])); };
    }
    if (types.includes(types_1.JsonTypes.array) && refScheme) {
        return function (a, b) { return sortFn(a, b, __spreadArrays([schemaKey, 0], [refScheme])); };
    }
    return function (a, b) { return utils_1.diff(a[schemaKey], b[schemaKey]); };
};
exports.getSelected = function (key, priorities) {
    if (!priorities) {
        return true;
    }
    return ((priorities === null || priorities === void 0 ? void 0 : priorities.primary.includes(key)) || (priorities === null || priorities === void 0 ? void 0 : priorities.secondary.includes(key)));
};
exports.onClickOutOrEsc = function (wrapper, callback) {
    var handleClickOutside = function (event) {
        if (!wrapper.contains(event.target)) {
            handler();
        }
    };
    var handleEsc = function (event) {
        if (event.key === 'Escape') {
            handler();
        }
    };
    var handler = function () {
        callback();
        if (document.activeElement instanceof HTMLElement) {
            document.activeElement.blur();
        }
        document.removeEventListener('mousedown', handleClickOutside);
        document.removeEventListener('keydown', handleEsc);
    };
    document.addEventListener('mousedown', handleClickOutside);
    document.addEventListener('keydown', handleEsc);
};
