"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decoratorPlugin = void 0;
var unist_util_visit_parents_1 = __importDefault(require("unist-util-visit-parents"));
var regexp_match_indices_1 = __importDefault(require("regexp-match-indices"));
var splitTextIntoNodes = function (text, decorator) {
    decorator.match.lastIndex = 0;
    var nodes = [];
    var lastIndex = 0;
    while (true) {
        var result = regexp_match_indices_1.default(decorator.match, text);
        if (!result) {
            break;
        }
        var captureGroupIndex = decorator.captureGroupIndex || 0;
        var _a = result.indices[captureGroupIndex], captureGroupStartIndex = _a[0], captureGroupEndIndex = _a[1];
        var matchedString = text.slice(captureGroupStartIndex, captureGroupEndIndex);
        nodes.push({
            type: 'text',
            value: text.substring(lastIndex, captureGroupStartIndex),
        }, {
            type: 'element',
            tagName: decorator.component,
            properties: decorator.properties,
            children: [
                {
                    type: 'text',
                    value: matchedString,
                },
            ],
        });
        lastIndex = captureGroupEndIndex;
        if (!decorator.match.global) {
            break;
        }
    }
    if (text.length > lastIndex) {
        nodes.push({
            type: 'text',
            value: text.substring(lastIndex),
        });
    }
    decorator.match.lastIndex = 0;
    return nodes;
};
var isLiteralNode = function (node) {
    return node.type === 'text';
};
var isElementNode = function (node) {
    return node.type === 'element';
};
var isCodeBlock = function (node) {
    return isElementNode(node) && node.tagName === 'code';
};
exports.decoratorPlugin = function (options) {
    var _a;
    if (!((_a = options.decorators) === null || _a === void 0 ? void 0 : _a.length)) {
        return;
    }
    var visitor = function (node, parents) {
        if (!isLiteralNode(node) || typeof node.value !== 'string') {
            return;
        }
        var value = node.value;
        var decorator = options.decorators.find(function (entry) {
            return entry.match.test(value);
        });
        if (!decorator) {
            return;
        }
        if (decorator.ignoreCodeBlock !== false && parents.some(isCodeBlock)) {
            return unist_util_visit_parents_1.default.SKIP;
        }
        var element = node;
        element.type = 'element';
        element.tagName = 'span';
        element.children = splitTextIntoNodes(node.value, decorator);
        return unist_util_visit_parents_1.default.SKIP;
    };
    return function (tree) {
        unist_util_visit_parents_1.default(tree, visitor, true);
    };
};
