"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationInstructions = exports.getUserOs = exports.osTitles = void 0;
var invert_1 = __importDefault(require("lodash/invert"));
var has_1 = __importDefault(require("lodash/has"));
var React = __importStar(require("react"));
var Flex_1 = require("../../components/Flex");
var Box_1 = require("../../components/Box");
var Txt_1 = require("../../components/Txt");
var Tabs_1 = require("../../components/Tabs");
var Link_1 = require("../../components/Link");
var List_1 = require("../../components/List");
var Heading_1 = require("../../components/Heading");
var useTranslation_1 = require("../../hooks/useTranslation");
var utils_1 = require("./utils");
exports.osTitles = {
    windows: 'Windows',
    osx: 'MacOS',
    linux: 'Linux',
    unknown: 'Unknown',
};
exports.getUserOs = function () {
    var platform = window.navigator.platform.toLowerCase();
    if (platform.includes('win')) {
        return 'windows';
    }
    if (platform.includes('mac')) {
        return 'osx';
    }
    if (platform.includes('x11') || platform.includes('linux')) {
        return 'linux';
    }
    return 'unknown';
};
var osTabIndices = {
    windows: 0,
    osx: 1,
    linux: 2,
    unknown: 0,
};
var osTabNames = invert_1.default(osTabIndices);
exports.ApplicationInstructions = React.memo(function (_a) {
    var _b;
    var deviceType = _a.deviceType, templateData = _a.templateData;
    var t = useTranslation_1.useTranslation().t;
    var _c = React.useState(exports.getUserOs()), currentOs = _c[0], setCurrentOs = _c[1];
    var instructions = deviceType === null || deviceType === void 0 ? void 0 : deviceType.instructions;
    var hasOsSpecificInstructions = !Array.isArray(instructions);
    var normalizedOs = currentOs === 'unknown' ? 'linux' : currentOs;
    React.useEffect(function () {
        if (hasOsSpecificInstructions && instructions) {
            var oses = Object.keys(instructions);
            if (!oses.includes(currentOs) && oses.length > 0) {
                setCurrentOs(oses[0]);
            }
        }
    }, [currentOs, setCurrentOs, instructions, hasOsSpecificInstructions]);
    if (!deviceType || !instructions) {
        return React.createElement(Txt_1.Txt, null, t('no_data.no_instructions_found'));
    }
    var interpolatedInstructions = (hasOsSpecificInstructions
        ? instructions[normalizedOs]
        : instructions).map(function (instruction) {
        return utils_1.interpolateMustache(templateData, instruction.replace(/<a/, '<a target="_blank"'));
    });
    var hasConfigDownloadOnly = ((_b = deviceType.yocto) === null || _b === void 0 ? void 0 : _b.deployArtifact) === 'docker-image';
    var finalInstructions = __spreadArrays([
        hasConfigDownloadOnly
            ? t('actions.use_form_to_download_configuration')
            : t('actions.use_from_to_configure_and_download')
    ], interpolatedInstructions, [
        t('actions_messages.appearance_device_explanation'),
    ]);
    return (React.createElement(Flex_1.Flex, { flexDirection: "column", alignItems: "flex-start" },
        React.createElement(Heading_1.Heading.h5, { mb: 3 }, t('labels.instructions')),
        hasOsSpecificInstructions && (React.createElement(Box_1.Box, { mb: 3 },
            React.createElement(Tabs_1.Tabs, { activeIndex: osTabIndices[currentOs], onActive: function (index) { return setCurrentOs(osTabNames[index.toString()]); } }, Object.keys(instructions).map(function (os) {
                return React.createElement(Tabs_1.Tab, { key: os, title: exports.osTitles[os] });
            })))),
        React.createElement(InstructionsList, { instructions: finalInstructions }),
        React.createElement(Flex_1.Flex, { mt: 4 },
            React.createElement(Txt_1.Txt, null,
                "For more details please refer to our",
                ' ',
                React.createElement(Link_1.Link, { blank: true, href: "https://www.balena.io/docs/learn/getting-started/" + deviceType.slug + "/nodejs/" }, "Getting Started Guide"),
                "."))));
});
var InstructionsItem = function (props) {
    var node = props.node;
    var hasChildren = has_1.default(node, 'children');
    var text = null;
    if (typeof node === 'string') {
        text = node;
    }
    if (node === null || node === void 0 ? void 0 : node.text) {
        text = node.text;
    }
    return (React.createElement("span", null,
        React.createElement("span", { dangerouslySetInnerHTML: { __html: text } }),
        hasChildren && (React.createElement(List_1.List, null, node.children.map(function (item) {
            return React.createElement(InstructionsItem, { node: item });
        })))));
};
var InstructionsList = function (props) {
    var instructions = props.instructions;
    return (React.createElement(List_1.List, { ordered: true, fontSize: 14 }, instructions.map(function (item) {
        return React.createElement(InstructionsItem, { key: item, node: item });
    })));
};
