import type { JSONSchema7 as JSONSchema } from 'json-schema';
import * as React from 'react';
import { DataTypeEditProps } from '../Filters';
import { InputProps } from '../Input';
import { TextareaProps } from '../Textarea';
import { SelectProps } from '../Select';
export declare const operators: {
    contains: {
        getLabel: (_s: JSONSchema) => string;
    };
    not_contains: {
        getLabel: (_s: JSONSchema) => string;
    };
};
declare type OperatorSlug = keyof typeof operators;
interface StringFilter extends JSONSchema {
    title: OperatorSlug;
    properties?: {
        [k: string]: {
            not?: {
                contains: {
                    const: string;
                };
            };
            contains?: {
                const: string;
            };
        };
    };
    anyOf?: Array<{
        properties?: {
            [k: string]: {
                not?: {
                    contains: {
                        const: string;
                    };
                };
                contains?: {
                    const: string;
                };
            };
        };
    }>;
}
export declare const decodeFilter: (filter: StringFilter) => {
    field: string;
    operator: OperatorSlug;
    value: string;
} | null;
export declare const createFilter: (field: string, operator: OperatorSlug, value: any, schema: JSONSchema) => JSONSchema;
interface OneOf {
    const: string | boolean | number;
    title: string;
}
export declare const Edit: ({ onUpdate, slim, ...props }: DataTypeEditProps & import("../Textarea").InternalTextareaProps & import("../..").StyledSystemProps & import("../..").Tooltip & import("../Input").InternalInputProps & {
    ref?: ((instance: HTMLInputElement | null) => void) | React.RefObject<HTMLInputElement | null> | null | undefined;
} & Pick<SelectProps<OneOf>, "replace" | "disabled" | "open" | "hidden" | "dir" | "p" | "slot" | "style" | "title" | "invalid" | "m" | "color" | "icon" | "tooltip" | "clear" | "padding" | "multiple" | "alignSelf" | "backgroundColor" | "display" | "fontSize" | "height" | "marginBottom" | "marginLeft" | "marginRight" | "marginTop" | "maxHeight" | "maxWidth" | "minHeight" | "minWidth" | "paddingBottom" | "paddingLeft" | "paddingRight" | "paddingTop" | "translate" | "width" | "gridArea" | "margin" | "children" | "name" | "className" | "id" | "lang" | "role" | "tabIndex" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "css" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "contentEditable" | "contextMenu" | "draggable" | "placeholder" | "spellCheck" | "radioGroup" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "value" | "onClose" | "mt" | "mb" | "ml" | "mr" | "my" | "mx" | "pt" | "pr" | "pb" | "pl" | "px" | "py" | "messages" | "a11yTitle" | "dropHeight" | "dropProps" | "plain" | "closeOnChange" | "disabledKey" | "dropAlign" | "dropTarget" | "labelKey" | "onMore" | "onOpen" | "onSearch" | "options" | "searchPlaceholder" | "valueLabel" | "valueKey" | "emptySearchMessage" | "bg" | "emphasized"> & {
    slim?: boolean | undefined;
}) => JSX.Element;
export declare const getFilter: (schema: JSONSchema, value: string) => {
    minItems: number;
    items: {
        properties: {
            [key: string]: import("json-schema").JSONSchema7Definition;
        };
    };
    contains?: undefined;
} | {
    contains: {
        const: string | number;
    };
    minItems?: undefined;
    items?: undefined;
};
export {};
