import { __assign, __rest } from "tslib";
import * as React from 'react';
import { randomString, regexEscape } from '../../utils';
import { Input } from '../Input';
import { Textarea } from '../Textarea';
import { getJsonDescription } from './utils';
import { Select } from '../Select';
import { findInObject } from '../../extra/AutoUI/utils';
export var operators = {
    contains: {
        getLabel: function (_s) { return 'contains'; },
    },
    not_contains: {
        getLabel: function (_s) { return 'does not contain'; },
    },
};
export var decodeFilter = function (filter) {
    var _a;
    var operator = filter.title;
    var properties = findInObject(filter, 'properties');
    var firstPropKey = Object.keys(properties)[0];
    var field = firstPropKey;
    var value = (_a = findInObject(filter, 'const')) !== null && _a !== void 0 ? _a : findInObject(filter, 'pattern');
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: randomString(),
        title: operator,
        description: getJsonDescription(title || field, operators[operator].getLabel(schema), value),
        type: 'object',
    };
    var filter = getFilter(schema, value);
    if (operator === 'contains') {
        return Object.assign(base, {
            properties: (_a = {},
                _a[field] = __assign({ type: 'array' }, filter),
                _a),
            required: [field],
        });
    }
    if (operator === 'not_contains') {
        return Object.assign(base, {
            anyOf: [
                {
                    properties: (_b = {},
                        _b[field] = {
                            type: 'array',
                            not: __assign({}, filter),
                        },
                        _b),
                },
                {
                    properties: (_c = {},
                        _c[field] = {
                            type: 'null',
                        },
                        _c),
                },
            ],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var onUpdate = _a.onUpdate, slim = _a.slim, props = __rest(_a, ["onUpdate", "slim"]);
    var schemaItems = props.schema.items;
    if (schemaItems === null || schemaItems === void 0 ? void 0 : schemaItems.oneOf) {
        return (React.createElement(Select, __assign({}, props, { options: schemaItems.oneOf || [], valueKey: "const", labelKey: "title", value: (schemaItems.oneOf || []).find(function (x) { return x.const === props.value; }), onChange: function (_a) {
                var option = _a.option;
                return onUpdate(option.const.toString());
            } })));
    }
    if (slim) {
        return (React.createElement(Input, __assign({ onChange: function (e) {
                return onUpdate(e.currentTarget.value);
            } }, props)));
    }
    return (React.createElement(Textarea, __assign({ onChange: function (e) {
            return onUpdate(e.currentTarget.value);
        } }, props)));
};
export var getFilter = function (schema, value) {
    if (!!(schema === null || schema === void 0 ? void 0 : schema.items) &&
        typeof schema.items !== 'boolean' &&
        'properties' in schema.items &&
        !!schema.items.properties) {
        return {
            minItems: 1,
            items: {
                properties: Object.keys(schema.items.properties).reduce(function (props, propKey) {
                    props[propKey] = {
                        regexp: {
                            pattern: regexEscape(value),
                            flags: 'i',
                        },
                    };
                    return props;
                }, {}),
            },
        };
    }
    return {
        contains: {
            const: Number.isNaN(parseInt(value, 10)) ? value : Number(value),
        },
    };
};
