import { __spreadArrays } from "tslib";
import { getDataModel } from '../../components/DataTypes';
import { normalizeDateTime } from '../../components/DataTypes/date-time-helpers';
var expectMatchesKeys = function (data, keys) {
    return expect(Object.keys(data).sort()).toEqual(keys.sort());
};
describe('DataTypes', function () {
    describe('.getDataModel()', function () {
        var dataModelKeys = ['operators', 'createFilter', 'decodeFilter'];
        it('should return null if provided with a falsey value as the schema parameter', function () {
            expect(getDataModel()).toBe(null);
            expect(getDataModel(undefined)).toBe(null);
            expect(getDataModel(0)).toBe(null);
            expect(getDataModel(false)).toBe(null);
            expect(getDataModel(null)).toBe(null);
            expect(getDataModel('')).toBe(null);
        });
        it('should return null for unknown types', function () {
            var schema = {
                type: 'foobar',
            };
            expect(getDataModel(schema)).toBe(null);
        });
        it('should return a model for string types', function () {
            var schema = {
                type: 'string',
            };
            expectMatchesKeys(getDataModel(schema), dataModelKeys);
        });
        it('should return a model for string | null types', function () {
            var schema = {
                type: ['string', 'null'],
            };
            expectMatchesKeys(getDataModel(schema), dataModelKeys);
        });
        it('should return a model for date-time formatted string types', function () {
            var schema = {
                type: 'string',
                format: 'date-time',
            };
            expectMatchesKeys(getDataModel(schema), dataModelKeys);
        });
        it('should return a model for object types', function () {
            var schema = {
                type: 'object',
            };
            expectMatchesKeys(getDataModel(schema), __spreadArrays(['Edit'], dataModelKeys));
        });
        it('should return a model for boolean types', function () {
            var schema = {
                type: 'boolean',
            };
            expectMatchesKeys(getDataModel(schema), __spreadArrays(dataModelKeys, ['uiSchema']));
        });
        it('should return a model for number types', function () {
            var schema = {
                type: 'number',
            };
            expectMatchesKeys(getDataModel(schema), dataModelKeys);
        });
    });
    describe('normalizeDateTime', function () {
        it('rejects invalid date', function () {
            expect(normalizeDateTime('wrong time')).toEqual('Invalid date');
            expect(normalizeDateTime('')).toEqual('Invalid date');
        });
        it('formats the date correctly', function () {
            var tzFormat = function (stamp) {
                return new Date(stamp).toISOString().replace(/\.000/, '');
            };
            expect(normalizeDateTime('2017-01-01T08:49:26Z')).toEqual(tzFormat('2017-01-01T08:49:26Z'));
            expect(normalizeDateTime('2018-03-26T11:43')).toEqual(tzFormat('2018-03-26T11:43'));
            expect(normalizeDateTime('Sun, 01 Jan 2017 08:49:26 +0000')).toEqual(tzFormat('2017-01-01T08:49:26Z'));
        });
    });
});
