import { __assign, __makeTemplateObject, __spreadArrays } from "tslib";
import { faTimes } from '@fortawesome/free-solid-svg-icons/faTimes';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import map from 'lodash/map';
import debounce from 'lodash/debounce';
import React, { useState } from 'react';
import styled from 'styled-components';
import { Button } from '../Button';
import { Box } from '../Box';
import { Flex } from '../Flex';
import { Modal } from '../Modal';
import { Select } from '../Select';
import { Txt } from '../Txt';
import * as SchemaSieve from './SchemaSieve';
import { Form } from '../Form';
import { getDataModel } from '../DataTypes';
var defaultFilterCompareFn = function (a, b) {
    return a.title.toLowerCase().localeCompare(b.title.toLowerCase());
};
var FilterInput = function (_a) {
    var schema = _a.schema, value = _a.value, operator = _a.operator, onUpdate = _a.onUpdate;
    var model = getDataModel(schema);
    var uiSchema = model && 'uiSchema' in model ? model.uiSchema : {};
    if (model && 'Edit' in model) {
        var Edit = model.Edit;
        return (React.createElement(Edit, { schema: schema, value: value, operator: operator, onUpdate: onUpdate, slim: true }));
    }
    return (React.createElement(Form, { schema: schema, value: value, onFormChange: function (_a) {
            var formData = _a.formData;
            return onUpdate(formData);
        }, uiSchema: __assign({ 'ui:options': { label: false, inline: true } }, uiSchema), hideSubmitButton: true }));
};
var RelativeBox = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var DeleteButton = styled(Button)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tcolor: rgba(0, 0, 0, 0.4);\n\tposition: absolute;\n\tbottom: 7px;\n\tright: -35px;\n"], ["\n\tcolor: rgba(0, 0, 0, 0.4);\n\tposition: absolute;\n\tbottom: 7px;\n\tright: -35px;\n"])));
export var FilterModal = function (_a) {
    var addFilter = _a.addFilter, onClose = _a.onClose, schema = _a.schema, edit = _a.edit, fieldCompareFn = _a.fieldCompareFn;
    var _b = useState(edit), filters = _b[0], setFilters = _b[1];
    var _c = useState(''), searchTerm = _c[0], setSearchTerm = _c[1];
    var debouncedSetSearchTerm = debounce(setSearchTerm, 300);
    var setEditField = function (field, index) {
        var currentEdit = filters.map(function (filter, i) {
            return i === index ? SchemaSieve.getCleanEditModel(schema, field) : filter;
        });
        setFilters(currentEdit);
        setSearchTerm('');
    };
    var setEditOperator = function (operator, index) {
        var currentEdit = filters.map(function (filter, i) {
            return i === index ? __assign(__assign({}, filter), { operator: operator }) : filter;
        });
        setFilters(currentEdit);
    };
    var setEditValue = function (value, index) {
        var currentEdit = filters.map(function (filter, i) {
            return i === index ? __assign(__assign({}, filter), { value: value }) : filter;
        });
        setFilters(currentEdit);
    };
    var removeCompound = function (index) {
        var currentEdit = filters.reduce(function (acc, cur, i) { return (i === index ? acc : __spreadArrays(acc, [cur])); }, []);
        setFilters(currentEdit);
    };
    var fieldOptions = React.useMemo(function () {
        return map(schema.properties, function (s, field) { return ({
            field: field,
            title: s.title || field,
        }); }).sort(fieldCompareFn || defaultFilterCompareFn);
    }, [schema.properties]);
    var filteredFieldOptions = React.useMemo(function () {
        if (!searchTerm) {
            return fieldOptions;
        }
        var searchTermRegEx = new RegExp(searchTerm, 'i');
        return fieldOptions.filter(function (option) {
            return (option.title.match(searchTermRegEx) ||
                option.field.match(searchTermRegEx));
        });
    }, [searchTerm, fieldOptions]);
    return (React.createElement(Modal, { title: "Filter by", cancel: onClose, done: function () { return addFilter(filters); }, action: "Save" },
        filters.map(function (_a, index) {
            var field = _a.field, operator = _a.operator, value = _a.value;
            var operators = SchemaSieve.getOperators(schema, field);
            return (React.createElement(RelativeBox, { key: index },
                index > 0 && React.createElement(Txt, { my: 2 }, "OR"),
                React.createElement(Flex, null,
                    React.createElement(Box, { flex: 1 },
                        React.createElement(Select, { id: "filtermodal__fieldselect", options: filteredFieldOptions, onSearch: debouncedSetSearchTerm, searchPlaceholder: "Search...", valueKey: "field", labelKey: "title", value: schema.properties
                                ? {
                                    field: field,
                                    title: schema.properties[field].title ||
                                        field,
                                }
                                : { field: field }, onChange: function (_a) {
                                var option = _a.option;
                                return setEditField(option.field, index);
                            } })),
                    operators.length === 1 && (React.createElement(Txt, { py: 2, px: 3, align: "center" }, operators[0].label)),
                    operators.length > 1 && (React.createElement(Box, { flex: 1, mx: 1 },
                        React.createElement(Select, { options: operators, valueKey: "slug", labelKey: "label", value: operators.find(function (x) { return x.slug === operator; }), onChange: function (_a) {
                                var option = _a.option;
                                return setEditOperator(option.slug, index);
                            } }))),
                    React.createElement(Flex, { flex: 1, alignItems: "center" },
                        React.createElement(FilterInput, { operator: operator, value: value, schema: schema.properties[field], onUpdate: function (v) { return setEditValue(v, index); } }))),
                index > 0 && (React.createElement(DeleteButton, { plain: true, fontSize: 1, p: 1, onClick: function () { return removeCompound(index); } },
                    React.createElement(FontAwesomeIcon, { icon: faTimes })))));
        }),
        React.createElement(Button, { mb: 2, mt: 4, primary: true, underline: true, onClick: function () {
                return setFilters(filters.concat(SchemaSieve.getCleanEditModel(schema)));
            } }, "Add alternative")));
};
var templateObject_1, templateObject_2;
