import { __assign, __makeTemplateObject } from "tslib";
import * as React from 'react';
import uniq from 'lodash/uniq';
import styled from 'styled-components';
import { createTemplate, createStory } from '../../stories/utils';
import { Filters } from '.';
import { SchemaSieve, Tag } from '../..';
import PokeDex, { getNameFromSlug } from '../../stories/assets/pokedex';
var StyledTable = styled.table(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\twidth: 100%;\n\n\ttd {\n\t\tborder: 1px solid #eee;\n\t\tpadding: 3px 6px;\n\t}\n"], ["\n\twidth: 100%;\n\n\ttd {\n\t\tborder: 1px solid #eee;\n\t\tpadding: 3px 6px;\n\t}\n"])));
var schema = {
    type: 'object',
    properties: {
        name: {
            title: 'Pokemon Name',
            type: 'string',
        },
        description: {
            type: 'string',
        },
        abilities: {
            type: 'array',
            items: {
                type: 'string',
            },
        },
        secondaryAbilities: {
            title: 'Secondary Abilities',
            type: 'array',
            items: {
                type: 'string',
                oneOf: [
                    {
                        title: 'Swimming',
                        const: 'swimming',
                    },
                    {
                        title: 'Fly',
                        const: 'fly',
                    },
                    {
                        title: 'Cut',
                        const: 'cut',
                    },
                ],
            },
        },
        tag: {
            type: 'object',
            properties: {
                tag_name: {
                    title: 'Name',
                    description: 'key',
                    type: 'string',
                },
                tag_value: {
                    description: 'value',
                    title: 'Value',
                    type: 'string',
                },
            },
        },
        first_seen: {
            title: 'First Seen',
            type: 'string',
            format: 'date-time',
        },
        caught: {
            title: 'Has been caught',
            type: 'boolean',
        },
        biometrics: {
            type: 'object',
            properties: {
                Height: {
                    type: ['number', null],
                },
                Weight: {
                    type: 'number',
                },
            },
        },
        pokedex_number: {
            title: 'National pokedex number',
            type: 'number',
        },
        category: {
            enum: uniq(PokeDex.map(function (p) { return p.Category; })),
        },
        nationality: {
            title: 'Nationality',
            oneOf: uniq(PokeDex.map(function (p) { return p.nationality; })).map(function (slug) { return ({
                title: getNameFromSlug(slug),
                const: slug,
            }); }),
        },
    },
};
var FiltersDemo = function (props) {
    var _a, _b;
    var _c = React.useState((_a = props.filters) !== null && _a !== void 0 ? _a : []), filters = _c[0], setFilters = _c[1];
    var _d = React.useState((_b = props.views) !== null && _b !== void 0 ? _b : []), views = _d[0], setViews = _d[1];
    var items = SchemaSieve.filter(filters, PokeDex);
    return (React.createElement("div", null,
        React.createElement(Filters, __assign({ filters: filters, views: views, onFiltersUpdate: setFilters, onViewsUpdate: setViews }, props)),
        items.map(function (item, index) { return (React.createElement("div", { key: index },
            React.createElement("h2", null, item.Name),
            React.createElement(StyledTable, null,
                React.createElement("tbody", null,
                    React.createElement("tr", null,
                        React.createElement("td", null, "National PokeDex Number"),
                        React.createElement("td", null, item.pokedex_number)),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Category"),
                        React.createElement("td", null, item.Category)),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Nationality"),
                        React.createElement("td", null, getNameFromSlug(item.nationality))),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Height"),
                        React.createElement("td", null, item.biometrics.Height)),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Weight"),
                        React.createElement("td", null, item.biometrics.Weight)),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Abilities"),
                        React.createElement("td", null, item.Abilities.join(', '))),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Secondary Abilities"),
                        React.createElement("td", null, item.secondaryAbilities.join(', '))),
                    React.createElement("tr", null,
                        React.createElement("td", null, "First Seen"),
                        React.createElement("td", null, item.first_seen
                            ? new Date(item.first_seen).toUTCString()
                            : '')),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Caught"),
                        React.createElement("td", null, item.caught ? 'yes' : 'no')),
                    React.createElement("tr", null,
                        React.createElement("td", null, "Tags"),
                        React.createElement("td", null, !!item.Tag &&
                            item.Tag.map(function (tag) { return (React.createElement(Tag, { key: tag.tag_name, value: tag.tag_value })); }))))),
            React.createElement("p", null, item.Description))); })));
};
export default {
    title: 'Core/Filters',
    component: Filters,
    args: {
        schema: schema,
    },
};
var Template = createTemplate(FiltersDemo);
export var Default = createStory(Template, {
    filters: [],
    viewScopes: [
        {
            slug: 'bleh',
            name: 'bleh',
            label: 'bla',
        },
        {
            slug: 'foo',
            name: 'foo',
        },
    ],
});
export var Disabled = createStory(Template, {
    filters: [],
    disabled: true,
});
export var ButtonProps = createStory(Template, {
    filters: [],
    addFilterButtonProps: {
        width: 200,
    },
    viewsMenuButtonProps: {
        width: 200,
        danger: true,
    },
});
export var Compact = createStory(Template, {
    filters: [],
    compact: [true],
});
export var RenderModes = createStory(Template, {
    filters: [
        {
            $id: 'FuELaSmfCBqiV9hx',
            anyOf: [
                {
                    $id: 'QXe1ev3KzutxZ0lK',
                    title: 'is',
                    description: '{"name": "Pokemon Name", "operator": "is", "value": "Squirtle"}',
                    type: 'object',
                    properties: {
                        Name: {
                            title: 'Pokemon Name',
                            const: 'Squirtle',
                        },
                    },
                },
                {
                    $id: 'QXe1ev3KzutxZ0lm',
                    title: 'is',
                    description: '{"name": "Pokemon Name", "operator": "is", "value": "Pikachu"}',
                    type: 'object',
                    properties: {
                        Name: {
                            title: 'Pokemon Name',
                            const: 'Pikachu',
                        },
                    },
                },
            ],
        },
    ],
    renderMode: ['add', 'views', 'summary'],
});
var templateObject_1;
