import { __assign, __extends, __makeTemplateObject, __rest, __spreadArrays } from "tslib";
import { faFilter } from '@fortawesome/free-solid-svg-icons/faFilter';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import castArray from 'lodash/castArray';
import cloneDeep from 'lodash/cloneDeep';
import includes from 'lodash/includes';
import isEmpty from 'lodash/isEmpty';
import isEqual from 'lodash/isEqual';
import reject from 'lodash/reject';
import * as React from 'react';
import styled from 'styled-components';
import { Button } from '../Button';
import { randomString } from '../../utils';
import { Box } from '../Box';
import { Flex } from '../Flex';
import { Search } from '../Search';
import { FilterModal } from './FilterModal';
import * as SchemaSieve from './SchemaSieve';
import Summary from './Summary';
import ViewsMenu from './ViewsMenu';
import { onClickOutOrEsc } from '../../extra/AutoUI/utils';
var SearchWrapper = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\twidth: 100%;\n\tflex-basis: 100%;\n\tposition: relative;\n\tmargin-right: 4px;\n\tpadding: 0 4px;\n\talign-self: center;\n"], ["\n\twidth: 100%;\n\tflex-basis: 100%;\n\tposition: relative;\n\tmargin-right: 4px;\n\tpadding: 0 4px;\n\talign-self: center;\n"])));
var FilterWrapper = styled(Box)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var BaseFilters = (function (_super) {
    __extends(BaseFilters, _super);
    function BaseFilters(props) {
        var _this = _super.call(this, props) || this;
        _this.searchContainer = React.createRef();
        _this.clearAllFilters = function () {
            _this.setFilters([]);
            _this.setState({
                searchString: '',
            });
        };
        var _a = _this.props, _b = _a.filters, filters = _b === void 0 ? [] : _b, schema = _a.schema, _c = _a.views, views = _c === void 0 ? [] : _c;
        var flatSchema = SchemaSieve.flattenSchema(schema);
        var flatViews = _this.flattenViews(views);
        var flatFilters = filters.map(function (filter) {
            return SchemaSieve.flattenSchema(filter);
        });
        _this.state = {
            showModal: false,
            searchString: '',
            editingFilter: null,
            filters: flatFilters,
            views: flatViews,
            schema: flatSchema,
            edit: [],
            showSearchDropDown: false,
        };
        _this.state.edit.push(_this.getCleanEditModel());
        _this.searchContainer = React.createRef();
        return _this;
    }
    BaseFilters.prototype.componentDidUpdate = function (prevProps) {
        var newState = {};
        if (!isEqual(prevProps.schema, this.props.schema)) {
            newState.schema = SchemaSieve.flattenSchema(this.props.schema);
        }
        if (!isEqual(prevProps.filters, this.props.filters)) {
            var filters = this.props.filters || [];
            newState.filters = filters.map(function (filter) {
                return SchemaSieve.flattenSchema(filter);
            });
        }
        if (!isEqual(prevProps.views, this.props.views)) {
            var views = this.props.views || [];
            newState.views = this.flattenViews(views);
        }
        if (!isEmpty(newState)) {
            this.setState(newState);
        }
    };
    BaseFilters.prototype.flattenViews = function (views) {
        return views.map(function (_a) {
            var filters = _a.filters, view = __rest(_a, ["filters"]);
            return (__assign(__assign({}, view), { filters: filters.map(function (filter) { return SchemaSieve.flattenSchema(filter); }) }));
        });
    };
    BaseFilters.prototype.emitViewsUpdate = function () {
        if (!this.props.onViewsUpdate) {
            return;
        }
        this.props.onViewsUpdate(this.state.views.map(function (_a) {
            var filters = _a.filters, view = __rest(_a, ["filters"]);
            return (__assign(__assign({}, view), { filters: filters.map(function (filter) { return SchemaSieve.unflattenSchema(filter); }) }));
        }));
    };
    BaseFilters.prototype.getCleanEditModel = function (field) {
        var schema = this.state.schema;
        if (!field) {
            field = Object.keys(schema.properties).shift();
        }
        var fieldOperators = this.getOperators(field);
        if (!fieldOperators.length) {
            return {
                field: field,
                operator: '',
                value: '',
            };
        }
        var operator = fieldOperators.shift().slug;
        var value = '';
        var subschema = schema.properties[field];
        if (typeof subschema !== 'boolean') {
            if (subschema.enum) {
                value = subschema.enum[0] || '';
            }
            if (subschema.oneOf) {
                value = subschema.oneOf[0].const || '';
            }
            if (subschema.type === 'boolean') {
                value = true;
            }
        }
        return {
            field: field,
            operator: operator,
            value: value,
        };
    };
    BaseFilters.prototype.getOperators = function (field) {
        var schema = this.state.schema;
        return SchemaSieve.getOperators(schema, field);
    };
    BaseFilters.prototype.emitFilterUpdate = function () {
        if (!this.props.onFiltersUpdate) {
            return;
        }
        this.props.onFiltersUpdate(this.state.filters.map(function (filter) { return SchemaSieve.unflattenSchema(filter); }));
    };
    BaseFilters.prototype.addFilter = function (edit) {
        var _this = this;
        var newFilter = SchemaSieve.createFilter(this.state.schema, edit);
        var currentFilters = !!this.state.editingFilter
            ? this.state.filters.map(function (filter) {
                return filter.$id === _this.state.editingFilter ? newFilter : filter;
            })
            : __spreadArrays(this.state.filters, [newFilter]);
        this.setState({
            filters: currentFilters,
            edit: [this.getCleanEditModel()],
            showModal: false,
            editingFilter: null,
        }, function () { return _this.emitFilterUpdate(); });
    };
    BaseFilters.prototype.editFilter = function (filter) {
        if (filter.title === SchemaSieve.FULL_TEXT_SLUG) {
            return;
        }
        var schema = this.state.schema;
        var signatures = SchemaSieve.decodeFilter(schema, filter);
        this.setState({
            edit: signatures,
            editingFilter: filter.$id,
            showModal: true,
        });
    };
    BaseFilters.prototype.removeFilter = function (_a) {
        var _this = this;
        var $id = _a.$id, title = _a.title;
        this.setState(function (prevState) {
            var newState = __assign(__assign({}, prevState), { filters: reject(prevState.filters, { $id: $id }) });
            if (title === SchemaSieve.FULL_TEXT_SLUG) {
                newState.searchString = '';
            }
            return newState;
        }, function () { return _this.emitFilterUpdate(); });
    };
    BaseFilters.prototype.setFilters = function (filters) {
        var _this = this;
        this.setState({ filters: filters }, function () { return _this.emitFilterUpdate(); });
    };
    BaseFilters.prototype.saveView = function (name, scope) {
        var _this = this;
        var view = {
            id: randomString(),
            name: name,
            scope: scope,
            filters: cloneDeep(this.state.filters),
        };
        this.setState(function (prevState) { return ({
            views: prevState.views.concat(view),
        }); }, function () {
            return _this.props.onViewsUpdate && _this.props.onViewsUpdate(_this.state.views);
        });
    };
    BaseFilters.prototype.deleteView = function (_a) {
        var _this = this;
        var id = _a.id;
        this.setState(function (prevState) { return ({
            views: reject(prevState.views, { id: id }),
        }); }, function () {
            return _this.props.onViewsUpdate && _this.props.onViewsUpdate(_this.state.views);
        });
    };
    BaseFilters.prototype.shouldRenderComponent = function (mode) {
        if (!this.props.renderMode) {
            return true;
        }
        var allowedModes = castArray(this.props.renderMode);
        if (includes(allowedModes, 'all')) {
            return true;
        }
        return includes(allowedModes, mode);
    };
    BaseFilters.prototype.render = function () {
        var _this = this;
        var _a = this.state, filters = _a.filters, searchString = _a.searchString, showSearchDropDown = _a.showSearchDropDown;
        var renderingSummaryAndOtherComponents = this.shouldRenderComponent('summary') &&
            [
                this.shouldRenderComponent('add'),
                this.shouldRenderComponent('search'),
                this.shouldRenderComponent('views'),
            ].includes(true);
        var componentsToRender = !!this.props.renderMode
            ? castArray(this.props.renderMode)
            : [];
        return (React.createElement(FilterWrapper, null,
            React.createElement(Flex, { justifyContent: "space-between", mb: renderingSummaryAndOtherComponents ? 3 : undefined },
                this.shouldRenderComponent('search') && (React.createElement(SearchWrapper, { ref: this.searchContainer, onFocus: function () {
                        _this.setState({ showSearchDropDown: true });
                        if (_this.searchContainer.current) {
                            onClickOutOrEsc(_this.searchContainer.current, function () {
                                _this.setState({ showSearchDropDown: false });
                            });
                        }
                    } },
                    React.createElement(Search, { dark: this.props.dark, disabled: this.props.disabled, value: searchString, onChange: function (e) {
                            if (e.target.value !== '') {
                                _this.setState({ showSearchDropDown: true });
                            }
                            else {
                                _this.setState({ showSearchDropDown: false });
                            }
                            _this.setState({ searchString: e.target.value });
                        }, onEnter: function () {
                            if (!searchString) {
                                return;
                            }
                            _this.setState(function (prevState) {
                                var newFilters = SchemaSieve.insertFullTextSearch(_this.state.schema, prevState.filters, searchString);
                                return {
                                    filters: newFilters,
                                    searchString: '',
                                };
                            }, function () { return _this.emitFilterUpdate(); });
                        } }),
                    searchString &&
                        showSearchDropDown &&
                        this.props.onSearch &&
                        this.props.onSearch(searchString))),
                this.shouldRenderComponent('add') && (React.createElement(Button, __assign({ mx: 1, disabled: this.props.disabled, light: this.props.dark, outline: true, quartenary: true, icon: React.createElement(FontAwesomeIcon, { icon: faFilter }), onClick: function () {
                        return _this.setState({ showModal: true, editingFilter: null });
                    }, label: "Add filter", compact: this.props.compact }, this.props.addFilterButtonProps))),
                this.shouldRenderComponent('views') && (React.createElement(ViewsMenu, { dark: this.props.dark, buttonProps: this.props.viewsMenuButtonProps, disabled: this.props.disabled, views: this.state.views || [], schema: this.props.schema, hasMultipleScopes: this.props.viewScopes && this.props.viewScopes.length > 1, renderMode: componentsToRender, setFilters: function (filters) { return _this.setFilters(filters); }, deleteView: function (view) { return _this.deleteView(view); }, compact: this.props.compact })),
                this.state.showModal && (React.createElement(FilterModal, { addFilter: function (edit) { return _this.addFilter(edit); }, onClose: function () { return _this.setState({ showModal: false }); }, schema: this.state.schema, edit: this.state.edit, fieldCompareFn: this.props.filterFieldCompareFn }))),
            this.shouldRenderComponent('summary') &&
                !!filters.length &&
                !this.props.disabled && (React.createElement(Summary, { scopes: this.props.viewScopes, edit: function (filter) { return _this.editFilter(filter); }, delete: function (filter) { return _this.removeFilter(filter); }, saveView: function (name, scope) { return _this.saveView(name, scope); }, clearAllFilters: this.clearAllFilters, filters: filters, views: this.state.views || [], schema: this.state.schema }))));
    };
    return BaseFilters;
}(React.Component));
export var Filters = BaseFilters;
var templateObject_1, templateObject_2;
