import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import keys from 'lodash/keys';
import get from 'lodash/get';
import escapeRegExp from 'lodash/escapeRegExp';
import filter from 'lodash/filter';
import memoize from 'lodash/memoize';
import JsonSchema7Schema from 'ajv/lib/refs/json-schema-draft-07.json';
import styled from 'styled-components';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faUndo } from '@fortawesome/free-solid-svg-icons/faUndo';
import asRendition from '../../../asRendition';
import { Flex } from '../../Flex';
import { Box } from '../../Box';
import { Card } from '../../Card';
import { Select } from '../../Select';
import { Button } from '../../Button';
import { Heading } from '../../Heading';
import { Checkbox } from '../../Checkbox';
import { Renderer } from '../index';
import { CONTEXT_FUNCTIONS, EXTRA_FORMATS } from '../examples';
import JsonEditor from './JsonEditor';
import { generateUiSchemaMetaSchema } from './util';
var SlimCard = styled(Card)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t& > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t}\n"], ["\n\t& > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t}\n"])));
var ResultCard = styled(SlimCard)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t& > div > div:last-child {\n\t\tdisplay: flex;\n\t}\n"], ["\n\t& > div > div:last-child {\n\t\tdisplay: flex;\n\t}\n"])));
var EditCard = styled(SlimCard)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\t& > div > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t\tmin-height: 0;\n\t}\n"], ["\n\t& > div > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t\tmin-height: 0;\n\t}\n"])));
var defaultJsonProps = { value: {}, schema: {}, uiSchema: {} };
var defaultRegExp = new RegExp('');
var getExampleNames = memoize(function (examples) { return keys(examples); });
var commonCardProps = {
    small: true,
    backgroundColor: 'quartenary.light',
};
var RendererPlaygroundBase = function (_a) {
    var _b = _a.title, title = _b === void 0 ? 'JSON Playground' : _b, examples = _a.examples, props = __rest(_a, ["title", "examples"]);
    var _c = React.useState(true), validate = _c[0], setValidate = _c[1];
    var _d = React.useState(''), selectedExample = _d[0], setSelectedExample = _d[1];
    var _e = React.useState(defaultRegExp), searchTermRegExp = _e[0], setSearchTermRegExp = _e[1];
    var _f = React.useState({}), value = _f[0], setValue = _f[1];
    var _g = React.useState({}), schema = _g[0], setSchema = _g[1];
    var _h = React.useState({}), uiSchema = _h[0], setUiSchema = _h[1];
    var _j = React.useState(true), isValueJsonValid = _j[0], setIsValueJsonValid = _j[1];
    var _k = React.useState(true), isSchemaJsonValid = _k[0], setIsSchemaJsonValid = _k[1];
    var _l = React.useState(true), isUiSchemaJsonValid = _l[0], setIsUiSchemaJsonValid = _l[1];
    var reset = React.useCallback(function () {
        setSelectedExample('');
        setSearchTermRegExp(defaultRegExp);
    }, [setSelectedExample, setSearchTermRegExp]);
    var onValueStrChange = React.useCallback(function (valueStr) {
        try {
            setValue(JSON.parse(valueStr));
            setIsValueJsonValid(true);
        }
        catch (_a) {
            setIsValueJsonValid(false);
        }
    }, []);
    var onSchemaStrChange = React.useCallback(function (schemaStr) {
        try {
            setSchema(JSON.parse(schemaStr));
            setIsSchemaJsonValid(true);
        }
        catch (_a) {
            setIsSchemaJsonValid(false);
        }
    }, []);
    var onUiSchemaStrChange = React.useCallback(function (uiSchemaStr) {
        try {
            setUiSchema(JSON.parse(uiSchemaStr));
            setIsUiSchemaJsonValid(true);
        }
        catch (_a) {
            setIsUiSchemaJsonValid(false);
        }
    }, []);
    React.useEffect(function () {
        var example = get(examples, selectedExample, defaultJsonProps);
        setValue(example.value);
        setSchema(example.schema);
        setUiSchema(example.uiSchema);
        setSearchTermRegExp(defaultRegExp);
    }, [selectedExample]);
    var uiSchemaMetaSchema = React.useMemo(function () {
        try {
            var newMetaSchema = generateUiSchemaMetaSchema({
                value: value,
                schema: schema,
                uiSchema: uiSchema,
                extraContext: __assign(__assign({}, CONTEXT_FUNCTIONS), { root: value }),
            });
            return newMetaSchema;
        }
        catch (error) {
            console.error('Failed to parse schemas', error);
            throw new Error('Failed to parse schemas');
        }
    }, [uiSchema, schema, value]);
    var valueStr = React.useMemo(function () { return JSON.stringify(value, null, 2); }, [value]);
    var schemaStr = React.useMemo(function () { return JSON.stringify(schema, null, 2); }, [schema]);
    var uiSchemaStr = React.useMemo(function () { return JSON.stringify(uiSchema, null, 2); }, [uiSchema]);
    var unfilteredExampleNames = getExampleNames(examples);
    var exampleNames = searchTermRegExp.source
        ? filter(unfilteredExampleNames, function (name) { return searchTermRegExp.test(name); })
        : unfilteredExampleNames;
    return (React.createElement(Flex, __assign({ p: 3 }, props),
        React.createElement(Flex, { flex: "1 1 50%", minWidth: 0, flexDirection: "column", pr: 2 },
            React.createElement(Flex, { mb: 3, alignItems: "center", justifyContent: "space-between" },
                React.createElement(Heading.h3, null, title),
                React.createElement(Flex, { ml: 3, alignItems: "center", justifyContent: "flex-end", flex: 1 },
                    React.createElement(Box, { flex: 1 },
                        React.createElement(Select, { placeholder: "Load an example...", emptySearchMessage: "No results", searchPlaceholder: "Search...", onSearch: function (s) {
                                return setSearchTermRegExp(new RegExp(escapeRegExp(s), 'i'));
                            }, value: selectedExample, options: exampleNames, onChange: function (_a) {
                                var option = _a.option;
                                setSelectedExample(option);
                            } })),
                    React.createElement(Button, { ml: 2, tooltip: { text: 'Reset', placement: 'right' }, icon: React.createElement(FontAwesomeIcon, { icon: faUndo }), onClick: reset }))),
            React.createElement(EditCard, __assign({ flex: 1 }, commonCardProps),
                React.createElement(JsonEditor, { title: "Data", value: valueStr, onChange: onValueStrChange, schema: schema, isValid: isValueJsonValid }),
                React.createElement(JsonEditor, { title: "Schema", value: schemaStr, onChange: onSchemaStrChange, schema: JsonSchema7Schema, isValid: isSchemaJsonValid }),
                React.createElement(JsonEditor, { title: "UI Schema", value: uiSchemaStr, onChange: onUiSchemaStrChange, schema: uiSchemaMetaSchema, isValid: isUiSchemaJsonValid }))),
        React.createElement(Flex, { flex: "1 1 50%", minWidth: 0, flexDirection: "column", pl: 2 },
            React.createElement(ResultCard, __assign({ flex: 1 }, commonCardProps, { title: "Result", cta: React.createElement(Checkbox, { checked: validate, label: "Validate", onChange: function (e) { return setValidate(e.target.checked); } }) }),
                React.createElement(Renderer, { value: value, schema: schema, uiSchema: uiSchema, p: 2, pb: 1, validate: validate, backgroundColor: "#fff", extraFormats: EXTRA_FORMATS, extraContext: __assign(__assign({}, CONTEXT_FUNCTIONS), { root: value }) })))));
};
export var RendererPlayground = asRendition(RendererPlaygroundBase);
var templateObject_1, templateObject_2, templateObject_3;
