/// <reference types="react" />
import type { JSONSchema, JsonTypesTypeMap, UiSchema, Format, Value } from '../types';
import type { Overwrite } from '../../../common-types';
import { UiOptions } from './ui-options';
export interface WidgetProps<T extends object = object> {
    value: Value;
    schema: JSONSchema | undefined;
    uiSchema?: UiSchema;
    extraFormats?: Format[];
    extraContext?: T;
}
interface WidgetStaticProperties {
    uiOptions?: UiOptions;
    supportedTypes?: string[];
    displayName: string;
}
export interface Widget<T extends object = object, ExtraProps = {}> extends WidgetStaticProperties {
    (props: WidgetProps<T> & ExtraProps): JSX.Element | null;
}
export declare function widgetFactory<ST extends Array<keyof JsonTypesTypeMap>>(displayName: string, uiOptions: Widget['uiOptions'], supportedTypes: ST): <T extends object, ExtraProps extends {} = {}, V extends Value = JsonTypesTypeMap[ST[number]]>(widgetFn: (props: Pick<WidgetProps<T>, "schema" | "uiSchema" | "extraFormats" | "extraContext"> & {
    value: V;
} & ExtraProps) => JSX.Element | null) => Widget<T, ExtraProps>;
export declare function formatTimestamp(timestamp: string | number, uiSchema?: UiSchema): string;
export declare const timeSince: (timestamp: string | number, suffix?: boolean) => string;
export declare function withOptionProps(uiOptions: UiOptions): (Component: Widget) => {
    (props: WidgetProps): JSX.Element;
    displayName: string;
    uiOptions: UiOptions | undefined;
    supportedTypes: string[] | undefined;
};
export declare const transformUiSchema: ({ value, uiSchema, extraContext, }: {
    value?: string | number | boolean | any[] | {
        [key: string]: any;
    } | null | undefined;
    uiSchema: WidgetProps['uiSchema'];
    extraContext: WidgetProps['extraContext'];
}) => any;
export declare const getBestSchemaMatch: (schema: JSONSchema | undefined, value: any) => JSONSchema | undefined;
export declare const getArrayItems: ({ value, schema, uiSchema, extraContext, extraFormats, }: WidgetProps) => WidgetProps[];
export declare function getObjectPropertyNames({ value, schema, uiSchema, }: WidgetProps): string[];
export declare const truncateHash: (str: string, maxLength?: number) => string;
export {};
