import { __assign } from "tslib";
import React from 'react';
import { createTemplate, createStory } from '../../stories/utils';
import PokeDex from '../../stories/assets/pokedex';
import { Table } from './';
var prefixNum = function (num) {
    return num.toString().length === 1 ? "0" + num : num;
};
var columns = [
    {
        title: 'Name',
        field: 'Name',
        sortable: true,
        selected: true,
    },
    {
        title: 'National Pokedex Number',
        field: 'pokedex_number',
        sortable: true,
        selected: true,
        render: function (value) { return React.createElement("code", null, value); },
    },
    {
        title: 'Category',
        field: 'Category',
        sortable: true,
        selected: true,
    },
    {
        title: 'First Seen',
        field: 'first_seen',
        sortable: true,
        selected: false,
        render: function (value) {
            if (value == null) {
                return null;
            }
            var d = new Date(value);
            return (React.createElement("span", null,
                d.getFullYear(),
                "-",
                prefixNum(d.getMonth() + 1),
                "-",
                prefixNum(d.getDay() + 1)));
        },
    },
];
export default {
    title: 'Core/Table',
    component: Table,
    args: {
        columns: columns,
        data: PokeDex,
        rowKey: 'pokedex_number',
        onCheck: null,
    },
};
var TableWithCheckboxesTemplate = createTemplate(function (props) {
    var _a;
    var _b = React.useState((_a = props.checkedItems) !== null && _a !== void 0 ? _a : []), selected = _b[0], setSelected = _b[1];
    return (React.createElement(Table, __assign({}, props, { checkedItems: selected, onCheck: function (items) { return setSelected(items); } })));
});
var Template = createTemplate(Table);
export var Default = createStory(Template, {});
export var WithPager = createStory(Template, {
    usePager: true,
    itemsPerPage: 3,
    pagerPosition: 'both',
});
export var WithFuzzyPager = createStory(Template, {
    usePager: true,
    itemsPerPage: 3,
    pagerPosition: 'both',
    fuzzyPager: true,
    data: PokeDex.slice(0, 5),
});
export var Sorted = createStory(Template, {
    sort: { field: 'Name', reverse: true },
});
export var WithCheckboxes = createStory(TableWithCheckboxesTemplate, {
    checkedItems: PokeDex.slice(0, 3),
});
export var WithRowClick = createStory(Template, {
    onRowClick: function () { return null; },
});
export var WithPrefix = createStory(Template, {
    tbodyPrefix: [
        React.createElement("tr", { key: 1 },
            React.createElement("td", { colSpan: columns.length },
                React.createElement("p", { style: { textAlign: 'center' } }, "Row 1"))),
        React.createElement("tr", { key: 2 },
            React.createElement("td", { colSpan: columns.length },
                React.createElement("p", { style: { textAlign: 'center' } }, "Row 2"))),
    ],
});
export var WithAnchorRows = createStory(Template, {
    getRowHref: function (row) { return "https://www.pokemon.com/uk/pokedex/" + row.Name; },
    rowAnchorAttributes: { target: '_blank' },
});
export var WithHighlightedRows = createStory(Template, {
    highlightedRows: [2, 5],
});
export var WithConditionalRowClasses = createStory(Template, {
    getRowClass: function (pokemon) {
        var classNames = ['pokemon'];
        if (pokemon.caught) {
            classNames.push('pokemon--caught');
        }
        if (pokemon.Abilities.length === 1) {
            classNames.push('pokemon--one-dimensional');
        }
        return classNames;
    },
});
export var withCustomColumns = createStory(Template, {
    enableCustomColumns: true,
});
