import memoizee from 'memoizee';
import * as React from 'react';
import { CheckboxProps } from '../Checkbox';
import { TableBaseColumn } from './TableRow';
declare type CheckedTypes = 'none' | 'some' | 'all';
interface TableBaseState<T> {
    allChecked: CheckedTypes;
    checkedItems: T[];
    sort: {
        reverse: boolean;
        field: null | keyof T;
    };
    page: number;
    lastSelected: T[keyof T] | null;
}
export declare class TableBase<T> extends React.Component<TableBaseProps<T>, TableBaseState<T>> {
    constructor(props: TableBaseProps<T>);
    componentDidUpdate(prevProps: TableBaseProps<T>): void;
    protected $getSelectedIdentifiersSet: ((selectedRows: T[] | undefined, rowKey: keyof T | undefined) => Set<unknown>) & memoizee.Memoized<(selectedRows: T[] | undefined, rowKey: keyof T | undefined) => Set<unknown>>;
    protected getCheckedRowIdentifiers(): Set<unknown>;
    isChecked(item: T): boolean | undefined;
    protected $getHighlightedRowIdentifiers: ((highlightedRows: NonNullable<TableBaseProps<T>['highlightedRows']>) => Set<unknown>) & memoizee.Memoized<(highlightedRows: NonNullable<TableBaseProps<T>['highlightedRows']>) => Set<unknown>>;
    protected getHighlightedRowIdentifiers(): Set<unknown>;
    isHighlighted(item: T): boolean | undefined;
    protected $getDisabledRowIdentifiers: ((disabledRows: NonNullable<TableBaseProps<T>['disabledRows']>) => Set<T[keyof T]>) & memoizee.Memoized<(disabledRows: NonNullable<TableBaseProps<T>['disabledRows']>) => Set<T[keyof T]>>;
    protected getDisabledRowIdentifiers(): Set<unknown>;
    isDisabled(item: T): boolean | undefined;
    componentWillUnmount(): void;
    howManyRowsChecked(checkedItems: T[]): CheckedTypes;
    sortData(data: T[]): T[];
    private $getValidatedCheckedItems;
    private getSelectedRows;
    setRowSelection: (selectedRows: T[]) => void;
    toggleAllChecked: () => void;
    toggleChecked: (e: React.ChangeEvent<HTMLInputElement>) => false | undefined;
    toggleSort: (e: React.MouseEvent<HTMLButtonElement>) => void;
    getElementFromKey(key: string): T | undefined;
    onRowClick: (e: React.MouseEvent<HTMLAnchorElement>) => void;
    setPage: (change: any) => void;
    resetPager: () => void;
    incrementPage: () => void;
    decrementPage: () => void;
    render(): JSX.Element;
}
export interface TableSortOptions<T> {
    reverse: boolean;
    field: keyof T | null;
}
export interface TableBaseProps<T> {
    columns: Array<TableBaseColumn<T>>;
    data?: T[] | null;
    checkedItems?: T[];
    getRowHref?: (row: T) => string;
    onCheck?: (checkedItems: T[]) => void;
    onRowClick?: (row: T, event: React.MouseEvent<HTMLAnchorElement>) => void;
    onSort?: (sort: TableSortOptions<T>) => void;
    onPageChange?: (page: number) => void;
    sort?: TableSortOptions<T>;
    rowAnchorAttributes?: React.AnchorHTMLAttributes<HTMLAnchorElement>;
    rowCheckboxAttributes?: CheckboxProps;
    rowKey?: keyof T;
    tbodyPrefix?: JSX.Element | JSX.Element[];
    highlightedRows?: any;
    disabledRows?: Array<T[keyof T]>;
    getRowClass?: (row: T) => string[];
    usePager?: boolean;
    fuzzyPager?: boolean;
    itemsPerPage?: number;
    pagerPosition?: 'top' | 'bottom' | 'both';
    className?: string;
}
export {};
