import { __assign, __awaiter, __extends, __generator, __makeTemplateObject, __rest, __spreadArrays } from "tslib";
import * as React from 'react';
import { TableBase } from './TableBase';
import styled, { css } from 'styled-components';
import keys from 'lodash/keys';
import pick from 'lodash/pick';
import filter from 'lodash/filter';
import map from 'lodash/map';
import flatMap from 'lodash/flatMap';
import uniq from 'lodash/uniq';
import reduce from 'lodash/reduce';
import without from 'lodash/without';
import isEqual from 'lodash/isEqual';
import keyBy from 'lodash/keyBy';
import { Flex } from '../Flex';
import { getNewTagTableColumnState, TableColumnSelector, TableColumnStateStoredProps, } from './TableColumnSelector';
import { TagLabel } from './TagLabel';
import { TagLabelList } from './TagLabelList';
import { CustomColumnHeader } from './CustomColumnHeader';
import { TableRow } from './TableRow';
import { getResourceTags } from '../TagManagementModal/tag-management-service';
import { getFromLocalStorage, setToLocalStorage } from '../../utils';
var Container = styled(Flex)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
export var TableColumnSelectorSizer = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: absolute;\n\ttop: ", ";\n\tright: 0;\n\tdisplay: flex;\n\talign-items: center;\n\theight: 40px;\n\tpadding: 0 8px;\n\tbackground: ", ";\n"], ["\n\tposition: absolute;\n\ttop: ", ";\n\tright: 0;\n\tdisplay: flex;\n\talign-items: center;\n\theight: 40px;\n\tpadding: 0 8px;\n\tbackground: ", ";\n"])), function (props) { return (props.pagerPosition === 'bottom' ? 0 : '47px'); }, function (props) { return props.theme.colors.quartenary.semilight; });
var fixedFirstColumnWidth = '60px';
var fixedFirstColumnCss = function (bg) { return css(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tmax-width: calc(100% - ", ");\n\tmargin-left: ", ";\n\n\twhite-space: nowrap;\n\n\t> [data-display='table-head']\n\t\t> [data-display='table-row']\n\t\t> [data-display='table-cell'],\n\t> [data-display='table-body']\n\t\t> [data-display='table-row']\n\t\t> [data-display='table-cell'] {\n\t\t&:first-child {\n\t\t\tposition: absolute;\n\t\t\tleft: 0;\n\t\t\tdisplay: flex;\n\t\t\talign-items: center;\n\t\t\twidth: ", ";\n\t\t\theight: inherit;\n\t\t\tz-index: 3;\n\t\t\tbackground-color: inherit;\n\t\t\t> input[type='checkbox'] {\n\t\t\t\tmargin: 0;\n\t\t\t}\n\t\t}\n\t}\n\t> [data-display='table-head']\n\t\t> [data-display='table-row']\n\t\t> [data-display='table-cell']:first-child {\n\t\tbackground-color: ", ";\n\t}\n"], ["\n\tmax-width: calc(100% - ", ");\n\tmargin-left: ", ";\n\n\twhite-space: nowrap;\n\n\t> [data-display='table-head']\n\t\t> [data-display='table-row']\n\t\t> [data-display='table-cell'],\n\t> [data-display='table-body']\n\t\t> [data-display='table-row']\n\t\t> [data-display='table-cell'] {\n\t\t&:first-child {\n\t\t\tposition: absolute;\n\t\t\tleft: 0;\n\t\t\tdisplay: flex;\n\t\t\talign-items: center;\n\t\t\twidth: ", ";\n\t\t\theight: inherit;\n\t\t\tz-index: 3;\n\t\t\tbackground-color: inherit;\n\t\t\t> input[type='checkbox'] {\n\t\t\t\tmargin: 0;\n\t\t\t}\n\t\t}\n\t}\n\t> [data-display='table-head']\n\t\t> [data-display='table-row']\n\t\t> [data-display='table-cell']:first-child {\n\t\tbackground-color: ", ";\n\t}\n"])), fixedFirstColumnWidth, fixedFirstColumnWidth, fixedFirstColumnWidth, bg); };
var StyledTable = styled(TableBase)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\t", ";\n\n\t> [data-display='table-head'] > [data-display='table-row'] {\n\t\theight: 42px;\n\t}\n\n\t> [data-display='table-body'] > [data-display='table-row'] {\n\t\theight: 50px;\n\t}\n\n\t", ";\n"], ["\n\t",
    ";\n\n\t> [data-display='table-head'] > [data-display='table-row'] {\n\t\theight: 42px;\n\t}\n\n\t> [data-display='table-body'] > [data-display='table-row'] {\n\t\theight: 50px;\n\t}\n\n\t",
    ";\n"])), function (props) {
    return props.enableCustomColumns
        ? "\n\t\t> [data-display='table-head']\n\t\t\t> [data-display='table-row']\n\t\t\t> [data-display='table-cell']:last-child {\n\t\t\tpadding-right: 50px;\n\t\t}\n\t"
        : '';
}, function (props) {
    return !!props.onCheck
        ? fixedFirstColumnCss(props.theme.colors.quartenary.semilight)
        : '';
});
var TypedTable = StyledTable;
var TAGS_COLUMN_KEY = 'Tags';
var tagCellAttributes = {
    href: undefined,
    style: {
        cursor: 'auto',
        paddingTop: '6px',
        paddingBottom: '6px',
    },
};
var isCustomTagColumn = function (column) {
    return column.type === 'tag' && column.key !== TAGS_COLUMN_KEY;
};
var insertTagColumns = function (columns, newTagColumns) {
    var allTagsColumnIndex = columns.findIndex(function (column) { return column.key === TAGS_COLUMN_KEY; });
    if (allTagsColumnIndex < 0) {
        allTagsColumnIndex = columns.length - 1;
    }
    columns.splice.apply(columns, __spreadArrays([allTagsColumnIndex, 0], newTagColumns));
};
var findTagOfTaggedResource = function (taggedResource, tagField, tagKey) { var _a; return (_a = getResourceTags(taggedResource, tagField)) === null || _a === void 0 ? void 0 : _a.find(function (tag) { return tag.tag_key === tagKey; }); };
var getTagTableColumn = function (columnState, tagField) {
    var column = __assign(__assign({}, columnState), { field: tagField + "." + columnState.tagKey, cellAttributes: tagCellAttributes });
    column.sortable = function (a, b) {
        var tagKey = column.tagKey;
        if (!tagKey) {
            return 0;
        }
        var item1tag = findTagOfTaggedResource(a, tagField, tagKey);
        var item2tag = findTagOfTaggedResource(b, tagField, tagKey);
        if (!item1tag && !item2tag) {
            return 0;
        }
        if (!item1tag) {
            return 1;
        }
        if (!item2tag) {
            return -1;
        }
        return (item1tag.value || '').localeCompare(item2tag.value || '');
    };
    column.render = function (_value, data) {
        var tagKey = column.tagKey;
        if (!tagKey) {
            return null;
        }
        var tag = findTagOfTaggedResource(data, tagField, tagKey);
        if (!tag) {
            return null;
        }
        return React.createElement(TagLabel, { tag: tag, showTagKey: false });
    };
    return column;
};
var normalizeTableColumn = function (originalColumn, enableCustomColumns) {
    var column = originalColumn;
    if (isCustomTagColumn(column) && !column.title && column.tagKey) {
        column.title = column.tagKey;
    }
    column.label = column.label || column.title;
    column.selected =
        !enableCustomColumns ||
            originalColumn.locked ||
            originalColumn.selected ||
            false;
    return column;
};
var getAllTagsTableColumn = function (tagField, enableCustomColumns) {
    return normalizeTableColumn({
        title: 'Tags',
        key: TAGS_COLUMN_KEY,
        selected: false,
        type: 'predefined',
        field: tagField,
        cellAttributes: tagCellAttributes,
        render: function (tags) {
            if (!tags) {
                return null;
            }
            return React.createElement(TagLabelList, { tags: tags, nowrap: true });
        },
    }, enableCustomColumns);
};
var loadSortingPreferences = function (sortingStateRestorationKey) {
    if (!sortingStateRestorationKey) {
        return;
    }
    var sortPreferences = getFromLocalStorage(sortingStateRestorationKey);
    if (!sortPreferences || !sortPreferences.field) {
        return;
    }
    return sortPreferences;
};
var saveSortingPreferences = function (sortingStateRestorationKey, sortPreferences) {
    if (!sortingStateRestorationKey) {
        return;
    }
    setToLocalStorage(sortingStateRestorationKey, sortPreferences);
};
var loadColumnPreferences = function (columnStateRestorationKey) {
    if (!columnStateRestorationKey) {
        return [];
    }
    var loadedColumns = getFromLocalStorage(columnStateRestorationKey);
    loadedColumns === null || loadedColumns === void 0 ? void 0 : loadedColumns.forEach(function (c) {
        if (c.type === 'tag' && !c.tagKey) {
            c.tagKey = undefined;
        }
    });
    return loadedColumns;
};
var saveColumnPreferences = function (columnStateRestorationKey, newColumns) {
    if (!columnStateRestorationKey) {
        return;
    }
    var savePayload = newColumns.map(function (c) {
        return pick(c, TableColumnStateStoredProps);
    });
    setToLocalStorage(columnStateRestorationKey, savePayload);
};
var applyColumnPreferences = function (columns, loadedColumns, tagField, enableCustomColumns) {
    if (!(loadedColumns === null || loadedColumns === void 0 ? void 0 : loadedColumns.length)) {
        return columns;
    }
    var columnsByKey = keyBy(columns, 'key');
    var loadedColumnsByKey = keyBy(loadedColumns, 'key');
    var tableColumnStateAssignedProps = without(TableColumnStateStoredProps, 'key');
    keys(columnsByKey).forEach(function (key) {
        var column = columnsByKey[key];
        var loadedColumn = loadedColumnsByKey[key];
        if (!loadedColumn || !column) {
            return;
        }
        Object.assign(column, pick(loadedColumn, tableColumnStateAssignedProps));
    });
    if (tagField) {
        var loadedTagColumns = filter(loadedColumns, isCustomTagColumn);
        var tagColumns = map(loadedTagColumns, function (c) {
            return getTagTableColumn(c, tagField);
        });
        insertTagColumns(columns, tagColumns);
    }
    columns.forEach(function (column) {
        return normalizeTableColumn(column, enableCustomColumns);
    });
    return columns;
};
var addCustomColumns = function (props) {
    var columns = props.columns, tagField = props.tagField, enableCustomColumns = props.enableCustomColumns, columnStateRestorationKey = props.columnStateRestorationKey;
    var allColumns = columns.map(function (column) {
        return normalizeTableColumn(column, enableCustomColumns);
    });
    if (tagField) {
        allColumns = allColumns.concat(getAllTagsTableColumn(tagField, enableCustomColumns));
    }
    var loadedColumns = props.loadColumnPreferences
        ? props.loadColumnPreferences()
        : loadColumnPreferences(columnStateRestorationKey);
    allColumns = applyColumnPreferences(allColumns, loadedColumns, tagField, enableCustomColumns);
    return allColumns;
};
var Table = (function (_super) {
    __extends(Table, _super);
    function Table(props) {
        var _this = _super.call(this, props) || this;
        _this.setColumnsAndSave = function (columns) { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.setColumns(columns)];
                    case 1:
                        _a.sent();
                        this.saveColumnPreferences(columns);
                        return [2];
                }
            });
        }); };
        _this.addTagColumn = function () {
            var _a = _this.state, tagKeys = _a.tagKeys, newTagColumnKeys = _a.newTagColumnKeys, allColumns = _a.allColumns, selectedTagColumnKeys = _a.selectedTagColumnKeys;
            if (!_this.props.tagField) {
                return;
            }
            if (allColumns.some(function (c) { return c.type === 'tag' && c.tagKey === undefined; })) {
                return;
            }
            var tagKey = newTagColumnKeys.length === 1 ? newTagColumnKeys[0] : undefined;
            var newColumnState = getNewTagTableColumnState(tagKey);
            var columns = allColumns.slice();
            var newTagColumn = getTagTableColumn(newColumnState, _this.props.tagField);
            _this.setTagTableColumnHeader({ tagKeys: tagKeys, selectedTagColumnKeys: selectedTagColumnKeys }, newTagColumn);
            insertTagColumns(columns, [newTagColumn]);
            _this.setColumnsAndSave(columns);
        };
        _this.configureTagColumn = function (column, tagKey) {
            if (!column || !tagKey || !_this.props.tagField) {
                return;
            }
            var indexOfColumn = _this.state.allColumns.indexOf(column);
            if (indexOfColumn < 0) {
                return;
            }
            var newColumn = getTagTableColumn(getNewTagTableColumnState(tagKey), _this.props.tagField);
            var columns = _this.state.allColumns.slice();
            columns.splice(indexOfColumn, 1, newColumn);
            _this.setColumnsAndSave(columns);
        };
        _this.onSort = function (sort) {
            if (_this.props.sortingStateRestorationKey) {
                saveSortingPreferences(_this.props.sortingStateRestorationKey, sort);
                _this.setState({
                    sort: sort,
                });
            }
            if (_this.props.onSort) {
                _this.props.onSort(sort);
            }
        };
        var allColumns = addCustomColumns(props);
        _this.state = _this.getNewStateSlice(allColumns, _this.props.data);
        return _this;
    }
    Table.prototype.componentWillReceiveProps = function (newProps) {
        var _this = this;
        if (this.props.data !== newProps.data ||
            this.props.columns !== newProps.columns) {
            var allColumns = this.state.allColumns;
            if (this.props.columns !== newProps.columns) {
                allColumns = addCustomColumns(newProps);
            }
            var newStateSlice_1 = this.getNewStateSlice(allColumns, newProps.data);
            var shouldSaveUpdatedColumns_1 = !isEqual(map(this.state.visibleColumns, 'key'), map(newStateSlice_1.visibleColumns, 'key'));
            this.setState(newStateSlice_1, function () {
                if (shouldSaveUpdatedColumns_1) {
                    _this.saveColumnPreferences(newStateSlice_1.allColumns);
                }
            });
        }
    };
    Table.prototype.getTagKeys = function (columns, data) {
        var _this = this;
        if (!this.props.tagField) {
            return {
                tagKeys: [],
                selectedTagColumnKeys: [],
                newTagColumnKeys: [],
            };
        }
        var tagKeys = uniq(flatMap(data, function (d) {
            return getResourceTags(d, _this.props.tagField) || [];
        }).map(function (t) { return t.tag_key; })).sort();
        var selectedTagColumnKeys = reduce(columns, function (acc, c) {
            if (c.type === 'tag' && c.tagKey) {
                acc.push(c.tagKey);
            }
            return acc;
        }, []);
        var newTagColumnKeys = without.apply(void 0, __spreadArrays([tagKeys], selectedTagColumnKeys));
        if (!this.state ||
            !isEqual(this.state.tagKeys, tagKeys) ||
            !isEqual(this.state.selectedTagColumnKeys, selectedTagColumnKeys) ||
            !isEqual(this.props.columns, columns)) {
            var addedFirstTag_1 = !!this.state && !this.state.tagKeys.length && tagKeys.length;
            columns = columns.map(function (c) {
                if (isCustomTagColumn(c)) {
                    _this.setTagTableColumnHeader({ tagKeys: tagKeys, selectedTagColumnKeys: selectedTagColumnKeys }, c);
                }
                else if (addedFirstTag_1 && c.key === TAGS_COLUMN_KEY && !c.selected) {
                    c.selected = true;
                }
                return c;
            });
        }
        return { tagKeys: tagKeys, selectedTagColumnKeys: selectedTagColumnKeys, newTagColumnKeys: newTagColumnKeys };
    };
    Table.prototype.getNewStateSlice = function (columns, data) {
        var visibleColumns = filter(columns, 'selected');
        var sort;
        if (this.state) {
            sort = this.state.sort;
        }
        else if (!this.props.sort && this.props.sortingStateRestorationKey) {
            var loadedSort_1 = loadSortingPreferences(this.props.sortingStateRestorationKey);
            if (loadedSort_1 &&
                visibleColumns.some(function (c) { return c.field === loadedSort_1.field; })) {
                sort = loadedSort_1;
            }
        }
        return __assign({ allColumns: columns, visibleColumns: visibleColumns,
            sort: sort }, this.getTagKeys(columns, data));
    };
    Table.prototype.setColumns = function (newColumns) {
        var _this = this;
        var newState = this.getNewStateSlice(newColumns.slice(), this.props.data);
        return new Promise(function (resolve) { return _this.setState(newState, resolve); });
    };
    Table.prototype.saveColumnPreferences = function (newColumns) {
        if (this.props.saveColumnPreferences) {
            this.props.saveColumnPreferences(newColumns);
        }
        else {
            saveColumnPreferences(this.props.columnStateRestorationKey, newColumns);
        }
    };
    Table.prototype.setTagTableColumnHeader = function (state, column) {
        column.label = (React.createElement(CustomColumnHeader, { columnInfo: column, items: state.tagKeys, disabledItems: state.selectedTagColumnKeys, label: "Tag", setColumn: this.configureTagColumn }));
    };
    Table.prototype.render = function () {
        var _a = this.props, columns = _a.columns, tagField = _a.tagField, sortingStateRestorationKey = _a.sortingStateRestorationKey, columnStateRestorationKey = _a.columnStateRestorationKey, loadColumnPreferences = _a.loadColumnPreferences, saveColumnPreferences = _a.saveColumnPreferences, sortProp = _a.sort, innerRef = _a.innerRef, onSort = _a.onSort, onRowClick = _a.onRowClick, props = __rest(_a, ["columns", "tagField", "sortingStateRestorationKey", "columnStateRestorationKey", "loadColumnPreferences", "saveColumnPreferences", "sort", "innerRef", "onSort", "onRowClick"]);
        var sort = sortProp || (sortingStateRestorationKey ? this.state.sort : undefined);
        return (React.createElement(Container, null,
            React.createElement(Flex, { flexDirection: "column", flex: "1", width: "100%" },
                React.createElement(TypedTable, __assign({ columns: this.state.visibleColumns, ref: innerRef, sort: sort, onSort: this.onSort, onRowClick: onRowClick }, props))),
            this.props.enableCustomColumns && (React.createElement(TableColumnSelectorSizer, { pagerPosition: props.pagerPosition },
                React.createElement(TableColumnSelector, { columns: this.state.allColumns, setColumns: this.setColumnsAndSave, addTagColumn: this.addTagColumn, tagKeys: tagField ? this.state.tagKeys : undefined })))));
    };
    return Table;
}(React.Component));
export { Table };
export { TableRow };
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;
