import { __assign, __makeTemplateObject } from "tslib";
import { faTrashAlt } from '@fortawesome/free-solid-svg-icons/faTrashAlt';
import { faUndo } from '@fortawesome/free-solid-svg-icons/faUndo';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import * as React from 'react';
import styled from 'styled-components';
import { stopKeyDownEvent, withPreventDefault } from '../../utils';
import { AddTagForm } from './AddTagForm';
import map from 'lodash/map';
import sortBy from 'lodash/sortBy';
import toString from 'lodash/toString';
import { faPencilAlt } from '@fortawesome/free-solid-svg-icons/faPencilAlt';
import { Heading } from '../Heading';
import { Modal } from '../Modal';
import { Flex } from '../Flex';
import { Input } from '../Input';
import { Button } from '../Button';
import { CollectionSummary } from './CollectionSummary/CollectionSummary';
import { useTranslation } from '../../hooks/useTranslation';
import { getResourceTagSubmitInfo, groupResourcesByTags, } from './tag-management-service';
import partition from 'lodash/partition';
var NBSP = '\u00a0';
var iconStyles = function (props) { return "\n\tfont-size: 14px;\n\tcolor: " + props.theme.colors.text.main + ";\n"; };
var FaPencil = function (props) { return (React.createElement(FontAwesomeIcon, __assign({ icon: faPencilAlt }, props))); };
var EditButtonIcon = styled(FaPencil)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t", " margin-left: 10px;\n"], ["\n\t", " margin-left: 10px;\n"])), iconStyles);
var FaTrashAlt = function (props) { return (React.createElement(FontAwesomeIcon, __assign({ icon: faTrashAlt }, props))); };
var DeleteButtonIcon = styled(FaTrashAlt)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t", ";\n"], ["\n\t", ";\n"])), iconStyles);
export var UndoButtonMinWidth = 100;
var UndoButton = styled(Button)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\twidth: ", "px;\n\ttext-align: left;\n"], ["\n\twidth: ", "px;\n\ttext-align: left;\n"])), UndoButtonMinWidth);
var InputPadder = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\tpadding-left: 17px;\n\tpadding-right: 17px;\n"], ["\n\tpadding-left: 17px;\n\tpadding-right: 17px;\n"])));
var TdThHorizontalPadding = 10;
var TagTable = styled.table(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n\twidth: 100%;\n\tmax-width: 100%;\n\tborder: none;\n\tborder-collapse: collapse;\n\tfont-size: 14px;\n\n\t& > thead > tr > th,\n\t& > thead > tr > td {\n\t\tpadding: 11px ", "px;\n\t}\n\n\t& > thead > tr > th {\n\t\theight: 42px;\n\t\tfont-size: 16px;\n\t\tfont-weight: bold;\n\t\tbackground-color: #f2f2f2;\n\t}\n\n\t& > tbody > tr > td {\n\t\tpadding: 8px ", "px;\n\t\theight: 50px;\n\t}\n\n\t& > tbody > tr:nth-of-type(even) {\n\t\tbackground-color: #f8f8f8;\n\t}\n\n\t& > thead > tr > th,\n\t& > tbody > tr > td {\n\t\tborder: none;\n\t\tvertical-align: middle;\n\t}\n"], ["\n\twidth: 100%;\n\tmax-width: 100%;\n\tborder: none;\n\tborder-collapse: collapse;\n\tfont-size: 14px;\n\n\t& > thead > tr > th,\n\t& > thead > tr > td {\n\t\tpadding: 11px ", "px;\n\t}\n\n\t& > thead > tr > th {\n\t\theight: 42px;\n\t\tfont-size: 16px;\n\t\tfont-weight: bold;\n\t\tbackground-color: #f2f2f2;\n\t}\n\n\t& > tbody > tr > td {\n\t\tpadding: 8px ", "px;\n\t\theight: 50px;\n\t}\n\n\t& > tbody > tr:nth-of-type(even) {\n\t\tbackground-color: #f8f8f8;\n\t}\n\n\t& > thead > tr > th,\n\t& > tbody > tr > td {\n\t\tborder: none;\n\t\tvertical-align: middle;\n\t}\n"])), TdThHorizontalPadding, TdThHorizontalPadding);
var TagTr = styled.tr(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n\t&:hover {\n\t\t", ", ", " {\n\t\t\topacity: 0.7;\n\t\t}\n\t}\n\n\t", ", ", " {\n\t\topacity: 0;\n\t\tcursor: pointer;\n\n\t\t&:hover {\n\t\t\topacity: 1;\n\t\t}\n\t}\n"], ["\n\t&:hover {\n\t\t", ", ", " {\n\t\t\topacity: 0.7;\n\t\t}\n\t}\n\n\t", ", ", " {\n\t\topacity: 0;\n\t\tcursor: pointer;\n\n\t\t&:hover {\n\t\t\topacity: 1;\n\t\t}\n\t}\n"])), DeleteButtonIcon, EditButtonIcon, DeleteButtonIcon, EditButtonIcon);
var TagDeleteTh = styled.th(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n\twidth: 36px;\n"], ["\n\twidth: 36px;\n"])));
var TagDeleteTd = styled(TagDeleteTh.withComponent('td'))(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n\ttable > tbody > tr > & {\n\t\tpadding-left: 11px;\n\t\tpadding-right: 11px;\n\t}\n"], ["\n\ttable > tbody > tr > & {\n\t\tpadding-left: 11px;\n\t\tpadding-right: 11px;\n\t}\n"])));
var TagPropertyTh = styled.th(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n\twidth: 30%;\n\tmax-width: 300px;\n\ttext-align: left;\n"], ["\n\twidth: 30%;\n\tmax-width: 300px;\n\ttext-align: left;\n"])));
var TagPropertyTd = TagPropertyTh.withComponent('td');
var TagKeyTd = styled(TagPropertyTd)(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n\tfont-weight: bold;\n\tcolor: ", ";\n"], ["\n\tfont-weight: bold;\n\tcolor: ",
    ";\n"])), function (props) {
    return props.state === 'added' ? props.theme.colors.warning.main : 'inherit';
});
var TagValueTd = styled(TagPropertyTd)(templateObject_11 || (templateObject_11 = __makeTemplateObject([""], [""])));
var TagProperty = styled.div(templateObject_12 || (templateObject_12 = __makeTemplateObject(["\n\tdisplay: flex;\n\tmax-width: 100%;\n\n\tcolor: ", ";\n\n\t& > ", " {\n\t\toverflow: hidden;\n\t\twhite-space: nowrap;\n\t\ttext-overflow: ellipsis;\n\t}\n"], ["\n\tdisplay: flex;\n\tmax-width: 100%;\n\n\tcolor: ",
    ";\n\n\t& > ", " {\n\t\toverflow: hidden;\n\t\twhite-space: nowrap;\n\t\ttext-overflow: ellipsis;\n\t}\n"])), function (props) {
    return props.state === 'added'
        ? props.theme.colors.warning.main
        : props.state === 'updated'
            ? props.theme.colors.warning.main
            : props.state === 'deleted'
                ? props.theme.colors.gray.main
                : 'inherit';
}, InputPadder);
var EdittableTagValue = styled(TagProperty)(templateObject_13 || (templateObject_13 = __makeTemplateObject(["\n\tdisplay: flex;\n\tcursor: pointer;\n\n\t& > ", " {\n\t\tdisplay: inline-flex;\n\t\talign-items: center;\n\t\tjustify-content: flex-start;\n\t\tmax-width: 100%;\n\t}\n"], ["\n\tdisplay: flex;\n\tcursor: pointer;\n\n\t& > ", " {\n\t\tdisplay: inline-flex;\n\t\talign-items: center;\n\t\tjustify-content: flex-start;\n\t\tmax-width: 100%;\n\t}\n"])), InputPadder);
var EdittableTagValueText = styled.div(templateObject_14 || (templateObject_14 = __makeTemplateObject(["\n\tflex: 1;\n\toverflow: hidden;\n\twhite-space: nowrap;\n\ttext-overflow: ellipsis;\n"], ["\n\tflex: 1;\n\toverflow: hidden;\n\twhite-space: nowrap;\n\ttext-overflow: ellipsis;\n"])));
var PreviousTagProperty = styled(TagProperty)(templateObject_15 || (templateObject_15 = __makeTemplateObject(["\n\tdisplay: inline-flex;\n\twidth: 100%;\n\tmargin-bottom: ", "px;\n\n\tposition: relative;\n\n\t&:after {\n\t\tcontent: '';\n\t\tposition: absolute;\n\t\tleft: 0;\n\t\tright: 0;\n\t\tdisplay: block;\n\t\tbackground: ", ";\n\t\theight: 2px;\n\t\ttop: 50%;\n\t}\n\n\t", " > &, ", " > & {\n\t\tcolor: ", ";\n\t}\n\n\t", " > &:after {\n\t\tright: ", "px;\n\t}\n\n\t", " > & {\n\t\twidth: auto;\n\t\t&:after {\n\t\t\tleft: ", "px;\n\t\t}\n\t}\n"], ["\n\tdisplay: inline-flex;\n\twidth: 100%;\n\tmargin-bottom: ", "px;\n\n\tposition: relative;\n\n\t&:after {\n\t\tcontent: '';\n\t\tposition: absolute;\n\t\tleft: 0;\n\t\tright: 0;\n\t\tdisplay: block;\n\t\tbackground: ", ";\n\t\theight: 2px;\n\t\ttop: 50%;\n\t}\n\n\t", " > &, ", " > & {\n\t\tcolor: ", ";\n\t}\n\n\t", " > &:after {\n\t\tright: ", "px;\n\t}\n\n\t", " > & {\n\t\twidth: auto;\n\t\t&:after {\n\t\t\tleft: ", "px;\n\t\t}\n\t}\n"])), function (props) { return (props.state === 'deleted' ? 0 : 6); }, function (props) { return props.theme.colors.warning.main; }, TagKeyTd, TagValueTd, function (props) { return props.theme.colors.gray.main; }, TagKeyTd, -TdThHorizontalPadding, TagValueTd, -TdThHorizontalPadding);
var TagUndoChangedTh = styled.th(templateObject_16 || (templateObject_16 = __makeTemplateObject(["\n\tmin-width: ", "px;\n"], ["\n\tmin-width: ", "px;\n"])), UndoButtonMinWidth);
var TagUndoChangedTd = styled(TagUndoChangedTh.withComponent('td'))(templateObject_17 || (templateObject_17 = __makeTemplateObject(["\n\ttext-align: right;\n"], ["\n\ttext-align: right;\n"])));
export var TagManagementModal = function (_a) {
    var items = _a.items, itemType = _a.itemType, titleField = _a.titleField, tagField = _a.tagField, cancel = _a.cancel, done = _a.done;
    var t = useTranslation().t;
    var _b = React.useState(undefined), editingTag = _b[0], setEditingTag = _b[1];
    var _c = React.useState(), tags = _c[0], setTags = _c[1];
    var _d = React.useState(), partialTags = _d[0], setPartialTags = _d[1];
    var tagDiffs = React.useMemo(function () { return getResourceTagSubmitInfo(tags || []); }, [tags]);
    React.useEffect(function () {
        var allTags = groupResourcesByTags(items, tagField);
        var _a = partition(allTags, function (t) { return t.items.length === items.length; }), commonTags = _a[0], $partialTags = _a[1];
        setTags(commonTags);
        setPartialTags($partialTags);
    }, [items.length > 0]);
    if (!tags || !partialTags) {
        return null;
    }
    var addTag = function (tag) {
        var slicedTags = tags.slice();
        var existingDeletedTag = slicedTags.find(function (existingTag) {
            return existingTag.state === 'deleted' && existingTag.tag_key === tag.tag_key;
        });
        if (existingDeletedTag) {
            existingDeletedTag.initialValue = existingDeletedTag.value;
            existingDeletedTag.value = tag.value;
            existingDeletedTag.state = 'updated';
        }
        else {
            var newTag = {
                tag_key: tag.tag_key,
                value: tag.value,
                items: items.slice(),
                state: 'added',
            };
            slicedTags.push(newTag);
            slicedTags = sortBy(slicedTags, 'tag_key');
        }
        setEditingTag(undefined);
        setTags(slicedTags);
    };
    var undoTagChanges = function (tag) {
        if (tag.state === 'added') {
            setTags(tags.filter(function (t) { return t !== tag; }));
            return;
        }
        if (tag.state === 'updated') {
            tag.value = tag.initialValue || '';
            tag.state = undefined;
        }
        if (tag.state === 'deleted') {
            tag.state = undefined;
        }
        setTags(tags.slice());
    };
    var startTagEdit = function (tag) {
        if (tag && tag.initialValue === undefined) {
            tag.initialValue = tag.value || '';
        }
        setEditingTag(tag);
    };
    var endTagEdit = function () {
        if (editingTag) {
            var tagKey_1 = editingTag.tag_key;
            var newTags = tags.map(function (tag) {
                return tag.tag_key === tagKey_1 ? editingTag : tag;
            });
            setTags(newTags);
        }
        setEditingTag(undefined);
    };
    var setEditingTagValue = function (value) {
        if (!editingTag) {
            return;
        }
        var newTag = __assign({}, editingTag);
        newTag.value = value;
        if (!newTag.state && newTag.initialValue !== value) {
            newTag.state = 'updated';
        }
        setEditingTag(newTag);
    };
    var deleteTag = function (tag) {
        if (tag.state === 'added') {
            setTags(tags.filter(function (t) { return t !== tag; }));
            return;
        }
        tag.state = 'deleted';
        setTags(tags.slice());
    };
    var getItemTitle = function (item) {
        var title = typeof titleField === 'function'
            ? titleField(item)
            : toString(item[titleField]);
        return title || "(" + t('no_data.no_name_set') + ")";
    };
    return (React.createElement(Modal, { width: 1000, titleElement: React.createElement("div", null,
            React.createElement(Heading.h3, { mt: 0, mb: 10 },
                items.length > 1 && React.createElement("span", null,
                    t('labels.shared'),
                    " "),
                t('labels.tags')),
            React.createElement(CollectionSummary, { items: items.map(getItemTitle).sort(), itemsType: t('resource.' + itemType, { count: items.length }), maxVisibleItemCount: 10 })), cancel: cancel, done: withPreventDefault(function () { return done(tagDiffs); }), action: t("actions.apply_item_type_count", {
            count: items.length,
            itemType: t('labels.' + itemType, {
                count: items.length,
            }).toLowerCase(),
        }), primaryButtonProps: {
            disabled: Object.values(tagDiffs).filter(function (changedTags) { return changedTags.length > 0; }).length === 0
                ? true
                : false,
        } },
        React.createElement(Flex, null,
            React.createElement(TagTable, null,
                React.createElement(AddTagForm, { itemType: itemType, existingTags: tags, overwritableTags: partialTags, addTag: addTag, t: t }),
                React.createElement("thead", null,
                    React.createElement("tr", null,
                        React.createElement(TagDeleteTh, null),
                        React.createElement(TagPropertyTh, null,
                            React.createElement(InputPadder, null, t('labels.tag_name'))),
                        React.createElement(TagPropertyTh, null,
                            React.createElement(InputPadder, null, t('labels.value'))),
                        React.createElement(TagUndoChangedTh, null))),
                React.createElement("tbody", null, !tags.length ? (React.createElement("tr", null,
                    React.createElement("td", null),
                    React.createElement("td", { colSpan: 3 },
                        React.createElement(InputPadder, null, t("errors.no_tags_for_selected_itemtype", {
                            count: items.length,
                            itemType: itemType,
                        }))))) : (map(tags, function (tag) {
                    var showPreviousTagProperties = (editingTag === null || editingTag === void 0 ? void 0 : editingTag.tag_key) !== tag.tag_key &&
                        (tag.state === 'deleted' || tag.state === 'updated');
                    return (React.createElement(TagTr, __assign({ key: tag.tag_key }, tag),
                        React.createElement(TagDeleteTd, null, tag.state !== 'deleted' && (React.createElement(Flex, { alignItems: "center" },
                            React.createElement(DeleteButtonIcon, { onClick: function () { return deleteTag(tag); } })))),
                        React.createElement(TagKeyTd, { state: tag.state },
                            showPreviousTagProperties && (React.createElement(PreviousTagProperty, { state: tag.state },
                                React.createElement(InputPadder, null, tag.tag_key))),
                            tag.state !== 'deleted' && (React.createElement(TagProperty, { state: tag.state },
                                React.createElement(InputPadder, null, tag.tag_key)))),
                        React.createElement(TagValueTd, null,
                            showPreviousTagProperties && (React.createElement(PreviousTagProperty, { state: tag.state },
                                React.createElement(InputPadder, null, tag.value || NBSP))),
                            (editingTag === null || editingTag === void 0 ? void 0 : editingTag.tag_key) !== tag.tag_key &&
                                tag.state !== 'deleted' && (React.createElement(EdittableTagValue, { state: tag.state, onClick: function () { return startTagEdit(tag); } },
                                React.createElement(InputPadder, null,
                                    React.createElement(EdittableTagValueText, null, tag.value || NBSP),
                                    React.createElement(EditButtonIcon, null)))),
                            (editingTag === null || editingTag === void 0 ? void 0 : editingTag.tag_key) === tag.tag_key && (React.createElement(Input, { width: "100%", autoFocus: true, onKeyDown: function (e) { return stopKeyDownEvent(e, 13, endTagEdit); }, onFocus: function (e) {
                                    var target = e.target;
                                    var len = (target.value || '').length;
                                    if (len) {
                                        target.setSelectionRange(len, len);
                                    }
                                }, onChange: function (e) { return setEditingTagValue(e.target.value); }, onBlur: function () { return endTagEdit(); }, value: editingTag.value, placeholder: t('labels.tag_value') }))),
                        React.createElement(TagUndoChangedTd, null, tag.state && (React.createElement(Flex, { alignItems: "center", justifyContent: "flex-end" },
                            React.createElement(UndoButton, { plain: true, primary: true, icon: React.createElement(FontAwesomeIcon, { icon: faUndo }), onClick: function () { return undoTagChanges(tag); } },
                                React.createElement("span", null, tag.state === 'added'
                                    ? t('actions.undo_add')
                                    : tag.state === 'updated'
                                        ? t('actions.undo_edit')
                                        : t('actions.undo_delete'))))))));
                })))))));
};
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9, templateObject_10, templateObject_11, templateObject_12, templateObject_13, templateObject_14, templateObject_15, templateObject_16, templateObject_17;
