import keys from 'lodash/keys';
import flatMap from 'lodash/flatMap';
import map from 'lodash/map';
import groupBy from 'lodash/groupBy';
export var TAGS_COLUMN_KEY = 'Tags';
export var getTagKeyValueComposite = function (tagKey, value) {
    return tagKey + ": " + value;
};
export var getResourceTags = function (item, tagField) { var _a; return ((_a = (tagField in item ? item[tagField] : null)) !== null && _a !== void 0 ? _a : []); };
export var groupResourcesByTags = function (items, tagField) {
    var resourceTagInfos = flatMap(items, function (item) {
        var tags = getResourceTags(item, tagField);
        return tags.map(function (tag) { return ({
            tag_key_value: getTagKeyValueComposite(tag.tag_key, tag.value),
            tag_key: tag.tag_key,
            value: tag.value,
            item: item,
        }); });
    });
    var tagsByTagKeyValue = groupBy(resourceTagInfos, 'tag_key_value');
    var tagsWithItems = map(keys(tagsByTagKeyValue).sort(), function (tagKeyValue) {
        var tags = tagsByTagKeyValue[tagKeyValue];
        var firstTag = tags[0];
        return {
            tag_key: firstTag.tag_key,
            value: firstTag.value,
            items: map(tags, 'item'),
        };
    });
    return tagsWithItems;
};
export var getResourceTagSubmitInfo = function (tags) {
    var submitInfo = {
        added: [],
        updated: [],
        deleted: [],
    };
    tags.forEach(function (tag) {
        if (tag.state && tag.state in submitInfo) {
            Array.prototype.push.apply(submitInfo[tag.state], tag.items.map(function (item) { return ({
                resourceId: item.id,
                tag_key: tag.tag_key,
                value: tag.value,
            }); }));
        }
    });
    return submitInfo;
};
