import { __assign, __extends } from "tslib";
import * as React from 'react';
import { createTemplate, createStory } from '../../stories/utils';
import { Terminal } from '.';
import { output1 } from '../../stories/assets/tty-output';
import { Repl } from '../../stories/assets/repl';
var outputArray = output1.split('\n');
var Logger = (function (_super) {
    __extends(Logger, _super);
    function Logger(props) {
        var _this = _super.call(this, props) || this;
        _this.lines = outputArray.slice();
        return _this;
    }
    Logger.prototype.componentDidMount = function () {
        var _this = this;
        this.interval = setInterval(function () {
            if (!_this.term) {
                return;
            }
            if (_this.lines.length) {
                _this.term.writeln(_this.lines.shift());
            }
            else {
                window.clearInterval(_this.interval);
                _this.interval = null;
            }
        }, 300);
    };
    Logger.prototype.componentWillUnmount = function () {
        if (this.interval) {
            window.clearInterval(this.interval);
        }
    };
    Logger.prototype.render = function () {
        var _this = this;
        return (React.createElement(Terminal, __assign({ ref: function (term) { return (_this.term = term); } }, this.props.termProps)));
    };
    return Logger;
}(React.Component));
var InteractiveTerm = (function (_super) {
    __extends(InteractiveTerm, _super);
    function InteractiveTerm(props) {
        var _this = _super.call(this, props) || this;
        _this.input = '';
        return _this;
    }
    InteractiveTerm.prototype.componentDidMount = function () {
        var _this = this;
        setTimeout(function () {
            _this.term.tty.setOption('bellStyle', 'visual');
        }, 2000);
        if (!this.props.ttyInstance) {
            this.term.tty._repl = new Repl(function (line) {
                if (_this.term.tty) {
                    _this.term.writeln(line);
                    _this.term.tty.prompt();
                }
            });
            this.term.tty.prompt = function () {
                _this.term.tty.write('\u001b[33m$ \u001b[0m');
            };
            this.term.tty.writeln('\u001b[32mThis is a basic interactive representation of a web browser javascript console\u001b[0m');
            this.term.tty.writeln('\u001b[32mType some keys and commands to play around\u001b[0m');
            this.term.tty.prompt();
            this.term.tty.onKey(function (_a) {
                var key = _a.key, domEvent = _a.domEvent;
                var printable = !domEvent.altKey &&
                    !domEvent.altGraphKey &&
                    !domEvent.ctrlKey &&
                    !domEvent.metaKey;
                if (domEvent.code === 'ArrowUp' || domEvent.code === 'ArrowDown') {
                    return;
                }
                if (domEvent.keyCode === 13) {
                    _this.term.write('\r\n');
                    _this.term.tty._repl.process(_this.input);
                    _this.input = '';
                }
                else if (domEvent.keyCode === 8) {
                    if (_this.term.tty.buffer.active.cursorX > 2) {
                        _this.term.tty.write('\b \b');
                        _this.input = _this.input.slice(0, -1);
                    }
                }
                else if (printable) {
                    _this.input += key;
                    _this.term.tty.write(key);
                }
            });
        }
        else {
            this.term = this.props.ttyInstance;
        }
    };
    InteractiveTerm.prototype.componentWillUnmount = function () {
        if (!this.props.persistent) {
            this.term.tty._repl.destroy();
        }
    };
    InteractiveTerm.prototype.render = function () {
        var _this = this;
        return (React.createElement(Terminal, __assign({ ref: function (term) { return (_this.term = term); } }, this.props.termProps)));
    };
    return InteractiveTerm;
}(React.Component));
export default {
    title: 'Core/Terminal',
    component: Terminal,
    decorators: [
        function (Story) { return (React.createElement("div", { style: { height: 500 } },
            React.createElement(Story, null))); },
    ],
};
var InteractiveTermTemplate = createTemplate(InteractiveTerm);
export var Default = createStory(InteractiveTermTemplate, {});
var NoninteractiveTermTemplate = createTemplate(Logger);
export var NoninteractiveTerminal = createStory(NoninteractiveTermTemplate, {
    nonInteractive: true,
});
