import { __assign } from "tslib";
import { mount } from 'enzyme';
import noop from 'lodash/noop';
import React from 'react';
import { Provider, Textarea } from '../../';
describe('Textarea component', function () {
    it('should accept and display a value', function () {
        var value = 'lorem ipsum dolor sit amet';
        var component = mount(React.createElement(Provider, null,
            React.createElement(Textarea, { value: value, onChange: noop })));
        expect(component.text()).toEqual(value);
    });
    describe('autoRows property', function () {
        var lines = [
            'lorem ipsum dolor sit amet',
            'consectetur adipiscing elit',
            'mauris dui nulla',
            'volutpat et commodo eu',
            'pellentesque a risus',
            'vivamus iaculis consectetur nulla vel laoreet',
        ];
        var value = lines.join('\n');
        it('should resize the textarea to match the content', function () {
            var component = mount(React.createElement(function (props) { return (React.createElement(Provider, null,
                React.createElement(Textarea, __assign({}, props)))); }, { autoRows: true, value: value, onChange: noop }));
            expect(component.text()).toEqual(value);
            var rows = component.find('textarea').prop('rows');
            expect(rows).toEqual(lines.length);
            var newLines = lines.slice();
            newLines.push('duis fermentum cursus accumsan');
            var newValue = newLines.join('\n');
            component.setProps({ value: newValue });
            component.update();
            expect(component.text()).toEqual(newValue);
            var newRows = component.find('textarea').prop('rows');
            expect(newRows).toEqual(newLines.length);
        });
        it('should respect the maxRows property', function () {
            var maxRows = Math.ceil(lines.length / 2);
            var component = mount(React.createElement(Provider, null,
                React.createElement(Textarea, { autoRows: true, maxRows: maxRows, value: value, onChange: noop })));
            expect(component.text()).toEqual(value);
            var rows = component.find('textarea').prop('rows');
            expect(rows).toEqual(maxRows);
        });
        it('should respect the minRows property', function () {
            var minRows = lines.length * 2;
            var component = mount(React.createElement(Provider, null,
                React.createElement(Textarea, { autoRows: true, minRows: minRows, value: value, onChange: noop })));
            expect(component.text()).toEqual(value);
            var rows = component.find('textarea').prop('rows');
            expect(rows).toEqual(minRows);
        });
    });
    describe('maxRows property', function () {
        it('should not allow a row property larger than maxRows', function () {
            var maxRows = 4;
            var rows = maxRows * 2;
            var component = mount(React.createElement(Provider, null,
                React.createElement(Textarea, { rows: rows, maxRows: maxRows })));
            var realRows = component.find('textarea').prop('rows');
            expect(realRows).toEqual(maxRows);
        });
    });
    describe('minRows property', function () {
        it('should not allow a row property smaller than minRows', function () {
            var minRows = 8;
            var rows = Math.ceil(minRows / 2);
            var component = mount(React.createElement(Provider, null,
                React.createElement(Textarea, { rows: rows, minRows: minRows })));
            var realRows = component.find('textarea').prop('rows');
            expect(realRows).toEqual(minRows);
        });
    });
});
