import { __assign, __rest } from "tslib";
import * as React from 'react';
import filter from 'lodash/filter';
import qs from 'qs';
import { Filters, } from '../../../components/Filters';
import { createFilter, createFullTextSearchFilter, decodeFilter, flattenSchema, FULL_TEXT_SLUG, } from '../../../components/Filters/SchemaSieve';
import { getFromLocalStorage, setToLocalStorage } from '../../../utils';
var isListQueryStringFilterRule = function (rule) {
    return rule != null &&
        typeof rule === 'object' &&
        !!rule.n &&
        typeof rule.n === 'string' &&
        ((!!rule.o && typeof rule.o === 'string') ||
            !!rule.v);
};
var isQueryStringFilterRuleset = function (rule) {
    return Array.isArray(rule) &&
        !!(rule === null || rule === void 0 ? void 0 : rule.length) && (rule === null || rule === void 0 ? void 0 : rule.every(isListQueryStringFilterRule));
};
var listFilterQuery = function (schema, rules) {
    var queryStringFilters = rules.map(function (filter) {
        var flatSchema = flattenSchema(schema);
        var flattenFilter = flattenSchema(filter);
        var signatures = decodeFilter(flatSchema, flattenFilter);
        return signatures.map(function (_a) {
            var field = _a.field, operator = _a.operator, value = _a.value;
            return ({
                n: field,
                o: operator,
                v: value,
            });
        });
    });
    return qs.stringify(queryStringFilters);
};
var loadRulesFromUrl = function (searchLocation, schema) {
    if (!searchLocation) {
        return [];
    }
    var parsed = qs.parse(searchLocation, { ignoreQueryPrefix: true }) || {};
    var rules = filter(parsed, isQueryStringFilterRuleset).map(function (rules) {
        if (!Array.isArray(rules)) {
            rules = [rules];
        }
        var signatures = rules.map(function (_a) {
            var n = _a.n, o = _a.o, v = _a.v;
            return ({
                field: n,
                operator: o,
                value: v,
            });
        });
        if (signatures[0].operator === FULL_TEXT_SLUG) {
            return createFullTextSearchFilter(schema, signatures[0].value);
        }
        return createFilter(schema, signatures);
    });
    return rules;
};
export var PersistentFilters = function (_a) {
    var _b, _c;
    var schema = _a.schema, views = _a.views, filters = _a.filters, onViewsUpdate = _a.onViewsUpdate, onFiltersUpdate = _a.onFiltersUpdate, viewsRestorationKey = _a.viewsRestorationKey, history = _a.history, onSearch = _a.onSearch, otherProps = __rest(_a, ["schema", "views", "filters", "onViewsUpdate", "onFiltersUpdate", "viewsRestorationKey", "history", "onSearch"]);
    var storedViews = React.useMemo(function () { var _a; return (_a = getFromLocalStorage(viewsRestorationKey)) !== null && _a !== void 0 ? _a : []; }, [viewsRestorationKey]);
    var locationSearch = (_c = (_b = history === null || history === void 0 ? void 0 : history.location) === null || _b === void 0 ? void 0 : _b.search) !== null && _c !== void 0 ? _c : '';
    var storedFilters = React.useMemo(function () {
        return loadRulesFromUrl(locationSearch, schema);
    }, [locationSearch, schema]);
    React.useEffect(function () {
        if (!(views === null || views === void 0 ? void 0 : views.length) && storedViews.length && onViewsUpdate) {
            onViewsUpdate(storedViews);
        }
    }, []);
    var updateUrl = function (filters) {
        var _a;
        var pathname = window.location.pathname;
        (_a = history === null || history === void 0 ? void 0 : history.replace) === null || _a === void 0 ? void 0 : _a.call(history, {
            pathname: pathname,
            search: listFilterQuery(schema, filters),
        });
    };
    React.useEffect(function () {
        onFiltersUpdate === null || onFiltersUpdate === void 0 ? void 0 : onFiltersUpdate(storedFilters);
    }, [storedFilters]);
    var viewsUpdate = function (views) {
        setToLocalStorage(viewsRestorationKey, views);
        if (onViewsUpdate) {
            onViewsUpdate(views);
        }
    };
    var filtersUpdate = function (filters) {
        updateUrl(filters);
        if (onFiltersUpdate) {
            onFiltersUpdate(filters);
        }
    };
    return (React.createElement(Filters, __assign({ schema: schema, filters: filters !== null && filters !== void 0 ? filters : storedFilters, views: views !== null && views !== void 0 ? views : storedViews, onFiltersUpdate: filtersUpdate, onViewsUpdate: viewsUpdate }, otherProps, { onSearch: onSearch })));
};
