import groupBy from 'lodash/groupBy';
import sortBy from 'lodash/sortBy';
import find from 'lodash/find';
import first from 'lodash/first';
import flatten from 'lodash/flatten';
import values from 'lodash/values';
import skhema from 'skhema';
import jsone from 'json-e';
import * as types from './types';
import map from 'lodash/map';
import uniq from 'lodash/uniq';
var lenses = Object.values(types);
export var getLenses = function (data, context, customLenses) {
    if (context === void 0) { context = {}; }
    if (!data) {
        return [];
    }
    var filteredLenses = lenses.concat(customLenses !== null && customLenses !== void 0 ? customLenses : []);
    var slugs = filteredLenses.map(function (lens) { return lens.slug; });
    if (slugs.length > uniq(slugs).length) {
        throw new Error('Lenses must have unique slugs');
    }
    var sortedData = filteredLenses
        .map(function (lens) {
        var filter = jsone(lens.data.filter, context);
        return {
            lens: lens,
            match: skhema.match(filter, data),
        };
    })
        .filter(function (value) { return value.match.valid; });
    sortedData = flatten(values(map(groupBy(sortedData, 'lens.data.format'), function (group) {
        return group.reduce(function (prev, current) {
            if (current.match.score > prev.match.score) {
                return current;
            }
            else {
                return prev;
            }
        });
    })));
    return sortBy(sortedData, 'match.score')
        .reverse()
        .map(function (value) { return value.lens; });
};
export var getLens = function (data, context) {
    return first(getLenses(data, context));
};
export var getLensBySlug = function (slug) {
    var fullList = flatten(values(lenses));
    return (find(fullList, {
        slug: slug,
    }) || null);
};
export var getLensForTarget = function (target) {
    return find(lenses, function (lens) {
        return (lens.data.pathRegExp && new RegExp(lens.data.pathRegExp).test(target));
    });
};
