import { __assign, __makeTemplateObject, __rest, __spreadArrays } from "tslib";
import React from 'react';
import { getFieldForFormat, autoUIJsonSchemaPick, } from './schemaOps';
import { getLenses } from './Lenses';
import { getFromLocalStorage, setToLocalStorage } from '../../utils';
import { LensSelection } from './Lenses/LensSelection';
import styled from 'styled-components';
import { Flex } from '../../components/Flex';
import { filter } from '../../components/Filters/SchemaSieve';
import isEqual from 'lodash/isEqual';
import { Spinner } from '../../components/Spinner';
import { useTranslation } from '../../hooks/useTranslation';
import { NoRecordsFoundArrow } from './NoRecordsFoundArrow';
import { useHistory } from '../../hooks/useHistory';
import { Filters } from './Filters/Filters';
import { Box } from '../../components/Box';
import { Tags } from './Actions/Tags';
import { Update } from './Actions/Update';
import { Create } from './Actions/Create';
import { autoUIAdaptRefScheme, autoUIAddToSchema, autoUIDefaultPermissions, autoUIGetModelForCollection, autoUIRunTransformers, } from './models/helpers';
import { autoUIGetDisabledReason, getTagsDisabledReason } from './utils';
import { FocusSearch } from './Filters/FocusSearch';
import { getSelected, getSortingFunction } from './utils';
import { CustomWidget } from './CustomWidget';
import { defaultFormats } from '../../components/Renderer/widgets';
var HeaderGrid = styled(Flex)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t> * {\n\t\t&:first-child {\n\t\t\tmargin-right: 4px;\n\t\t}\n\t\t&:not(:last-child):not(:first-child) {\n\t\t\tmargin-left: 4px;\n\t\t\tmargin-right: 4px;\n\t\t}\n\t\t&:last-child {\n\t\t\tmargin-left: 4px;\n\t\t}\n\t}\n"], ["\n\t> * {\n\t\t&:first-child {\n\t\t\tmargin-right: 4px;\n\t\t}\n\t\t&:not(:last-child):not(:first-child) {\n\t\t\tmargin-left: 4px;\n\t\t\tmargin-right: 4px;\n\t\t}\n\t\t&:last-child {\n\t\t\tmargin-left: 4px;\n\t\t}\n\t}\n"])));
export var AutoUI = function (_a) {
    var _b;
    var modelRaw = _a.model, data = _a.data, formats = _a.formats, actions = _a.actions, sdk = _a.sdk, customSort = _a.customSort, refresh = _a.refresh, getBaseUrl = _a.getBaseUrl, onEntityClick = _a.onEntityClick, onChange = _a.onChange, customLenses = _a.customLenses, lensContext = _a.lensContext, boxProps = __rest(_a, ["model", "data", "formats", "actions", "sdk", "customSort", "refresh", "getBaseUrl", "onEntityClick", "onChange", "customLenses", "lensContext"]);
    var t = useTranslation().t;
    var history = useHistory();
    var modelRef = React.useRef(modelRaw);
    var model = React.useMemo(function () {
        if (isEqual(modelRaw, modelRef.current)) {
            return modelRef.current;
        }
        return modelRaw;
    }, [modelRaw]);
    var _c = React.useState([]), filters = _c[0], setFilters = _c[1];
    var _d = React.useState([]), views = _d[0], setViews = _d[1];
    var _e = React.useState([]), selected = _e[0], $setSelected = _e[1];
    var _f = React.useState(), isBusyMessage = _f[0], setIsBusyMessage = _f[1];
    var _g = React.useState(), actionData = _g[0], setActionData = _g[1];
    var setSelected = React.useCallback(function (items) {
        $setSelected(items);
        if (!!actionData) {
            setActionData(__assign(__assign({}, actionData), { affectedEntries: items }));
        }
    }, [$setSelected, setActionData, actionData]);
    var showFilters = React.useMemo(function () { return Array.isArray(data) && !!((data === null || data === void 0 ? void 0 : data.length) && data.length > 0); }, [data]);
    var filtered = React.useMemo(function () { return (Array.isArray(data) ? filter(filters, data) : []); }, [data, filters]);
    React.useEffect(function () {
        setSelected([]);
    }, [filters]);
    var onActionTriggered = React.useCallback(function (actionData) {
        setActionData(actionData);
        if (actionData.action.actionFn) {
            actionData.action.actionFn({
                affectedEntries: actionData.affectedEntries || [],
            });
        }
    }, []);
    var defaultLensSlug = getFromLocalStorage(model.resource + "__view_lens");
    var lenses = React.useMemo(function () { return getLenses(data, lensContext, customLenses); }, [data, lensContext, customLenses]);
    var _h = React.useState(lenses[0]), lens = _h[0], setLens = _h[1];
    React.useEffect(function () {
        var foundLens = lenses.find(function (lens) { return (lens === null || lens === void 0 ? void 0 : lens.slug) === defaultLensSlug; }) || lenses[0];
        if ((lens === null || lens === void 0 ? void 0 : lens.slug) === (foundLens === null || foundLens === void 0 ? void 0 : foundLens.slug)) {
            return;
        }
        setLens(foundLens);
    }, [lenses]);
    var lensRendererOnEntityClick = React.useCallback(function (row, event) {
        var _a;
        onEntityClick === null || onEntityClick === void 0 ? void 0 : onEntityClick(row, event);
        if (event.isPropagationStopped() && event.isDefaultPrevented()) {
            return;
        }
        if (getBaseUrl && !event.ctrlKey && !event.metaKey && history) {
            event.preventDefault();
            try {
                var url = new URL(getBaseUrl(row));
                window.open(url.toString(), '_blank');
            }
            catch (err) {
                (_a = history.push) === null || _a === void 0 ? void 0 : _a.call(history, getBaseUrl(row));
            }
        }
    }, [onEntityClick, getBaseUrl, history]);
    var autouiContext = React.useMemo(function () {
        var _a, _b;
        var tagField = getFieldForFormat(model.schema, 'tag');
        var tagsAction = !!(sdk === null || sdk === void 0 ? void 0 : sdk.tags)
            ? {
                title: t('actions.manage_tags'),
                type: 'update',
                renderer: function (_a) {
                    var affectedEntries = _a.affectedEntries, onDone = _a.onDone;
                    return !!affectedEntries && (React.createElement(Tags, { selected: affectedEntries, autouiContext: autouiContext, onDone: onDone, setIsBusyMessage: setIsBusyMessage, refresh: refresh }));
                },
                isDisabled: function (_a) {
                    var affectedEntries = _a.affectedEntries;
                    return !!affectedEntries &&
                        getTagsDisabledReason(affectedEntries, tagField, t);
                },
            }
            : null;
        return {
            resource: model.resource,
            idField: 'id',
            nameField: (_b = (_a = model.priorities) === null || _a === void 0 ? void 0 : _a.primary[0]) !== null && _b !== void 0 ? _b : 'id',
            tagField: tagField,
            getBaseUrl: getBaseUrl,
            onEntityClick: onEntityClick,
            actions: !!tagsAction ? (actions || []).concat(tagsAction) : actions,
            customSort: customSort,
            sdk: sdk,
        };
    }, [model, getBaseUrl, onEntityClick, actions, customSort, sdk]);
    var properties = React.useMemo(function () {
        return getColumnsFromSchema({
            schema: model.schema,
            idField: autouiContext.idField,
            tagField: autouiContext.tagField,
            customSort: autouiContext.customSort,
            priorities: model.priorities,
            formats: formats,
        });
    }, [
        model.schema,
        autouiContext.idField,
        autouiContext.tagField,
        autouiContext.customSort,
        model.priorities,
    ]);
    var hasUpdateActions = React.useMemo(function () {
        var _a;
        return !!((_a = actions === null || actions === void 0 ? void 0 : actions.filter(function (action) { return action.type !== 'create'; })) === null || _a === void 0 ? void 0 : _a.length) ||
            !!(sdk === null || sdk === void 0 ? void 0 : sdk.tags);
    }, [actions, sdk === null || sdk === void 0 ? void 0 : sdk.tags]);
    return (React.createElement(Flex, __assign({ flex: 1, flexDirection: "column" }, boxProps),
        React.createElement(Spinner, { flex: 1, label: isBusyMessage !== null && isBusyMessage !== void 0 ? isBusyMessage : t('loading.resource', {
                resource: t("resource." + model.resource + "_plural").toLowerCase(),
            }), show: data == null || !!isBusyMessage },
            React.createElement(Flex, { height: "100%", flexDirection: "column" },
                Array.isArray(data) && (React.createElement(React.Fragment, null,
                    React.createElement(Box, { mb: 3 },
                        React.createElement(HeaderGrid, { flexWrap: "wrap", justifyContent: "space-between", alignItems: "baseline" },
                            React.createElement(Create, { model: model, autouiContext: autouiContext, hasOngoingAction: false, onActionTriggered: onActionTriggered }),
                            data.length > 0 && (React.createElement(Update, { model: model, selected: selected, autouiContext: autouiContext, hasOngoingAction: false, onActionTriggered: onActionTriggered })),
                            showFilters && (React.createElement(Box, { order: [-1, -1, -1, 0], flex: ['1 0 100%', '1 0 100%', '1 0 100%', 'auto'], alignSelf: "flex-start", mb: 2 },
                                React.createElement(Filters, { schema: model.schema, filters: filters, views: views, autouiContext: autouiContext, changeFilters: function (updatedFilters) {
                                        setFilters(updatedFilters);
                                        if (onChange) {
                                            onChange({
                                                filters: updatedFilters,
                                            });
                                        }
                                    }, changeViews: setViews, onSearch: function (term) { return (React.createElement(FocusSearch, { searchTerm: term, filtered: filtered, selected: selected, setSelected: setSelected, autouiContext: autouiContext, model: model, hasUpdateActions: hasUpdateActions })); } }))),
                            data.length > 0 && (React.createElement(LensSelection, { lenses: lenses, lens: lens, setLens: function (lens) {
                                    setLens(lens);
                                    setToLocalStorage(model.resource + "__view_lens", lens.slug);
                                } }))),
                        filters.length > 0 && (React.createElement(Filters, { renderMode: 'summary', schema: model.schema, filters: filters, views: views, autouiContext: autouiContext, changeFilters: setFilters, changeViews: setViews }))),
                    data.length === 0 && (React.createElement(NoRecordsFoundArrow, null,
                        t("no_data.no_resource_data", {
                            resource: t("resource.item_plural").toLowerCase(),
                        }),
                        React.createElement("br", null),
                        t('questions.how_about_adding_one'))))),
                !Array.isArray(data) && (React.createElement(HeaderGrid, null,
                    React.createElement(LensSelection, { lenses: lenses, lens: lens, setLens: function (lens) {
                            setLens(lens);
                            setToLocalStorage(model.resource + "__view_lens", lens.slug);
                        } }))),
                lens &&
                    data &&
                    (!Array.isArray(data) ||
                        (Array.isArray(data) && data.length > 0)) && (React.createElement(lens.data.renderer, { flex: 1, filtered: filtered, selected: selected, properties: properties, hasUpdateActions: hasUpdateActions, changeSelected: setSelected, data: data, autouiContext: autouiContext, onEntityClick: !!onEntityClick || !!getBaseUrl
                        ? lensRendererOnEntityClick
                        : undefined, model: model })),
                ((_b = actionData === null || actionData === void 0 ? void 0 : actionData.action) === null || _b === void 0 ? void 0 : _b.renderer) &&
                    actionData.action.renderer({
                        schema: actionData.schema,
                        affectedEntries: actionData.affectedEntries,
                        onDone: function () { return setActionData(undefined); },
                    })))));
};
export { autoUIRunTransformers, autoUIDefaultPermissions, autoUIGetModelForCollection, autoUIAddToSchema, autoUIJsonSchemaPick, autoUIGetDisabledReason, };
export var getColumnsFromSchema = function (_a) {
    var _b;
    var schema = _a.schema, idField = _a.idField, tagField = _a.tagField, customSort = _a.customSort, priorities = _a.priorities, formats = _a.formats;
    return Object.entries((_b = schema.properties) !== null && _b !== void 0 ? _b : {})
        .filter(function (entry) {
        return entry[0] !== tagField && entry[0] !== idField;
    })
        .map(function (_a) {
        var _b;
        var key = _a[0], val = _a[1];
        if (typeof val !== 'object') {
            return;
        }
        var definedPriorities = priorities !== null && priorities !== void 0 ? priorities : {};
        var priority = definedPriorities.primary.find(function (prioritizedKey) { return prioritizedKey === key; })
            ? 'primary'
            : definedPriorities.secondary.find(function (prioritizedKey) { return prioritizedKey === key; })
                ? 'secondary'
                : 'tertiary';
        var widgetSchema = __assign(__assign({}, val), { title: undefined });
        return {
            title: val.title || key,
            field: key,
            key: key,
            selected: getSelected(key, priorities),
            priority: priority,
            type: 'predefined',
            sortable: (_b = customSort === null || customSort === void 0 ? void 0 : customSort[key]) !== null && _b !== void 0 ? _b : getSortingFunction(key, val),
            render: function (fieldVal, entry) {
                var calculatedField = autoUIAdaptRefScheme(fieldVal, val);
                return val.format ? (React.createElement(CustomWidget, { extraFormats: __spreadArrays((formats !== null && formats !== void 0 ? formats : []), defaultFormats), schema: widgetSchema, value: calculatedField, extraContext: entry })) : (calculatedField);
            },
        };
    })
        .filter(function (columnDef) { return !!columnDef; });
};
var templateObject_1;
