import { __assign, __spreadArrays } from "tslib";
import isEmpty from 'lodash/isEmpty';
import { autoUIJsonSchemaPick, } from '../schemaOps';
import get from 'lodash/get';
export var autoUIDefaultPermissions = {
    read: [],
    create: [],
    update: [],
    delete: false,
};
export var isJson = function (str) {
    try {
        JSON.parse(str);
    }
    catch (err) {
        return false;
    }
    return true;
};
export var autoUIRunTransformers = function (data, transformers, context) {
    if (!data) {
        return data;
    }
    if (!transformers || isEmpty(transformers)) {
        return data;
    }
    var transformEntry = function (entry) {
        return Object.entries(transformers).forEach(function (_a) {
            var fieldName = _a[0], transformer = _a[1];
            entry[fieldName] = transformer(entry, context);
        });
    };
    var mutatedData = data;
    if (Array.isArray(mutatedData)) {
        mutatedData.forEach(transformEntry);
    }
    else {
        transformEntry(mutatedData);
    }
    return mutatedData;
};
export var autoUIAdaptRefScheme = function (field, property) {
    var _a, _b, _c;
    if (!property || field == null) {
        return null;
    }
    if (typeof property === 'boolean' ||
        !((_a = property.description) === null || _a === void 0 ? void 0 : _a.includes('x-ref-scheme')) ||
        !isJson(property.description) ||
        !!property.format) {
        return field;
    }
    var refScheme = getPropertyRefScheme(property);
    var transformed = (_b = (Array.isArray(field) && field.length <= 1 ? field[0] : field)) !== null && _b !== void 0 ? _b : null;
    if (refScheme) {
        return (_c = get(transformed, refScheme)) !== null && _c !== void 0 ? _c : null;
    }
    return transformed;
};
export var autoUIGetModelForCollection = function (model, context) {
    var accessRole = context === null || context === void 0 ? void 0 : context.accessRole;
    var schema = !!model.priorities
        ? autoUIJsonSchemaPick(model.schema, __spreadArrays(model.priorities.primary, model.priorities.secondary, model.priorities.tertiary))
        : model.schema;
    return __assign(__assign({}, model), { permissions: (accessRole != null && model.permissions[accessRole]) ||
            model.permissions['default'], schema: schema });
};
export var autoUIAddToSchema = function (schema, schemaProperty, property, value) {
    var _a, _b;
    var _c;
    return __assign(__assign({}, schema), { properties: __assign(__assign({}, schema.properties), (_a = {}, _a[schemaProperty] = __assign(__assign({}, (_c = schema.properties) === null || _c === void 0 ? void 0 : _c[schemaProperty]), (_b = {}, _b[property] = value, _b)), _a)) });
};
export var getPropertyRefScheme = function (schemaValue) {
    return typeof schemaValue !== 'boolean' &&
        !!schemaValue.description &&
        isJson(schemaValue.description)
        ? JSON.parse(schemaValue.description)['x-ref-scheme']
        : null;
};
