/// <reference types="react" />
import type { JSONSchema7 as JSONSchema } from 'json-schema';
import { Dictionary } from '../../common-types';
import { ResourceTagModelService } from '../../components/TagManagementModal/tag-management-service';
export interface AutoUIBaseResource<T> {
    id: number;
    __permissions: Permissions<T>;
}
export interface Permissions<T> {
    read: Array<keyof T>;
    create: Array<keyof T>;
    update: Array<keyof T>;
    delete: boolean;
}
export interface Priorities<T> {
    primary: Array<keyof T>;
    secondary: Array<keyof T>;
    tertiary: Array<keyof T>;
}
export interface AutoUIRawModel<T> {
    resource: string;
    schema: JSONSchema;
    permissions: Dictionary<Permissions<T>>;
    priorities?: Priorities<T>;
}
export interface AutoUIModel<T> {
    resource: string;
    schema: JSONSchema;
    permissions: Permissions<T>;
    priorities?: Priorities<T>;
}
export interface AutoUIAction<T> {
    title: string;
    type: 'create' | 'update' | 'delete';
    renderer?: (props: {
        schema: JSONSchema;
        affectedEntries?: T[];
        onDone: () => void;
    }) => React.ReactNode;
    actionFn?: (props: {
        affectedEntries?: T[];
    }) => void;
    isDisabled?: (props: {
        affectedEntries?: T[];
    }) => string | false;
    isDangerous?: boolean;
}
export interface AutoUIContext<T> {
    resource: string;
    getBaseUrl?: (entry: T) => string;
    onEntityClick?: (entity: T, event: React.MouseEvent<HTMLAnchorElement, MouseEvent>) => void;
    idField: string;
    nameField?: string;
    tagField?: string;
    geolocation?: {
        latitudeField?: string;
        longitudeField?: string;
    };
    actions?: Array<AutoUIAction<T>>;
    customSort?: Dictionary<(a: T, b: T) => number>;
    sdk?: {
        tags?: ResourceTagModelService;
    };
}
export interface ActionData<T> {
    action: AutoUIAction<T>;
    schema: JSONSchema;
    affectedEntries?: T[];
}
export declare const autoUIJsonSchemaPick: <T>(schema: JSONSchema, selectors: (keyof T)[]) => JSONSchema;
export declare const getFieldForFormat: (schema: JSONSchema, format: string) => string | undefined;
