import { __spreadArrays } from "tslib";
import { JsonTypes } from '../../components/Renderer/types';
import { diff } from '../../utils';
import castArray from 'lodash/castArray';
import { createBrowserHistory } from 'history';
import { getPropertyRefScheme } from './models/helpers';
import get from 'lodash/get';
export var history = createBrowserHistory();
export var findInObject = function (obj, key) {
    var result;
    for (var property in obj) {
        if (obj.hasOwnProperty(property)) {
            if (property === key) {
                return obj[key];
            }
            else if (typeof obj[property] === 'object') {
                result = findInObject(obj[property], key);
                if (typeof result !== 'undefined') {
                    return result;
                }
            }
        }
    }
};
export var ObjectFromEntries = function (entries) {
    var obj = {};
    for (var _i = 0, entries_1 = entries; _i < entries_1.length; _i++) {
        var _a = entries_1[_i], key = _a[0], value = _a[1];
        obj[key] = value;
    }
    return obj;
};
export var getTagsDisabledReason = function (selected, tagField, t) {
    if (selected.length === 0) {
        return t('info.no_selected');
    }
    var lacksPermissionsOnSelected = selected.some(function (entry) {
        return (!entry.__permissions.delete &&
            !entry.__permissions.create.includes(tagField) &&
            !entry.__permissions.update.includes(tagField));
    });
    if (lacksPermissionsOnSelected) {
        return t('info.edit_tag_no_permissions', { resource: 'item' });
    }
    return false;
};
export var getCreateDisabledReason = function (permissions, hasOngoingAction, t) {
    var _a;
    if (hasOngoingAction) {
        return t('info.ongoing_action_wait');
    }
    if (!((_a = permissions.create) === null || _a === void 0 ? void 0 : _a.length)) {
        return t('info.create_item_no_permissions', { resource: 'item' });
    }
};
export var autoUIGetDisabledReason = function (selected, hasOngoingAction, actionType, t) {
    if (selected.length === 0) {
        return t('info.no_selected');
    }
    if (hasOngoingAction) {
        return t('info.ongoing_action_wait');
    }
    if (!actionType) {
        return;
    }
    var lacksPermissionsOnSelected = selected.some(function (entry) {
        return (!entry.__permissions[actionType] ||
            (Array.isArray(entry.__permissions[actionType]) &&
                entry.__permissions[actionType].length <= 0));
    });
    if (lacksPermissionsOnSelected) {
        return t('info.update_item_no_permissions', {
            action: actionType,
            resource: 'item',
        });
    }
};
var sortFn = function (a, b, ref) {
    var _a, _b;
    var aa = (_a = get(a, ref)) !== null && _a !== void 0 ? _a : '';
    var bb = (_b = get(b, ref)) !== null && _b !== void 0 ? _b : '';
    if (typeof aa === 'string' && typeof bb === 'string') {
        return aa.toLowerCase().localeCompare(bb.toLowerCase());
    }
    return diff(aa, bb);
};
export var getSortingFunction = function (schemaKey, schemaValue) {
    var types = castArray(schemaValue.type);
    var refScheme = getPropertyRefScheme(schemaValue);
    if (types.includes(JsonTypes.string)) {
        return function (a, b) { return sortFn(a, b, schemaKey); };
    }
    if (types.includes(JsonTypes.object) && refScheme) {
        return function (a, b) { return sortFn(a, b, __spreadArrays([schemaKey], [refScheme])); };
    }
    if (types.includes(JsonTypes.array) && refScheme) {
        return function (a, b) { return sortFn(a, b, __spreadArrays([schemaKey, 0], [refScheme])); };
    }
    return function (a, b) { return diff(a[schemaKey], b[schemaKey]); };
};
export var getSelected = function (key, priorities) {
    if (!priorities) {
        return true;
    }
    return ((priorities === null || priorities === void 0 ? void 0 : priorities.primary.includes(key)) || (priorities === null || priorities === void 0 ? void 0 : priorities.secondary.includes(key)));
};
export var onClickOutOrEsc = function (wrapper, callback) {
    var handleClickOutside = function (event) {
        if (!wrapper.contains(event.target)) {
            handler();
        }
    };
    var handleEsc = function (event) {
        if (event.key === 'Escape') {
            handler();
        }
    };
    var handler = function () {
        callback();
        if (document.activeElement instanceof HTMLElement) {
            document.activeElement.blur();
        }
        document.removeEventListener('mousedown', handleClickOutside);
        document.removeEventListener('keydown', handleEsc);
    };
    document.addEventListener('mousedown', handleClickOutside);
    document.addEventListener('keydown', handleEsc);
};
