import { __assign, __awaiter, __generator, __spreadArrays } from "tslib";
import React from 'react';
import { useLocation } from 'react-router';
import { getAllNaturalPropertiesKeys, getSelectableOptions, getSchemaFromLocation, pine, getFromRef, } from './odata';
import { useRequest } from '../../hooks/useRequest';
import { AutoUI, autoUIRunTransformers } from '../AutoUI';
import { findInObject, history } from '../AutoUI/utils';
import isEmpty from 'lodash/isEmpty';
import { ActionMethods } from '.';
var updateSchema = function (schema) {
    if (!schema.properties) {
        return schema;
    }
    var newSchema = __assign(__assign({}, schema), { properties: Object.entries(schema.properties).reduce(function (acc, _a) {
            var _b, _c;
            var key = _a[0], value = _a[1];
            return typeof value === 'object'
                ? __assign(__assign({}, acc), (_b = {}, _b[key] = __assign(__assign({}, value), { title: key.split('_').join(' ') }), _b)) : __assign(__assign({}, acc), (_c = {}, _c[key] = value, _c));
        }, {}) });
    return newSchema;
};
var generateModel = function (schema, resourceName, naturalPropertiesKeys) {
    var firstPropertyKey = naturalPropertiesKeys[0], otherPropertyKeys = naturalPropertiesKeys.slice(1);
    return {
        resource: resourceName,
        schema: updateSchema(schema),
        permissions: {
            read: __spreadArrays([firstPropertyKey], otherPropertyKeys),
            create: [firstPropertyKey],
            update: [],
            delete: false,
        },
        priorities: {
            primary: [firstPropertyKey],
            secondary: __spreadArrays(otherPropertyKeys),
            tertiary: [],
        },
    };
};
export var Content = function (_a) {
    var openApiJson = _a.openApiJson, openActionSidebar = _a.openActionSidebar;
    var pathname = useLocation().pathname;
    var resourceName = pathname.replace(/^\/([^\/]*).*$/, '$1');
    var id = pathname.substring(pathname.lastIndexOf('/') + 1);
    var endsWithValidId = !isNaN(parseInt(id, 10));
    var schema = getSchemaFromLocation(openApiJson, resourceName);
    var naturalPropertiesKeys = getAllNaturalPropertiesKeys(schema === null || schema === void 0 ? void 0 : schema.properties);
    var correspondingPath = !endsWithValidId
        ? openApiJson.paths["/" + resourceName]
        : openApiJson.paths["/" + resourceName + "({id})"];
    var data = useRequest(function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, pine.get(__assign(__assign({ resource: resourceName }, (endsWithValidId && { id: id })), { options: {
                            $select: __spreadArrays(getSelectableOptions(correspondingPath, [])),
                        } }))];
                case 1: return [2, _a.sent()];
            }
        });
    }); }, [openApiJson, pathname], { polling: false })[0];
    var model = React.useMemo(function () {
        if (!schema) {
            return null;
        }
        return generateModel(schema, resourceName, naturalPropertiesKeys);
    }, [schema, resourceName, naturalPropertiesKeys]);
    var memoizedData = React.useMemo(function () {
        return autoUIRunTransformers(data, {
            contract: function () { return null; },
            __permissions: function () { return model === null || model === void 0 ? void 0 : model.permissions; },
        }, {});
    }, [data, model]);
    var memoizedActions = React.useMemo(function () {
        if (!correspondingPath) {
            return undefined;
        }
        return Object.entries(correspondingPath)
            .filter(function (_a) {
            var pathkey = _a[0];
            return [
                ActionMethods.POST,
                ActionMethods.PATCH,
                ActionMethods.DELETE,
            ].includes(pathkey);
        })
            .map(function (_a) {
            var pathKey = _a[0], pathDescription = _a[1];
            var requestSchemaRef = findInObject(pathDescription.requestBody, '$ref');
            var requestSchema = requestSchemaRef
                ? getFromRef(openApiJson, requestSchemaRef)
                : id;
            if (pathKey === ActionMethods.POST) {
                return {
                    title: "Add " + resourceName,
                    type: 'create',
                    actionFn: function () {
                        return openActionSidebar({
                            action: ActionMethods.POST,
                            schema: requestSchema,
                            resourceName: resourceName,
                            id: id,
                        });
                    },
                };
            }
            if (pathKey === ActionMethods.PATCH) {
                return {
                    title: "Update " + resourceName,
                    type: 'update',
                };
            }
            return {
                title: "Delete " + resourceName,
                type: 'delete',
            };
        });
    }, [correspondingPath]);
    if (!model) {
        return React.createElement(React.Fragment, null, "Could not generate a model");
    }
    if (!memoizedData || isEmpty(memoizedData)) {
        return React.createElement(React.Fragment, null, "No data");
    }
    return (React.createElement(AutoUI, __assign({ model: model, actions: memoizedActions, data: memoizedData }, (!endsWithValidId && {
        onEntityClick: function (entity) { return history.push(pathname + "/" + entity.id); },
    }))));
};
