import React from 'react';
import { render } from '@testing-library/react';
import { Provider } from '../../';
import { Markdown } from '.';
import suite from './specsuite';
export var codeBlocks = "\n## Code blocks\n\n```\n// This is plaintext\nconst foo = () => {\nreturn 'bar'\n}\n```\n\n```javascript\n// This is javascript\nconst foo = () => {\n  return 'bar'\n}\n```\n";
export var htmlBlocks = "\n\n## Inline HTML\n\n<strong>An image:</strong>\n<br>\n<img src=\"https://balena.io\" />\n<br>\n<em>A link:</em>\n<a target=\"_blank\" href=\"http://github.com/\">http://github.com/</a>\n\n## Keyboard keys\n\n<kbd>cmd</kbd> + <kbd>alt</kbd> + <kbd>shift</kbd> + <kbd>a</kbd>\n";
export var sanitizeBlocks = "\n<img src=x onerror=alert(123) />\n";
describe('Markdown component', function () {
    it('should not highlight code when disabled', function () {
        var container = render(React.createElement(Provider, null,
            React.createElement(Markdown, { disableCodeHighlight: true }, codeBlocks))).container;
        expect(container).toMatchSnapshot();
    });
    it('should not sanitize html when disabled', function () {
        var container = render(React.createElement(Provider, null,
            React.createElement(Markdown, { sanitizerOptions: null }, sanitizeBlocks))).container;
        expect(container).toMatchSnapshot();
    });
    it('should not render raw html when disabled', function () {
        var container = render(React.createElement(Provider, null,
            React.createElement(Markdown, { disableRawHtml: true }, htmlBlocks))).container;
        expect(container).toMatchSnapshot();
    });
    it('should decorate the text matching the condition', function () {
        var decorators = [
            {
                match: new RegExp('(\\s|^)((@{1,2}|#|!{1,2})[a-z\\d-_\\/]+(\\.[a-z\\d-_\\/]+)*)(\\s|$)', 'gmi'),
                captureGroupIndex: 2,
                component: 'span',
                properties: {
                    style: {
                        color: 'green',
                    },
                },
            },
        ];
        var container = render(React.createElement(Provider, null,
            React.createElement(Markdown, { decorators: decorators }, "@good foo @bad@bad [@good](https://github.com) bar@bad baz qux. `Is @bad inside code` @good @good"))).container;
        expect(container).toMatchSnapshot();
    });
    suite.forEach(function (testCase) {
        it(testCase.name, function () {
            var container = render(React.createElement(Provider, null,
                React.createElement(Markdown, { sanitizerOptions: testCase.sanitizerOptions }, testCase.source))).container;
            expect(container).toMatchSnapshot();
        });
    });
});
