import { __awaiter, __generator, __spreadArrays } from "tslib";
import * as React from 'react';
import { createPoll } from '../utils/poll';
export var useRequest = function (action, deps, options) {
    var polling = options.polling, pollInterval = options.pollInterval, stopExecution = options.stopExecution;
    var _a = React.useState(true), loading = _a[0], setLoading = _a[1];
    var _b = React.useState(), error = _b[0], setError = _b[1];
    var _c = React.useState(), data = _c[0], setData = _c[1];
    var _d = React.useState(true), isVisible = _d[0], setIsVisible = _d[1];
    var pollRef = React.useRef();
    React.useEffect(function () {
        var handleVisibilityChange = function () { return setIsVisible(!document.hidden); };
        document.addEventListener('visibilitychange', handleVisibilityChange);
        return function () {
            return document.removeEventListener('visibilitychange', handleVisibilityChange);
        };
    });
    var loadData = React.useCallback(function (poll) { return __awaiter(void 0, void 0, void 0, function () {
        var response, e_1;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    _a.trys.push([0, 2, 3, 4]);
                    return [4, action(poll)];
                case 1:
                    response = _a.sent();
                    setData(response);
                    return [3, 4];
                case 2:
                    e_1 = _a.sent();
                    if (e_1 instanceof Error) {
                        setError(e_1);
                    }
                    else {
                        setError(new Error(typeof e_1 === 'string' ? e_1 : 'Unknown error'));
                    }
                    setData([]);
                    return [3, 4];
                case 3:
                    setLoading(false);
                    return [7];
                case 4: return [2];
            }
        });
    }); }, deps);
    var forcePoll = React.useCallback(function () {
        setLoading(true);
        if (pollRef.current) {
            pollRef.current.poll({ forced: true });
        }
        else {
            loadData();
        }
    }, [pollRef, loadData]);
    React.useEffect(function () {
        if (stopExecution) {
            return pollRef.current && pollRef.current.stop();
        }
        if (!polling) {
            loadData();
            return;
        }
        pollRef.current = createPoll(loadData, pollInterval, isVisible);
        pollRef.current.start();
        return function () {
            if (pollRef.current) {
                pollRef.current.destroy();
                pollRef.current = undefined;
            }
        };
    }, [polling, loadData, pollInterval, stopExecution, isVisible]);
    React.useEffect(function () {
        if (!polling) {
            return;
        }
        setData(undefined);
        forcePoll();
    }, __spreadArrays(deps, [polling]));
    return [data, loading, error, forcePoll];
};
