import { __spreadArrays } from "tslib";
import invert from 'lodash/invert';
import has from 'lodash/has';
import * as React from 'react';
import { Flex } from '../../components/Flex';
import { Box } from '../../components/Box';
import { Txt } from '../../components/Txt';
import { Tabs, Tab } from '../../components/Tabs';
import { Link } from '../../components/Link';
import { List } from '../../components/List';
import { Heading } from '../../components/Heading';
import { useTranslation } from '../../hooks/useTranslation';
import { interpolateMustache } from './utils';
export var osTitles = {
    windows: 'Windows',
    osx: 'MacOS',
    linux: 'Linux',
    unknown: 'Unknown',
};
export var getUserOs = function () {
    var platform = window.navigator.platform.toLowerCase();
    if (platform.includes('win')) {
        return 'windows';
    }
    if (platform.includes('mac')) {
        return 'osx';
    }
    if (platform.includes('x11') || platform.includes('linux')) {
        return 'linux';
    }
    return 'unknown';
};
var osTabIndices = {
    windows: 0,
    osx: 1,
    linux: 2,
    unknown: 0,
};
var osTabNames = invert(osTabIndices);
export var ApplicationInstructions = React.memo(function (_a) {
    var _b;
    var deviceType = _a.deviceType, templateData = _a.templateData;
    var t = useTranslation().t;
    var _c = React.useState(getUserOs()), currentOs = _c[0], setCurrentOs = _c[1];
    var instructions = deviceType === null || deviceType === void 0 ? void 0 : deviceType.instructions;
    var hasOsSpecificInstructions = !Array.isArray(instructions);
    var normalizedOs = currentOs === 'unknown' ? 'linux' : currentOs;
    React.useEffect(function () {
        if (hasOsSpecificInstructions && instructions) {
            var oses = Object.keys(instructions);
            if (!oses.includes(currentOs) && oses.length > 0) {
                setCurrentOs(oses[0]);
            }
        }
    }, [currentOs, setCurrentOs, instructions, hasOsSpecificInstructions]);
    if (!deviceType || !instructions) {
        return React.createElement(Txt, null, t('no_data.no_instructions_found'));
    }
    var interpolatedInstructions = (hasOsSpecificInstructions
        ? instructions[normalizedOs]
        : instructions).map(function (instruction) {
        return interpolateMustache(templateData, instruction.replace(/<a/, '<a target="_blank"'));
    });
    var hasConfigDownloadOnly = ((_b = deviceType.yocto) === null || _b === void 0 ? void 0 : _b.deployArtifact) === 'docker-image';
    var finalInstructions = __spreadArrays([
        hasConfigDownloadOnly
            ? t('actions.use_form_to_download_configuration')
            : t('actions.use_from_to_configure_and_download')
    ], interpolatedInstructions, [
        t('actions_messages.appearance_device_explanation'),
    ]);
    return (React.createElement(Flex, { flexDirection: "column", alignItems: "flex-start" },
        React.createElement(Heading.h5, { mb: 3 }, t('labels.instructions')),
        hasOsSpecificInstructions && (React.createElement(Box, { mb: 3 },
            React.createElement(Tabs, { activeIndex: osTabIndices[currentOs], onActive: function (index) { return setCurrentOs(osTabNames[index.toString()]); } }, Object.keys(instructions).map(function (os) {
                return React.createElement(Tab, { key: os, title: osTitles[os] });
            })))),
        React.createElement(InstructionsList, { instructions: finalInstructions }),
        React.createElement(Flex, { mt: 4 },
            React.createElement(Txt, null,
                "For more details please refer to our",
                ' ',
                React.createElement(Link, { blank: true, href: "https://www.balena.io/docs/learn/getting-started/" + deviceType.slug + "/nodejs/" }, "Getting Started Guide"),
                "."))));
});
var InstructionsItem = function (props) {
    var node = props.node;
    var hasChildren = has(node, 'children');
    var text = null;
    if (typeof node === 'string') {
        text = node;
    }
    if (node === null || node === void 0 ? void 0 : node.text) {
        text = node.text;
    }
    return (React.createElement("span", null,
        React.createElement("span", { dangerouslySetInnerHTML: { __html: text } }),
        hasChildren && (React.createElement(List, null, node.children.map(function (item) {
            return React.createElement(InstructionsItem, { node: item });
        })))));
};
var InstructionsList = function (props) {
    var instructions = props.instructions;
    return (React.createElement(List, { ordered: true, fontSize: 14 }, instructions.map(function (item) {
        return React.createElement(InstructionsItem, { key: item, node: item });
    })));
};
