import { __awaiter, __generator } from "tslib";
var DEFAULT_INTERVAL = 15000;
var DEFAULT_GRACE_RATIO = 0.33;
var Poll = (function () {
    function Poll(fn, interval, graceRatio, isTabActive) {
        this._cancelled = true;
        this._counter = 0;
        this.pollInterval = null;
        this.lastCompleteTime = 0;
        this.blocked = false;
        this.interval = interval;
        this.fn = fn;
        this.poll = this.poll.bind(this);
        this.graceInterval = this.interval * graceRatio;
        this.isTabActive = isTabActive;
    }
    Object.defineProperty(Poll.prototype, "cancelled", {
        get: function () {
            return this._cancelled;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Poll.prototype, "counter", {
        get: function () {
            return this._counter;
        },
        enumerable: false,
        configurable: true
    });
    Poll.prototype.poll = function (opts) {
        return __awaiter(this, void 0, void 0, function () {
            var forced;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (this.cancelled || this.blocked) {
                            return [2];
                        }
                        forced = opts && opts.forced;
                        if (!forced && !this.isTabActive && this.lastCompleteTime !== 0) {
                            return [2];
                        }
                        if (!forced && Date.now() - this.lastCompleteTime < this.graceInterval) {
                            return [2];
                        }
                        this.blocked = true;
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, , 3, 4]);
                        return [4, this.fn(this)];
                    case 2:
                        _a.sent();
                        this.lastCompleteTime = Date.now();
                        return [3, 4];
                    case 3:
                        this._counter++;
                        this.blocked = false;
                        return [7];
                    case 4: return [2];
                }
            });
        });
    };
    Poll.prototype.start = function () {
        if (this.pollInterval != null) {
            return;
        }
        this.lastCompleteTime = 0;
        this._cancelled = false;
        this.pollInterval = setInterval(this.poll, this.interval);
        return this.poll();
    };
    Poll.prototype.stop = function () {
        if (this.pollInterval) {
            clearInterval(this.pollInterval);
        }
        this._cancelled = true;
        this.pollInterval = null;
    };
    Poll.prototype.destroy = function () {
        var _this = this;
        this.stop();
        this.fn = function () { return __awaiter(_this, void 0, void 0, function () { return __generator(this, function (_a) {
            return [2, undefined];
        }); }); };
    };
    return Poll;
}());
export { Poll };
export var createPoll = function (fn, interval, isTabActive, graceRatio) {
    if (interval === void 0) { interval = DEFAULT_INTERVAL; }
    if (isTabActive === void 0) { isTabActive = true; }
    if (graceRatio === void 0) { graceRatio = DEFAULT_GRACE_RATIO; }
    return new Poll(fn, interval, graceRatio, isTabActive);
};
