import * as utils from '.';
describe('utils', function () {
    describe('.stripSchemaFormats()', function () {
        var schema = {
            type: 'object',
            properties: {
                array: {
                    type: 'array',
                    items: {
                        type: 'string',
                        format: 'dnsmasq-address',
                    },
                },
                foo: {
                    type: 'object',
                    properties: {
                        bar: {
                            type: 'string',
                            format: 'uri',
                        },
                    },
                },
                baz: {
                    type: 'string',
                    format: 'uuid',
                },
                buzz: {
                    type: 'string',
                    format: 'email',
                },
            },
        };
        it('should remove formats from a schema', function () {
            expect(utils.stripSchemaFormats(schema)).toEqual({
                type: 'object',
                properties: {
                    array: {
                        type: 'array',
                        items: {
                            type: 'string',
                        },
                    },
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                            },
                        },
                    },
                    baz: {
                        type: 'string',
                    },
                    buzz: {
                        type: 'string',
                    },
                },
            });
        });
        it('should allow a whitelist of formats', function () {
            var whitelist = ['email', 'uri'];
            expect(utils.stripSchemaFormats(schema, whitelist)).toEqual({
                type: 'object',
                properties: {
                    array: {
                        type: 'array',
                        items: {
                            type: 'string',
                        },
                    },
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                                format: 'uri',
                            },
                        },
                    },
                    baz: {
                        type: 'string',
                    },
                    buzz: {
                        type: 'string',
                        format: 'email',
                    },
                },
            });
        });
    });
    describe('.disallowAdditionalProperties()', function () {
        var schema = {
            type: 'object',
            properties: {
                foo: {
                    type: 'object',
                    properties: {
                        bar: {
                            type: 'string',
                        },
                    },
                    additionalProperties: true,
                },
            },
            additionalProperties: true,
        };
        it('should remove formats from a schema', function () {
            expect(utils.disallowAdditionalProperties(schema)).toEqual({
                type: 'object',
                properties: {
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                            },
                        },
                        additionalProperties: false,
                    },
                },
                additionalProperties: false,
            });
        });
        it('should not modify the original schema', function () {
            utils.disallowAdditionalProperties(schema);
            expect(schema).toEqual({
                type: 'object',
                properties: {
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                            },
                        },
                        additionalProperties: true,
                    },
                },
                additionalProperties: true,
            });
        });
    });
});
